@@ -1,36 +1,36 @@
-/* $Id: sccont.c 10864 2010-03-13 23:37:28Z airwin $
- *
- *      Contour plotter front-ends for Fortran.
- *
- * Copyright (C) 2004  Alan W. Irwin
- *
- * This file is part of PLplot.
- *
- * PLplot is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Library Public License as published
- * by the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * PLplot is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with PLplot; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
- *
- */
+// $Id: sccont.c 11759 2011-06-01 17:41:34Z airwin $
+//
+//      Contour plotter front-ends for Fortran.
+//
+// Copyright (C) 2004  Alan W. Irwin
+//
+// This file is part of PLplot.
+//
+// PLplot is free software; you can redistribute it and/or modify
+// it under the terms of the GNU Library General Public License as published
+// by the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+//
+// PLplot is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Library General Public License for more details.
+//
+// You should have received a copy of the GNU Library General Public License
+// along with PLplot; if not, write to the Free Software
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+//
+//
 
 #include "plstubs.h"
 
-/*----------------------------------------------------------------------*\
- * pltr0f()
- *
- * Identity transformation for plots from Fortran.
- * Only difference from C-language identity function (pltr0) is that the
- * Fortran paradigm for array index is used, i.e. starting at 1.
- \*----------------------------------------------------------------------*/
+//--------------------------------------------------------------------------
+// pltr0f()
+//
+// Identity transformation for plots from Fortran.
+// Only difference from C-language identity function (pltr0) is that the
+// Fortran paradigm for array index is used, i.e. starting at 1.
+//--------------------------------------------------------------------------
 
 void
 pltr0f( PLFLT x, PLFLT y, PLFLT *tx, PLFLT *ty, void *pltr_data )
@@ -39,20 +39,20 @@ pltr0f( PLFLT x, PLFLT y, PLFLT *tx, PLFLT *ty, void *pltr_data )
     *ty = y + 1.0;
 }
 
-/*----------------------------------------------------------------------*\
- * Contour plotter front-ends.
- * These specify the row-dominant function evaluator in the plfcont
- * argument list.  NO TRANSPOSE IS NECESSARY.  The routines are as follows:
- *
- * - plcon0	no transformation
- * - plcon1	linear interpolation from singly dimensioned coord arrays
- * - plcon2	linear interpolation from doubly dimensioned coord arrays
- *
- * The latter two work by calling plfcont() with the appropriate grid
- * structure for input to pltr2f().
- \*----------------------------------------------------------------------*/
+//--------------------------------------------------------------------------
+// Contour plotter front-ends.
+// These specify the row-dominant function evaluator in the plfcont
+// argument list.  NO TRANSPOSE IS NECESSARY.  The routines are as follows:
+//
+// - plcon0	no transformation
+// - plcon1	linear interpolation from singly dimensioned coord arrays
+// - plcon2	linear interpolation from doubly dimensioned coord arrays
+//
+// The latter two work by calling plfcont() with the appropriate grid
+// structure for input to pltr2f().
+//--------------------------------------------------------------------------
 
-/* no transformation */
+// no transformation
 
 void
 PLCON07( PLFLT *z, PLINT *nx, PLINT *ny, PLINT *kx, PLINT *lx,
@@ -69,7 +69,7 @@ PLCON07( PLFLT *z, PLINT *nx, PLINT *ny, PLINT *kx, PLINT *lx,
         pltr0f, NULL );
 }
 
-/* 1-d transformation */
+// 1-d transformation
 
 void
 PLCON17( PLFLT *z, PLINT *nx, PLINT *ny, PLINT *kx, PLINT *lx,
@@ -93,7 +93,7 @@ PLCON17( PLFLT *z, PLINT *nx, PLINT *ny, PLINT *kx, PLINT *lx,
         pltr1, (void *) &cgrid );
 }
 
-/* 2-d transformation */
+// 2-d transformation
 
 void
 PLCON27( PLFLT *z, PLINT *nx, PLINT *ny, PLINT *kx, PLINT *lx,
@@ -117,20 +117,20 @@ PLCON27( PLFLT *z, PLINT *nx, PLINT *ny, PLINT *kx, PLINT *lx,
         pltr2f, (void *) &cgrid );
 }
 
-/*----------------------------------------------------------------------*\
- * Vector plotter front-ends.
- * These specify the row-dominant function evaluator in the plfvect
- * argument list.  NO TRANSPOSE IS NECESSARY.  The routines are as follows:
- *
- * - plvec0	no transformation
- * - plvec1	linear interpolation from singly dimensioned coord arrays
- * - plvec2	linear interpolation from doubly dimensioned coord arrays
- *
- * The latter two work by calling plfvect() with the appropriate grid
- * structure for input to pltr2f().
- \*----------------------------------------------------------------------*/
+//--------------------------------------------------------------------------
+// Vector plotter front-ends.
+// These specify the row-dominant function evaluator in the plfvect
+// argument list.  NO TRANSPOSE IS NECESSARY.  The routines are as follows:
+//
+// - plvec0	no transformation
+// - plvec1	linear interpolation from singly dimensioned coord arrays
+// - plvec2	linear interpolation from doubly dimensioned coord arrays
+//
+// The latter two work by calling plfvect() with the appropriate grid
+// structure for input to pltr2f().
+//--------------------------------------------------------------------------
 
-/* no transformation */
+// no transformation
 
 void
 PLVEC07( PLFLT *u, PLFLT *v, PLINT *nx, PLINT *ny, PLFLT *scale )
@@ -149,7 +149,7 @@ PLVEC07( PLFLT *u, PLFLT *v, PLINT *nx, PLINT *ny, PLFLT *scale )
         *nx, *ny, *scale, pltr0f, NULL );
 }
 
-/* 1-d transformation */
+// 1-d transformation
 
 void
 PLVEC17( PLFLT *u, PLFLT *v, PLINT *nx, PLINT *ny, PLFLT *scale,
@@ -176,7 +176,7 @@ PLVEC17( PLFLT *u, PLFLT *v, PLINT *nx, PLINT *ny, PLFLT *scale,
         *nx, *ny, *scale, pltr1, (void *) &cgrid );
 }
 
-/* 2-d transformation */
+// 2-d transformation
 
 void
 PLVEC27( PLFLT *u, PLFLT *v, PLINT *nx, PLINT *ny, PLFLT *scale,
@@ -203,9 +203,9 @@ PLVEC27( PLFLT *u, PLFLT *v, PLINT *nx, PLINT *ny, PLFLT *scale,
         *nx, *ny, *scale, pltr2f, (void *) &cgrid );
 }
 
-/*----------------------------------------------------------------------*\
- * Here are the old contour plotters.
- \*----------------------------------------------------------------------*/
+//--------------------------------------------------------------------------
+// Here are the old contour plotters.
+//--------------------------------------------------------------------------
 
 static void
 pltr( PLFLT x, PLFLT y, PLFLT *tx, PLFLT *ty, void *pltr_data )
@@ -251,19 +251,19 @@ PLVECT7( PLFLT *u, PLFLT *v, PLINT *nx, PLINT *ny, PLFLT *scale,
         pltr, (void *) ftr );
 }
 
-/*----------------------------------------------------------------------*\
- * plfshade front-ends.
- * These specify the row-dominant function evaluator in the plfshade
- * argument list.  NO TRANSPOSE IS NECESSARY.  The routines are as follows:
- *
- * - plshade0	map indices to xmin, xmax, ymin, ymax.
- * The next two work by calling plfshade() with the appropriate grid
- * structure for input to pltr2f().
- * - plshade1	linear interpolation from singly dimensioned coord arrays
- * - plshade2	linear interpolation from doubly dimensioned coord arrays
- * - plshade    tr array transformation
- *
- \*----------------------------------------------------------------------*/
+//--------------------------------------------------------------------------
+// plfshade front-ends.
+// These specify the row-dominant function evaluator in the plfshade
+// argument list.  NO TRANSPOSE IS NECESSARY.  The routines are as follows:
+//
+// - plshade0	map indices to xmin, xmax, ymin, ymax.
+// The next two work by calling plfshade() with the appropriate grid
+// structure for input to pltr2f().
+// - plshade1	linear interpolation from singly dimensioned coord arrays
+// - plshade2	linear interpolation from doubly dimensioned coord arrays
+// - plshade    tr array transformation
+//
+//--------------------------------------------------------------------------
 
 void
 PLSHADE07( PLFLT *z, PLINT *nx, PLINT *ny, const char *defined,
@@ -273,33 +273,34 @@ PLSHADE07( PLFLT *z, PLINT *nx, PLINT *ny, const char *defined,
            PLINT *min_color, PLINT *min_width,
            PLINT *max_color, PLINT *max_width, PLINT *lx )
 {
-    PLINT rect = 1;
-    PLFLT ** a;
-    int   i, j;
+    PLINT   rect = 1;
 
-/* Create a vectored a array from transpose of the fortran z array. */
-    plAlloc2dGrid( &a, *nx, *ny );
-    for ( i = 0; i < *nx; i++ )
-    {
-        for ( j = 0; j < *ny; j++ )
-        {
-            a[i][j] = z[i + j * *lx];
-        }
-    }
+    PLfGrid data;
 
-    c_plshade( a, *nx, *ny, NULL,
+// Fill a grid data structure to hold the fortran z array.
+    data.f  = z;
+    data.nx = *lx;
+    data.ny = *ny;
+
+
+// Call plfshade to do the actual work - plf2evalr is the
+//   interface that deals with the fortran data organisation
+
+    plfshade( plf2evalr, &data, NULL, NULL, *nx, *ny,
         *xmin, *xmax, *ymin, *ymax,
         *shade_min, *shade_max,
         *sh_cmap, *sh_color, *sh_width,
         *min_color, *min_width, *max_color, *max_width,
         c_plfill, rect, NULL, NULL );
 
-/* Clean up memory allocated for a */
-    plFree2dGrid( a, *nx, *ny );
+// Clean up memory allocated for a
+//
+//    plFree2dGrid( a, *nx, *ny );
+//
 }
 
 
-/* 1-d transformation */
+// 1-d transformation
 
 void
 PLSHADE17( PLFLT *z, PLINT *nx, PLINT *ny, const char *defined,
@@ -311,36 +312,33 @@ PLSHADE17( PLFLT *z, PLINT *nx, PLINT *ny, const char *defined,
            PLFLT *xg1, PLFLT *yg1, PLINT *lx )
 {
     PLINT   rect = 1;
-    PLFLT   ** a;
-    int     i, j;
+    PLfGrid data;
     PLcGrid cgrid;
 
-/* Create a vectored a array from transpose of the fortran z array. */
-    plAlloc2dGrid( &a, *nx, *ny );
-    for ( i = 0; i < *nx; i++ )
-    {
-        for ( j = 0; j < *ny; j++ )
-        {
-            a[i][j] = z[i + j * *lx];
-        }
-    }
+// Fill a grid data structure to hold the coordinate arrays.
 
     cgrid.nx = *nx;
     cgrid.ny = *ny;
     cgrid.xg = xg1;
     cgrid.yg = yg1;
-    c_plshade( a, *nx, *ny, NULL,
+
+// Fill a grid data structure to hold the fortran z array.
+    data.f  = z;
+    data.nx = *lx;
+    data.ny = *ny;
+
+// Call plfshade to do the actual work - plf2evalr is the
+//   interface that deals with the fortran data organisation.
+
+    plfshade( plf2evalr, &data, NULL, NULL, *nx, *ny,
         *xmin, *xmax, *ymin, *ymax,
         *shade_min, *shade_max,
         *sh_cmap, *sh_color, *sh_width,
         *min_color, *min_width, *max_color, *max_width,
         c_plfill, rect, pltr1, ( PLPointer ) & cgrid );
-
-/* Clean up memory allocated for a */
-    plFree2dGrid( a, *nx, *ny );
 }
 
-/* 2-d transformation */
+// 2-d transformation
 
 void
 PLSHADE27( PLFLT *z, PLINT *nx, PLINT *ny, const char *defined,
@@ -351,38 +349,30 @@ PLSHADE27( PLFLT *z, PLINT *nx, PLINT *ny, const char *defined,
            PLINT *max_color, PLINT *max_width,
            PLFLT *xg2, PLFLT *yg2, PLINT *lx )
 {
-    PLINT    rect = 0;
-    PLFLT    **a;
-    int      i, j;
-    PLcGrid2 cgrid2;
+    PLINT   rect = 0;
+    PLfGrid data;
+    PLcGrid cgrid;
 
-/* Create a vectored a array from transpose of the fortran z array. */
-    plAlloc2dGrid( &a, *nx, *ny );
-    plAlloc2dGrid( &cgrid2.xg, *nx, *ny );
-    plAlloc2dGrid( &cgrid2.yg, *nx, *ny );
-    cgrid2.nx = *nx;
-    cgrid2.ny = *ny;
-    for ( i = 0; i < *nx; i++ )
-    {
-        for ( j = 0; j < *ny; j++ )
-        {
-            a[i][j]         = z[i + j * *lx];
-            cgrid2.xg[i][j] = xg2[i + j * *lx];
-            cgrid2.yg[i][j] = yg2[i + j * *lx];
-        }
-    }
+// Fill a grid data structure to hold the coordinate arrays.
+    cgrid.nx = *lx;
+    cgrid.ny = *ny;
+    cgrid.xg = xg2;
+    cgrid.yg = yg2;
 
-    c_plshade( a, *nx, *ny, NULL,
+// Fill a grid data structure to hold the fortran z array.
+    data.f  = z;
+    data.nx = *lx;
+    data.ny = *ny;
+
+// Call plfshade to do the actual work - plf2evalr is the
+//   interface that deals with the fortran data organisation.
+
+    plfshade( plf2evalr, &data, NULL, NULL, *nx, *ny,
         *xmin, *xmax, *ymin, *ymax,
         *shade_min, *shade_max,
         *sh_cmap, *sh_color, *sh_width,
         *min_color, *min_width, *max_color, *max_width,
-        c_plfill, rect, pltr2, (void *) &cgrid2 );
-
-/* Clean up memory allocated for a */
-    plFree2dGrid( a, *nx, *ny );
-    plFree2dGrid( cgrid2.xg, *nx, *ny );
-    plFree2dGrid( cgrid2.yg, *nx, *ny );
+        c_plfill, rect, pltr2f, ( PLPointer ) & cgrid );
 }
 
 void
@@ -393,40 +383,34 @@ PLSHADE7( PLFLT *z, PLINT *nx, PLINT *ny, const char *defined,
           PLINT *min_color, PLINT *min_width,
           PLINT *max_color, PLINT *max_width, PLFLT *ftr, PLINT *lx )
 {
-    PLINT rect = 1;
-    PLFLT ** a;
-    int   i, j;
+    PLINT   rect = 1;
+    PLfGrid data;
 
-/* Create a vectored a array from transpose of the fortran z array. */
-    plAlloc2dGrid( &a, *nx, *ny );
-    for ( i = 0; i < *nx; i++ )
-    {
-        for ( j = 0; j < *ny; j++ )
-        {
-            a[i][j] = z[i + j * *lx];
-        }
-    }
+// Fill a grid data structure to hold the fortran z array.
+    data.f  = z;
+    data.nx = *lx;
+    data.ny = *ny;
 
-    c_plshade( a, *nx, *ny, NULL,
+// Call plfshade to do the actual work - plf2evalr is the
+//   interface that deals with the fortran data organisation.
+
+    plfshade( plf2evalr, &data, NULL, NULL, *nx, *ny,
         *xmin, *xmax, *ymin, *ymax,
         *shade_min, *shade_max,
         *sh_cmap, *sh_color, *sh_width,
         *min_color, *min_width, *max_color, *max_width,
-        c_plfill, rect, pltr, (void *) ftr );
-
-/* Clean up memory allocated for a */
-    plFree2dGrid( a, *nx, *ny );
+        c_plfill, rect, pltr, (PLPointer) ftr );
 }
 
-/*----------------------------------------------------------------------*\
- * plshades front-ends.
- *
- * - plshades0	map indices to xmin, xmax, ymin, ymax
- * - plshades1	linear interpolation from singly dimensioned coord arrays
- * - plshades2	linear interpolation from doubly dimensioned coord arrays
- * - plshades   pass tr information with plplot common block (and
- *              then pass tr as last argument of PLSHADES7)
- \*----------------------------------------------------------------------*/
+//--------------------------------------------------------------------------
+// plshades front-ends.
+//
+// - plshades0	map indices to xmin, xmax, ymin, ymax
+// - plshades1	linear interpolation from singly dimensioned coord arrays
+// - plshades2	linear interpolation from doubly dimensioned coord arrays
+// - plshades   pass tr information with plplot common block (and
+//              then pass tr as last argument of PLSHADES7)
+//--------------------------------------------------------------------------
 
 void
 PLSHADES07( PLFLT *z, PLINT *nx, PLINT *ny, const char *defined,
@@ -434,28 +418,21 @@ PLSHADES07( PLFLT *z, PLINT *nx, PLINT *ny, const char *defined,
             PLFLT *clevel, PLINT *nlevel, PLINT *fill_width,
             PLINT *cont_color, PLINT *cont_width, PLINT *lx )
 {
-    PLINT rect = 1;
-    PLFLT ** a;
-    int   i, j;
+    PLINT    rect = 1;
+    PLfGrid2 data;
 
-/* Create a vectored a array from transpose of the fortran z array. */
-    plAlloc2dGrid( &a, *nx, *ny );
-    for ( i = 0; i < *nx; i++ )
-    {
-        for ( j = 0; j < *ny; j++ )
-        {
-            a[i][j] = z[i + j * *lx];
-        }
-    }
+// Fill a grid data structure to hold the fortran z array.
+    data.f  = (PLFLT **) z;
+    data.nx = *lx;
+    data.ny = *ny;
 
-    c_plshades( a, *nx, *ny, NULL,
+// Call plfshades to do the actual work - plf2ops_col_major() returns a collection
+//   of functions to access the data in fortran style.
+    plfshades( plf2ops_grid_col_major(), &data, *nx, *ny, NULL,
         *xmin, *xmax, *ymin, *ymax,
         clevel, *nlevel, *fill_width,
         *cont_color, *cont_width,
         c_plfill, rect, NULL, NULL );
-
-/* Clean up memory allocated for a */
-    plFree2dGrid( a, *nx, *ny );
 }
 
 void
@@ -465,34 +442,28 @@ PLSHADES17( PLFLT *z, PLINT *nx, PLINT *ny, const char *defined,
             PLINT *cont_color, PLINT *cont_width,
             PLFLT *xg1, PLFLT *yg1, PLINT *lx )
 {
-    PLINT   rect = 1;
-    PLFLT   ** a;
-    int     i, j;
-    PLcGrid cgrid;
+    PLINT    rect = 1;
+    PLfGrid2 data;
+    PLcGrid  cgrid;
 
-/* Create a vectored a array from transpose of the fortran z array. */
-    plAlloc2dGrid( &a, *nx, *ny );
-    for ( i = 0; i < *nx; i++ )
-    {
-        for ( j = 0; j < *ny; j++ )
-        {
-            a[i][j] = z[i + j * *lx];
-        }
-    }
+// Fill a grid data structure to hold the fortran z array.
+    data.f  = (PLFLT **) z;
+    data.nx = *lx;
+    data.ny = *ny;
 
+// Fill a grid data structure to hold the coordinate arrays.
     cgrid.nx = *nx;
     cgrid.ny = *ny;
     cgrid.xg = xg1;
     cgrid.yg = yg1;
 
-    c_plshades( a, *nx, *ny, NULL,
+// Call plfshades to do the actual work - plf2ops_col_major() returns a collection
+//   of functions to access the data in fortran style.
+    plfshades( plf2ops_grid_col_major(), &data, *nx, *ny, NULL,
         *xmin, *xmax, *ymin, *ymax,
         clevel, *nlevel, *fill_width,
         *cont_color, *cont_width,
         c_plfill, rect, pltr1, ( PLPointer ) & cgrid );
-
-/* Clean up memory allocated for a */
-    plFree2dGrid( a, *nx, *ny );
 }
 
 void
@@ -503,36 +474,27 @@ PLSHADES27( PLFLT *z, PLINT *nx, PLINT *ny, const char *defined,
             PLFLT *xg2, PLFLT *yg2, PLINT *lx )
 {
     PLINT    rect = 0;
-    PLFLT    **a;
-    int      i, j;
-    PLcGrid2 cgrid2;
+    PLfGrid2 data;
+    PLcGrid  cgrid;
 
-/* Create a vectored a array from transpose of the fortran z array. */
-    plAlloc2dGrid( &a, *nx, *ny );
-    plAlloc2dGrid( &cgrid2.xg, *nx, *ny );
-    plAlloc2dGrid( &cgrid2.yg, *nx, *ny );
-    cgrid2.nx = *nx;
-    cgrid2.ny = *ny;
-    for ( i = 0; i < *nx; i++ )
-    {
-        for ( j = 0; j < *ny; j++ )
-        {
-            a[i][j]         = z[i + j * *lx];
-            cgrid2.xg[i][j] = xg2[i + j * *lx];
-            cgrid2.yg[i][j] = yg2[i + j * *lx];
-        }
-    }
+// Fill a grid data structure to hold the fortran z array.
+    data.f  = (PLFLT **) z;
+    data.nx = *lx;
+    data.ny = *ny;
 
-    c_plshades( a, *nx, *ny, NULL,
+// Fill a grid data structure to hold the coordinate arrays.
+    cgrid.nx = *lx;
+    cgrid.ny = *ny;
+    cgrid.xg = xg2;
+    cgrid.yg = yg2;
+
+// Call plfshades to do the actual work - plf2ops_col_major() returns a collection
+//   of functions to access the data in fortran style.
+    plfshades( plf2ops_grid_col_major(), &data, *nx, *ny, NULL,
         *xmin, *xmax, *ymin, *ymax,
         clevel, *nlevel, *fill_width,
         *cont_color, *cont_width,
-        c_plfill, rect, pltr2, (void *) &cgrid2 );
-
-/* Clean up allocated memory */
-    plFree2dGrid( a, *nx, *ny );
-    plFree2dGrid( cgrid2.xg, *nx, *ny );
-    plFree2dGrid( cgrid2.yg, *nx, *ny );
+        c_plfill, rect, pltr2f, ( PLPointer ) & cgrid );
 }
 
 void
@@ -541,28 +503,21 @@ PLSHADES7( PLFLT *z, PLINT *nx, PLINT *ny, const char *defined,
            PLFLT *clevel, PLINT *nlevel, PLINT *fill_width,
            PLINT *cont_color, PLINT *cont_width, PLFLT *ftr, PLINT *lx )
 {
-    PLINT rect = 1;
-    PLFLT ** a;
-    int   i, j;
+    PLINT    rect = 1;
+    PLfGrid2 data;
 
-/* Create a vectored a array from transpose of the fortran z array. */
-    plAlloc2dGrid( &a, *nx, *ny );
-    for ( i = 0; i < *nx; i++ )
-    {
-        for ( j = 0; j < *ny; j++ )
-        {
-            a[i][j] = z[i + j * *lx];
-        }
-    }
+// Fill a grid data structure to hold the fortran z array.
+    data.f  = (PLFLT **) z;
+    data.nx = *lx;
+    data.ny = *ny;
 
-    c_plshades( a, *nx, *ny, NULL,
+// Call plfshades to do the actual work - plf2ops_col_major() returns a collection
+//   of functions to access the data in fortran style.
+    plfshades( plf2ops_grid_col_major(), &data, *nx, *ny, NULL,
         *xmin, *xmax, *ymin, *ymax,
         clevel, *nlevel, *fill_width,
         *cont_color, *cont_width,
         c_plfill, rect, pltr, (void *) ftr );
-
-/* Clean up memory allocated for a */
-    plFree2dGrid( a, *nx, *ny );
 }
 
 void
@@ -587,7 +542,7 @@ PLGRIDDATA( PLFLT *x, PLFLT *y, PLFLT *z, PLINT *npts,
         }
     }
 
-/* Clean up memory allocated for a */
+// Clean up memory allocated for a
     plFree2dGrid( a, *nptsx, *nptsy );
 }
 
@@ -610,7 +565,7 @@ PLIMAGEFR07( PLFLT *idata, PLINT *nx, PLINT *ny,
         }
     }
 
-    c_plimagefr( pidata, *nx, *ny,
+    c_plimagefr( (const PLFLT **) pidata, *nx, *ny,
         *xmin, *xmax, *ymin, *ymax, *zmin, *zmax,
         *valuemin, *valuemax, pltr0, NULL );
 
@@ -642,7 +597,7 @@ PLIMAGEFR17( PLFLT *idata, PLINT *nx, PLINT *ny,
         }
     }
 
-    c_plimagefr( pidata, *nx, *ny,
+    c_plimagefr( (const PLFLT **) pidata, *nx, *ny,
         *xmin, *xmax, *ymin, *ymax, *zmin, *zmax,
         *valuemin, *valuemax, pltr1, (void *) &cgrid );
 
@@ -682,7 +637,7 @@ PLIMAGEFR27( PLFLT *idata, PLINT *nx, PLINT *ny,
         }
     }
 
-    c_plimagefr( pidata, *nx, *ny,
+    c_plimagefr( (const PLFLT **) pidata, *nx, *ny,
         *xmin, *xmax, *ymin, *ymax, *zmin, *zmax,
         *valuemin, *valuemax, pltr2, (void *) &cgrid2 );
 
@@ -710,7 +665,7 @@ PLIMAGEFR7( PLFLT *idata, PLINT *nx, PLINT *ny,
         }
     }
 
-    c_plimagefr( pidata, *nx, *ny,
+    c_plimagefr( (const PLFLT **) pidata, *nx, *ny,
         *xmin, *xmax, *ymin, *ymax, *zmin, *zmax,
         *valuemin, *valuemax, pltr, (void *) ftr );
 
