@@ -1,31 +1,31 @@
-/* $Id: scstubs.c 11016 2010-05-21 06:12:23Z airwin $
- *
- *      C stub routines.
- *
- * Copyright (C) 2004  Alan W. Irwin
- *
- * This file is part of PLplot.
- *
- * PLplot is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Library Public License as published
- * by the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * PLplot is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with PLplot; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
- *
- *
- *      The stubs contained here are the ones that are relatively simple,
- *      i.e. involving only a call convention change or integer-to-string
- *      conversion.  Exceptions are plparseopts and  plstripc  which have
- *      a few more complications in them.
- */
+// $Id: scstubs.c 11915 2011-09-07 11:45:29Z andrewross $
+//
+//      C stub routines.
+//
+// Copyright (C) 2004  Alan W. Irwin
+//
+// This file is part of PLplot.
+//
+// PLplot is free software; you can redistribute it and/or modify
+// it under the terms of the GNU Library General Public License as published
+// by the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+//
+// PLplot is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Library General Public License for more details.
+//
+// You should have received a copy of the GNU Library General Public License
+// along with PLplot; if not, write to the Free Software
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+//
+//
+//      The stubs contained here are the ones that are relatively simple,
+//      i.e. involving only a call convention change or integer-to-string
+//      conversion.  Exceptions are plparseopts and  plstripc  which have
+//      a few more complications in them.
+//
 
 #include "plstubs.h"
 
@@ -34,15 +34,18 @@
 #else
 #define STDCALL
 #endif
-static void ( STDCALL *plmapform )( PLINT *, PLFLT *, PLFLT * ); /* Note: slightly different prototype than
-                                                                  * (*mapform)! */
-/* Slightly different to (*label_func) as we don't support PLPointer for
- * additional data in f77.
- * Note the hidden argument! */
+static void ( STDCALL *plmapform )( PLINT *, PLFLT *, PLFLT * ); // Note: slightly different prototype than
+                                                                 // (*mapform)!
+// Slightly different to (*label_func) as we don't support PLPointer for
+// additional data in f77.
+// Note the hidden argument!
 static void ( STDCALL *pllabelfunc )( PLINT *, PLFLT *, char *, PLINT *, PLINT );
-/* Slightly different to C version as we don't support PLPointer  for additional data */
+// Slightly different to C version as we don't support PLPointer  for additional data
 static void ( STDCALL *pltransform )( PLFLT *, PLFLT *, PLFLT *, PLFLT * );
 
+static char **pllegend_text;
+static char **pllegend_symbols;
+
 static void
 pltransformf2c( PLFLT x, PLFLT y, PLFLT *tx, PLFLT *ty, PLPointer data )
 {
@@ -87,9 +90,9 @@ PLADV( PLINT *sub )
 }
 
 void
-PLARC( PLFLT *x, PLFLT *y, PLFLT *a, PLFLT *b, PLFLT *angle1, PLFLT *angle2, PLBOOL *fill )
+PLARC( PLFLT *x, PLFLT *y, PLFLT *a, PLFLT *b, PLFLT *angle1, PLFLT *angle2, PLFLT *rotate, PLBOOL *fill )
 {
-    c_plarc( *x, *y, *a, *b, *angle1, *angle2, *fill );
+    c_plarc( *x, *y, *a, *b, *angle1, *angle2, *rotate, *fill );
 }
 
 void
@@ -164,13 +167,14 @@ PLCOL1( PLFLT *col )
     c_plcol1( *col );
 }
 
-/* The old way, same as plcol0 */
-
-void
-PLCOL( PLINT *icol )
-{
-    c_plcol0( *icol );
-}
+//void
+//PLCOLORBAR( PLINT *position, PLINT *opt, PLFLT *x, PLFLT *y, PLFLT *length, PLFLT *width,
+//            PLINT *cont_color, PLINT *cont_width, PLFLT *ticks, PLINT *sub_ticks,
+//            char *axis_opts, char *label, PLINT *n_colors, PLFLT *colors, PLFLT *values )
+//{
+//    c_plcolorbar( *position, *opt, *x, *y, *length, *width, *cont_color, *cont_width, *ticks, *sub_ticks,
+//        axis_opts, label, *n_colors, colors, values );
+//}
 
 void
 PLCONFIGTIME( PLFLT *scale, PLFLT *offset1, PLFLT *offset2, PLINT *ccontrol, PLBOOL *ifbtime_offset, PLINT *year, PLINT *month, PLINT *day, PLINT *hour, PLINT *min, PLFLT *sec )
@@ -336,9 +340,9 @@ PLGFAM( PLINT *fam, PLINT *num, PLINT *bmax )
     c_plgfam( fam, num, bmax );
 }
 
-/* Note: Fortran does not distinguish between unsigned and signed integers
- * so the 32-bit PLUNICODE can be mapped to 4-byte Fortran integer outside
- * this routine. */
+// Note: Fortran does not distinguish between unsigned and signed integers
+// so the 32-bit PLUNICODE can be mapped to 4-byte Fortran integer outside
+// this routine.
 void
 PLGFCI( PLUNICODE *pfci )
 {
@@ -437,11 +441,13 @@ PLHIST( PLINT *n, PLFLT *data, PLFLT *datmin, PLFLT *datmax,
     c_plhist( *n, data, *datmin, *datmax, *nbin, *oldwin );
 }
 
+#ifdef PL_DEPRECATED
 void
 PLHLS( PLFLT *hue, PLFLT *light, PLFLT *sat )
 {
     c_plhls( *hue, *light, *sat );
 }
+#endif  // PL_DEPRECATED
 
 void
 PLHLSRGB( PLFLT *h, PLFLT *l, PLFLT *s, PLFLT *r, PLFLT *g, PLFLT *b )
@@ -467,7 +473,7 @@ PLIMAGE( PLFLT *idata, PLINT *nx, PLINT *ny,
         }
     }
 
-    c_plimage( pidata, *nx, *ny,
+    c_plimage( (const PLFLT **) pidata, *nx, *ny,
         *xmin, *xmax, *ymin, *ymax, *zmin, *zmax,
         *Dxmin, *Dxmax, *Dymin, *Dymax );
 
@@ -497,18 +503,91 @@ pllabelfuncf2c( PLINT axis, PLFLT value, char *label, PLINT length, PLPointer da
 {
     int i;
 
-    /* (AM) Note the hidden argument "length" - it ensures that the string "label"
-     * is recognised to have that length
-     */
+    // (AM) Note the hidden argument "length" - it ensures that the string "label"
+    // is recognised to have that length
+    //
     ( *pllabelfunc )( &axis, &value, label, &length, length );
 
-    /* Ensure string is null terminated */
+    // Ensure string is null terminated
     i = length - 1;
     while ( ( i >= 0 ) && ( label[i] == ' ' ) )
         i--;
     label[i + 1] = '\0';
 }
 
+// Auxiliary function to create a C-compatible string array
+// Note the hidden argument
+void
+PLLEGEND_CNV_TEXT( PLINT *id, PLINT *number, char *string, PLINT length )
+{
+    int  j;
+    int  i;
+    char **p_string;
+    char *data;
+
+    // Ensure the strings are null terminated
+
+    p_string = (char **) malloc( sizeof ( char * ) * ( *number ) );
+    data     = (char *) malloc( sizeof ( char * ) * ( *number ) * ( length + 1 ) );
+
+    for ( j = 0; j < ( *number ); j++ )
+    {
+        p_string[j] = data + j * ( length + 1 );
+        memcpy( p_string[j], &string[j * length], length );
+        p_string[j][length] = '\0';
+        i = length - 1;
+        while ( ( i >= 0 ) && ( p_string[j][i] == ' ' ) )
+            i--;
+        p_string[j][i + 1] = '\0';
+    }
+
+    if ( *id == 1 )
+    {
+        pllegend_text = p_string;
+    }
+    else
+    {
+        pllegend_symbols = p_string;
+    }
+}
+
+void PLLEGEND(
+    PLFLT *p_legend_width, PLFLT *p_legend_height,
+    PLINT *opt, PLINT *position, PLFLT *x, PLFLT *y, PLFLT *plot_width,
+    PLINT *bg_color, PLINT *bb_color, PLINT *bb_style,
+    PLINT *nrow, PLINT *ncolumn,
+    PLINT *nlegend, const PLINT *opt_array,
+    PLFLT *text_offset, PLFLT *text_scale, PLFLT *text_spacing,
+    PLFLT *text_justification,
+    const PLINT *text_colors,
+    const PLINT *box_colors, const PLINT *box_patterns,
+    const PLFLT *box_scales, const PLINT *box_line_widths,
+    const PLINT *line_colors, const PLINT *line_styles,
+    const PLINT *line_widths,
+    const PLINT *symbol_colors, const PLFLT *symbol_scales,
+    const PLINT *symbol_numbers )
+{
+    c_pllegend( p_legend_width, p_legend_height,
+        *opt, *position, *x, *y, *plot_width,
+        *bg_color, *bb_color, *bb_style,
+        *nrow, *ncolumn,
+        *nlegend, opt_array,
+        *text_offset, *text_scale, *text_spacing,
+        *text_justification,
+        text_colors, (const char **) pllegend_text,
+        box_colors, box_patterns,
+        box_scales, box_line_widths,
+        line_colors, line_styles,
+        line_widths,
+        symbol_colors, symbol_scales,
+        symbol_numbers, (const char **) pllegend_symbols );
+
+    free( *pllegend_text );
+    free( pllegend_text );
+    free( *pllegend_symbols );
+    free( pllegend_symbols );
+}
+
 void
 PLLIGHTSOURCE( PLFLT *x, PLFLT *y, PLFLT *z )
 {
@@ -582,7 +661,7 @@ PLMTEX37( const char *side, PLFLT *disp, PLFLT *pos, PLFLT *just, const char *te
 void
 PLPARSEOPTS7( int *numargs, const char *iargs, PLINT *mode, PLINT *maxindex )
 {
-/* Same as in plparseopts fortran subroutine that calls this one. */
+// Same as in plparseopts fortran subroutine that calls this one.
 #define MAXARGS    20
     if ( *numargs <= MAXARGS )
     {
@@ -591,7 +670,7 @@ PLPARSEOPTS7( int *numargs, const char *iargs, PLINT *mode, PLINT *maxindex )
         for ( i = 0; i < *numargs; i++ )
         {
             argv[i] = iargs + ( i * *maxindex );
-/*	 fprintf(stderr, "%d - %s\n", i, argv[i]); */
+//	 fprintf(stderr, "%d - %s\n", i, argv[i]);
         }
         c_plparseopts( numargs, argv, *mode );
     }
@@ -663,17 +742,21 @@ PLREPLOT( void )
     c_plreplot();
 }
 
+#ifdef PL_DEPRECATED
 void
 PLRGB( PLFLT *red, PLFLT *green, PLFLT *blue )
 {
     c_plrgb( *red, *green, *blue );
 }
+#endif  // PL_DEPRECATED
 
+#ifdef PL_DEPRECATED
 void
 PLRGB1( PLINT *r, PLINT *g, PLINT *b )
 {
     c_plrgb1( *r, *g, *b );
 }
+#endif  // PL_DEPRECATED
 
 void
 PLRGBHLS( PLFLT *r, PLFLT *g, PLFLT *b, PLFLT *h, PLFLT *l, PLFLT *s )
@@ -823,8 +906,8 @@ PLSESC( PLINT *esc )
     c_plsesc( (char) *esc );
 }
 
-/* Auxiliary routine - not to be used publicly
- */
+// Auxiliary routine - not to be used publicly
+//
 #define    PLSETMAPFORMC      FNAME( PLSETMAPFORMC, plsetmapformc )
 #define    PLCLEARMAPFORMC    FNAME( PLCLEARMAPFORMC, plclearmapformc )
 void
@@ -851,9 +934,9 @@ PLSFAM( PLINT *fam, PLINT *num, PLINT *bmax )
     c_plsfam( *fam, *num, *bmax );
 }
 
-/* Note: Fortran does not distinguish between unsigned and signed integers
- * so the 32-bit PLUNICODE can be mapped to 4-byte Fortran integer outside
- * this routine. */
+// Note: Fortran does not distinguish between unsigned and signed integers
+// so the 32-bit PLUNICODE can be mapped to 4-byte Fortran integer outside
+// this routine.
 void
 PLSFCI( PLUNICODE *fci )
 {
@@ -873,10 +956,10 @@ PLSFONT( PLINT *family, PLINT *style, PLINT *weight )
 }
 
 void
-PLSLABELFUNC( void ( STDCALL *labelfunc )( PLINT *, PLFLT *, char *, PLINT * ) )
+PLSLABELFUNC( void ( STDCALL *labelfunc )( PLINT *, PLFLT *, char *, PLINT *, PLINT ) )
 {
     pllabelfunc = labelfunc;
-    /* N.B. neglect pointer to additional data for f77 */
+    // N.B. neglect pointer to additional data for f77
     c_plslabelfunc( pllabelfuncf2c, NULL );
 }
 
@@ -906,6 +989,12 @@ PLSMEM( PLINT *maxx, PLINT *maxy, void *plotmem )
     c_plsmem( *maxx, *maxy, plotmem );
 }
 
+void
+PLSMEMA( PLINT *maxx, PLINT *maxy, void *plotmem )
+{
+    c_plsmema( *maxx, *maxy, plotmem );
+}
+
 void
 PLSMIN( PLFLT *def, PLFLT *scale )
 {
@@ -977,7 +1066,7 @@ void
 PLSTRANSFORM( void ( STDCALL *transformfunc )( PLFLT *, PLFLT *, PLFLT *, PLFLT * ) )
 {
     pltransform = transformfunc;
-    /* N.B. neglect pointer to additional data for f77 */
+    // N.B. neglect pointer to additional data for f77
     c_plstransform( pltransformf2c, NULL );
 }
 
@@ -995,6 +1084,18 @@ PLSTRANSFORM_NONE_( void )
     c_plstransform( NULL, NULL );
 }
 
+void
+PLSTRING7( PLINT *n, PLFLT *x, PLFLT *y, const char *string )
+{
+    c_plstring( *n, x, y, string );
+}
+
+void
+PLSTRING37( PLINT *n, PLFLT *x, PLFLT *y, PLFLT *z, const char *string )
+{
+    c_plstring3( *n, x, y, z, string );
+}
+
 void
 PLSTRIPA( PLINT *id, PLINT *pen, PLFLT *x, PLFLT *y )
 {
