@@ -1,52 +1,52 @@
-/* $Id: plstubs.h 11005 2010-05-18 12:56:14Z andrewross $
- *
- * Maurice LeBrun
- * IFS, University of Texas
- *
- * Header file for plplot Fortran interface stubs.
- * THIS FILE IS NOT FOR INCLUSION BY USER CODES!!
- *
- * The contents of this file are in the public domain.
- */
+// $Id: plstubs.h 11915 2011-09-07 11:45:29Z andrewross $
+//
+// Maurice LeBrun
+// IFS, University of Texas
+//
+// Header file for plplot Fortran interface stubs.
+// THIS FILE IS NOT FOR INCLUSION BY USER CODES!!
+//
+// The contents of this file are in the public domain.
+//
 
 #ifndef __PLSTUBS_H__
 #define __PLSTUBS_H__
 
 #include "plplotP.h"
 
-/*----------------------------------------------------------------------*\
- * Select name transformation based on system type.
- *
- * Define the STUB_LINKAGE flag to get proper C<->Fortran linkage on your
- * system.  This flag describes what the compiler does to Fortran routine
- * names, which we must duplicate on the C stubs so that the Fortran
- * routines may call them.  You can often set STUB_LINKAGE by the
- * construct -DSTUB_LINKAGE=<value> on the C compiler command line, but
- * it is best to either rely on the default or explicitly handle your
- * system below.
- *
- * Current choices for STUB_LINKAGE:
- *
- *      STUB_LAU	lower-case, append underscore
- *      STUB_L		lower-case
- *	STUB_U		upper-case
- *	STUB_FORTRAN	use "fortran" keyword (MS-DOS convention)
- *
- * If no choice is made, the default is set to STUB_LAU.  This should
- * handle most generic Unix boxes not already accounted for.
- *
- * ** Namespace collision **
- *
- * If you use the STUB_L option, the C & Fortran namespaces will collide
- * if the Fortran compiler does lower case folding (they usually do).
- * The problem is then that the stub names and actual function names will
- * be exactly the same, if we insist on the Fortran and C bindings to be
- * similar.  The solution is to give the externally callable C routines
- * unique names, and provide macros to turn the documented entry names in
- * to the real ones.  This is a horrible kludge, but the alternatives are
- * worse.  Fortunately it has no effect on the user program, and you can
- * forget that you ever read about it here.
- \*----------------------------------------------------------------------*/
+//--------------------------------------------------------------------------
+// Select name transformation based on system type.
+//
+// Define the STUB_LINKAGE flag to get proper C<->Fortran linkage on your
+// system.  This flag describes what the compiler does to Fortran routine
+// names, which we must duplicate on the C stubs so that the Fortran
+// routines may call them.  You can often set STUB_LINKAGE by the
+// construct -DSTUB_LINKAGE=<value> on the C compiler command line, but
+// it is best to either rely on the default or explicitly handle your
+// system below.
+//
+// Current choices for STUB_LINKAGE:
+//
+//      STUB_LAU	lower-case, append underscore
+//      STUB_L		lower-case
+//	STUB_U		upper-case
+//	STUB_FORTRAN	use "fortran" keyword (MS-DOS convention)
+//
+// If no choice is made, the default is set to STUB_LAU.  This should
+// handle most generic Unix boxes not already accounted for.
+//
+// ** Namespace collision **
+//
+// If you use the STUB_L option, the C & Fortran namespaces will collide
+// if the Fortran compiler does lower case folding (they usually do).
+// The problem is then that the stub names and actual function names will
+// be exactly the same, if we insist on the Fortran and C bindings to be
+// similar.  The solution is to give the externally callable C routines
+// unique names, and provide macros to turn the documented entry names in
+// to the real ones.  This is a horrible kludge, but the alternatives are
+// worse.  Fortunately it has no effect on the user program, and you can
+// forget that you ever read about it here.
+//--------------------------------------------------------------------------
 
 #define STUB_LAU        1
 #define STUB_L          2
@@ -54,46 +54,47 @@
 #define STUB_FORTRAN    4
 #define STUB_STDCALL    5
 #define STUB_MINGW      6
+#define STUB_IVF        7
 
 #ifndef STUB_LINKAGE
 
-#if defined ( SX )                         /* NEC Super-UX (SX-3) */
+#if defined ( SX )                         // NEC Super-UX (SX-3)
 #define STUB_LINKAGE    STUB_LAU
 #endif
 
-#if defined ( _IBMR2 ) && defined ( _AIX )    /* AIX */
+#if defined ( _IBMR2 ) && defined ( _AIX )    // AIX
 #define STUB_LINKAGE    STUB_L
 #endif
 
-#ifdef __hpux                           /* HP/UX */
+#ifdef __hpux                           // HP/UX
 #define STUB_LINKAGE    STUB_L
 #endif
 
-#ifdef __mips                           /* IRIX (SGI systems) */
+#ifdef __mips                           // IRIX (SGI systems)
 #define STUB_LINKAGE    STUB_LAU
 #endif
 
-#ifdef sun                              /* Suns */
+#ifdef sun                              // Suns
 #define STUB_LINKAGE    STUB_LAU
 #endif
 
-#ifdef CRAY                             /* Cray/UNICOS */
+#ifdef CRAY                             // Cray/UNICOS
 #define STUB_LINKAGE    STUB_U
 #endif
 
-#if defined ( __alpha ) && defined ( __osf__ ) /* DEC Alpha AXP/OSF */
+#if defined ( __alpha ) && defined ( __osf__ ) // DEC Alpha AXP/OSF
 #define STUB_LINKAGE    STUB_LAU
 #endif
 
-#ifdef __GO32__                         /* dos386/djgpp */
+#ifdef __GO32__                         // dos386/djgpp
 #ifdef MSDOS
 #undef MSDOS
 #endif
 #endif
 
-#ifdef WIN32                            /* MS-DOS based */
-#ifdef IVF                              /* Intel Visual Fortran */
-#define STUB_LINKAGE    STUB_U
+#ifdef WIN32                            // MS-DOS based
+#ifdef IVF                              // Intel Visual Fortran
+#define STUB_LINKAGE    STUB_IVF
 #elif defined ( CVF )
 #define STUB_LINKAGE    STUB_U
 #elif defined ( MSDOS )
@@ -103,21 +104,21 @@
 #elif defined ( __GNUC__ )
 #define STUB_LINKAGE    STUB_MINGW
 #endif
-#elif defined ( MSDOS )                    /* MS-DOS based */
+#elif defined ( MSDOS )                    // MS-DOS based
 #define STUB_LINKAGE    STUB_FORTRAN
-#endif /* Windows 32-bit */
+#endif // Windows 32-bit
 
-#ifndef STUB_LINKAGE                    /* The default */
+#ifndef STUB_LINKAGE                    // The default
 #define STUB_LINKAGE    STUB_LAU
 #endif
 
-#endif  /* ifndef STUB_LINKAGE */
+#endif  // ifndef STUB_LINKAGE
 
-/*----------------------------------------------------------------------*\
- * Define name-translation macro.
- * To use, define with x the upper case routine name, y the lower case.
- * Should be adaptable to virtually any system.
- \*----------------------------------------------------------------------*/
+//--------------------------------------------------------------------------
+// Define name-translation macro.
+// To use, define with x the upper case routine name, y the lower case.
+// Should be adaptable to virtually any system.
+//--------------------------------------------------------------------------
 
 #if STUB_LINKAGE == STUB_LAU
 #define FNAME( x, y )     PLDLLIMPEXP_F95C y ## _
@@ -143,23 +144,27 @@
 #define FNAME( x, y )     PLDLLIMPEXP_F95C y ## _
 #define FNAME_( x, y )    y
 
+#elif STUB_LINKAGE == STUB_IVF
+#define FNAME( x, y )     PLDLLIMPEXP_F95C x
+#define FNAME_( x, y )    x
+
 #else
 #error "Illegal setting for STUB_LINKAGE"
 #endif
 
-/*----------------------------------------------------------------------*\
- * Now to actually define the stub names.
- * Each stub must have an entry here.
- \*----------------------------------------------------------------------*/
+//--------------------------------------------------------------------------
+// Now to actually define the stub names.
+// Each stub must have an entry here.
+//--------------------------------------------------------------------------
 
-/* N.B. By default the g77 compiler appends second underscore to name if
- * the original name contains any underscore at all.  According to info
- * g77, "This is done to ensure compatibility with code produced by many
- * UNIX Fortran compilers."  However, other fortran compilers do not have
- * this default naming scheme so to avoid trouble I have #defined two
- * variations of the embedded underscore names, one with and one without
- * the extra trailing underscore.
- */
+// N.B. By default the g77 compiler appends second underscore to name if
+// the original name contains any underscore at all.  According to info
+// g77, "This is done to ensure compatibility with code produced by many
+// UNIX Fortran compilers."  However, other fortran compilers do not have
+// this default naming scheme so to avoid trouble I have #defined two
+// variations of the embedded underscore names, one with and one without
+// the extra trailing underscore.
+//
 
 #define    PL_SETCONTLABELFORMAT     FNAME( PL_SETCONTLABELFORMAT, pl_setcontlabelformat )
 #define    PL_SETCONTLABELFORMATa    FNAME( PL_SETCONTLABELFORMAT_, pl_setcontlabelformat_ )
@@ -178,7 +183,6 @@
 #define    PLCALC_WORLDa             FNAME( PLCALC_WORLD_, plcalc_world_ )
 #define    PLCLEAR                   FNAME( PLCLEAR, plclear )
 #define    PLCLR                     FNAME( PLCLR, plclr )
-#define    PLCOL                     FNAME( PLCOL, plcol )
 #define    PLCOL0                    FNAME( PLCOL0, plcol0 )
 #define    PLCOL1                    FNAME( PLCOL1, plcol1 )
 #define    PLCONFIGTIME              FNAME( PLCONFIGTIME, plconfigtime )
@@ -230,7 +234,6 @@
 #define    PLGYAX                    FNAME( PLGYAX, plgyax )
 #define    PLGZAX                    FNAME( PLGZAX, plgzax )
 #define    PLHIST                    FNAME( PLHISTF77, plhistf77 )
-#define    PLHLS                     FNAME( PLHLS, plhls )
 #define    PLHLSRGB                  FNAME( PLHLSRGB, plhlsrgb )
 #define    PLIMAGE                   FNAME( PLIMAGEF77, plimagef77 )
 #define    PLIMAGEFR07               FNAME( PLIMAGEFR07, plimagefr07 )
@@ -240,6 +243,8 @@
 #define    PLINIT                    FNAME( PLINIT, plinit )
 #define    PLJOIN                    FNAME( PLJOIN, pljoin )
 #define    PLLAB7                    FNAME( PLLAB7, pllab7 )
+#define    PLLEGEND_CNV_TEXT         FNAME( PLLEGEND07_CNV_TEXT, pllegend07_cnv_text )
+#define    PLLEGEND                  FNAME( PLLEGEND07, pllegend07 )
 #define    PLLIGHTSOURCE             FNAME( PLLIGHTSOURCE, pllightsource )
 #define    PLLINE                    FNAME( PLLINEF77, pllinef77 )
 #define    PLLINE3                   FNAME( PLLINE3F77, plline3f77 )
@@ -273,8 +278,6 @@
 #define    PLPTEX37                  FNAME( PLPTEX37, plptex37 )
 #define    PLRANDD                   FNAME( PLRANDDF77, plranddf77 )
 #define    PLREPLOT                  FNAME( PLREPLOT, plreplot )
-#define    PLRGB                     FNAME( PLRGB, plrgb )
-#define    PLRGB1                    FNAME( PLRGB1, plrgb1 )
 #define    PLRGBHLS                  FNAME( PLRGBHLS, plrgbhls )
 #define    PLSCHR                    FNAME( PLSCHR, plschr )
 #define    PLSCMAP0                  FNAME( PLSCMAP0F77, plscmap0f77 )
@@ -322,6 +325,7 @@
 #define    PLSLABELFUNC_NONEa        FNAME( PLSLABELFUNC_NONE_, plslabelfunc_none_ )
 #define    PLSMAJ                    FNAME( PLSMAJ, plsmaj )
 #define    PLSMEM                    FNAME( PLSMEM, plsmem )
+#define    PLSMEMA                   FNAME( PLSMEMA, plsmema )
 #define    PLSMIN                    FNAME( PLSMIN, plsmin )
 #define    PLSORI                    FNAME( PLSORI, plsori )
 #define    PLSPAGE                   FNAME( PLSPAGE, plspage )
@@ -336,6 +340,8 @@
 #define    PLSTRANSFORM1             FNAME( PLSTRANSFORM1, plstransform1 )
 #define    PLSTRANSFORM2             FNAME( PLSTRANSFORM2, plstransform2 )
 #define    PLSTRANSFORM3             FNAME( PLSTRANSFORM3, plstransform3 )
+#define    PLSTRING7                 FNAME( PLSTRING7, plstring7 )
+#define    PLSTRING37                FNAME( PLSTRING37, plstring37 )
 #define    PLSTRIPA                  FNAME( PLSTRIPA, plstripa )
 #define    PLSTRIPC                  FNAME( PLSTRIPCF77, plstripcf77 )
 #define    PLSTRIPD                  FNAME( PLSTRIPD, plstripd )
@@ -362,4 +368,10 @@
 #define    PLWIND                    FNAME( PLWIND, plwind )
 #define    PLXORMOD                  FNAME( PLXORMODF77, plxormodf77 )
 
-#endif  /* __PLSTUBS_H__ */
+#ifdef PL_DEPRECATE
+#define    PLRGB                     FNAME( PLRGB, plrgb )
+#define    PLRGB1                    FNAME( PLRGB1, plrgb1 )
+#define    PLHLS                     FNAME( PLHLS, plhls )
+#endif  // PL_DEPRECATED
+
+#endif  // __PLSTUBS_H__
