@@ -1,5 +1,5 @@
 !***********************************************************************
-!  $Id: sfstubs.f90 11005 2010-05-18 12:56:14Z andrewross $
+!  $Id: sfstubs.f90 11680 2011-03-27 17:57:51Z airwin $
 !  sfstubs.f
 !
 !  Copyright (C) 2004  Alan W. Irwin
@@ -7,7 +7,7 @@
 !  This file is part of PLplot.
 !
 !  PLplot is free software; you can redistribute it and/or modify
-!  it under the terms of the GNU General Library Public License as published
+!  it under the terms of the GNU Library General Public License as published
 !  by the Free Software Foundation; either version 2 of the License, or
 !  (at your option) any later version.
 !
@@ -324,6 +324,46 @@
 
       end subroutine
 
+!***********************************************************************
+
+      subroutine plstring(x,y,string)
+
+      implicit none
+      real(kind=plflt) x(:), y(:)
+      character(len=*) string
+
+      include 'sfstubs.h'
+
+      integer n
+
+      n = size(x)
+
+      call plstrf2c(string, string1, maxlen)
+      s1 = transfer( string1, s1 )
+      call plstring7(n,x,y,s1)
+
+      end subroutine
+
+!***********************************************************************
+
+      subroutine plstring3(x,y,z,string)
+
+      implicit none
+      real(kind=plflt) x(:), y(:), z(:)
+      character(len=*) string
+
+      include 'sfstubs.h'
+
+      integer n
+
+      n = size(x)
+
+      call plstrf2c(string, string1, maxlen)
+      s1 = transfer( string1, s1 )
+      call plstring37(n,x,y,z,s1)
+
+      end subroutine
+
 !***********************************************************************
 
       subroutine plvectors_0(u, v, scale)
