@@ -1,5 +1,5 @@
 !***********************************************************************
-!  $Id: sfstubsf95.f90 11005 2010-05-18 12:56:14Z andrewross $
+!  $Id: sfstubsf95.f90 11915 2011-09-07 11:45:29Z andrewross $
 !  sfstubsf95.f
 !
 !  Copyright (C) 2005, 2006  Arjen Markus
@@ -8,7 +8,7 @@
 !  This file is part of PLplot.
 !
 !  PLplot is free software; you can redistribute it and/or modify
-!  it under the terms of the GNU General Library Public License as published
+!  it under the terms of the GNU Library General Public License as published
 !  by the Free Software Foundation; either version 2 of the License, or
 !  (at your option) any later version.
 !
@@ -137,46 +137,7 @@
       !
 
       implicit none
-
-      !
-      ! Parameters connecting a mnemonic name to the
-      ! constants used by various routines
-      !
-      integer, parameter :: PL_PARSE_FULL = 1
-
-      integer, parameter :: PL_GRID_CSA    = 1
-      integer, parameter :: PL_GRID_DTLI   = 2
-      integer, parameter :: PL_GRID_NNI    = 3
-      integer, parameter :: PL_GRID_NNIDW  = 4
-      integer, parameter :: PL_GRID_NNLI   = 5
-      integer, parameter :: PL_GRID_NNAIDW = 6
-
-      integer, parameter :: PL_JUST_NONE      = -1
-      integer, parameter :: PL_JUST_OPTIMAL   =  0
-      integer, parameter :: PL_JUST_SAME      =  1
-      integer, parameter :: PL_JUST_ISOMETRIC =  2
-
-      integer, parameter :: PL_AXIS_NOTHING    = -2
-      integer, parameter :: PL_AXIS_BOX_ONLY   = -1
-      integer, parameter :: PL_AXIS_NORMAL     =  0
-      integer, parameter :: PL_AXIS_ATZERO     =  1
-      integer, parameter :: PL_AXIS_MAJORGRID  =  2
-      integer, parameter :: PL_AXIS_MINORGRID  =  3
-      integer, parameter :: PL_AXIS_LOGX       = 10
-      integer, parameter :: PL_AXIS_LOGY       = 20
-      integer, parameter :: PL_AXIS_LOGXY      = 30
-
-      integer, parameter :: PL_FONT_STANDARD   =  0
-      integer, parameter :: PL_FONT_EXTENDED   =  1
-
-      real(kind=plflt), parameter :: PL_NOTSET = -42.0_plflt
-
-      !
-      ! TODO:
-      ! Parameters for fill patterns and symbols
-      !
-
-      real(kind=plflt), parameter :: PL_PI = 3.1415926535897932384_plflt
+      include 'plplot_parameters.h'
 
       !
       ! To be added: alternative interfaces
@@ -215,12 +176,6 @@
          end subroutine plcol0
       end interface
 
-      interface
-         subroutine plcol( icol )
-            integer :: icol
-         end subroutine plcol
-      end interface
-
       interface
          subroutine plcol1( col )
             use plplot_flt
@@ -491,6 +446,11 @@
          end subroutine pllightsource
       end interface
 
+      interface pllegend
+         module procedure pllegend_1
+         module procedure pllegend_2
+      end interface
+
       interface plline
          module procedure plline
       end interface
@@ -792,6 +752,7 @@
       end interface
 
       ! plsmem: void * argument tricky - TODO
+      ! plsmema: void * argument tricky - TODO
 
       interface
          subroutine plsmin( def, scale )
@@ -1098,6 +1059,98 @@
                           dxmin, dxmax, dymin, dymax )
       end subroutine plimage
 
+      subroutine pllegend_1( legend_width, legend_height, &
+     &                       opt, position, x, y, &
+     &                       plot_width, bg_color, bb_color, bb_style, &
+     &                       nrow, ncolumn, nlegend, opt_array, &
+     &                       text_offset, text_scale, text_spacing, &
+     &                       text_justification, text_colors, text, &
+     &                       box_colors, box_patterns, box_scales, &
+     &                       box_line_widths, &
+     &                       line_colors, line_styles, line_widths, &
+     &                       symbol_colors, symbol_scales, &
+     &                       symbol_numbers, symbols )
+
+      real(kind=plflt)               :: legend_width, legend_height, plot_width, x, y
+      real(kind=plflt)               :: text_offset, text_scale, text_spacing, text_justification
+      integer                        :: position, opt, bg_color, bb_color, bb_style
+      integer                        :: nrow, ncolumn, nlegend
+
+      character(len=*), dimension(:) :: text, symbols
+
+      integer, dimension(:)          :: opt_array, text_colors, box_colors
+      integer, dimension(:)          :: box_patterns, box_line_widths
+      integer, dimension(:)          :: line_colors, line_styles, line_widths
+      integer, dimension(:)          :: symbol_colors, symbol_numbers
+      real(kind=plflt), dimension(:) :: box_scales, symbol_scales
+
+      !
+      ! Convert the text arrays and store the results in a convenient
+      ! albeit global location. This way we avoid all manner of complications.
+      ! (Though introducing a potentially nasty one: non-threadsafety)
+      !
+      call pllegend07_cnv_text( 1, nlegend, text )
+      call pllegend07_cnv_text( 2, nlegend, symbols )
+
+      call pllegend07( legend_width, legend_height, opt, position, x, y, &
+                       plot_width, bg_color, bb_color, bb_style, &
+                       nrow, ncolumn, nlegend, opt_array, &
+                       text_offset, text_scale, text_spacing, &
+                       text_justification, text_colors, &
+                       box_colors, box_patterns, box_scales, &
+                       box_line_widths, &
+                       line_colors, line_styles, line_widths, &
+                       symbol_colors, symbol_scales, &
+                       symbol_numbers )
+
+      end subroutine pllegend_1
+
+      subroutine pllegend_2( legend_width, legend_height, &
+     &                       opt, position, x, y, &
+     &                       plot_width, bg_color, bb_color, bb_style, &
+     &                       nrow, ncolumn, opt_array, &
+     &                       text_offset, text_scale, text_spacing, &
+     &                       text_justification, text_colors, text, &
+     &                       box_colors, box_patterns, box_scales, &
+     &                       box_line_widths, &
+     &                       line_colors, line_styles, line_widths, &
+     &                       symbol_colors, symbol_scales, &
+     &                       symbol_numbers, symbols )
+
+      real(kind=plflt)               :: legend_width, legend_height, plot_width, x, y
+      real(kind=plflt)               :: text_offset, text_scale, text_spacing, text_justification
+      integer                        :: position, opt, bg_color, bb_color, bb_style
+      integer                        :: nrow, ncolumn
+
+      character(len=*), dimension(:) :: text, symbols
+
+      integer, dimension(:)          :: opt_array, text_colors, box_colors
+      integer, dimension(:)          :: box_patterns, box_line_widths
+      integer, dimension(:)          :: line_colors, line_styles, line_widths
+      integer, dimension(:)          :: symbol_colors, symbol_numbers
+      real(kind=plflt), dimension(:) :: box_scales, symbol_scales
+
+      integer                        :: nlegend
+
+      !
+      ! Determine number of legend entries
+      !
+      nlegend = min( size(opt_array), size(text) )
+
+      call pllegend_1( legend_width, legend_height, &
+                       opt, position, x, y, &
+                       plot_width, bg_color, bb_color, bb_style, &
+                       nrow, ncolumn, nlegend, opt_array, &
+                       text_offset, text_scale, text_spacing, &
+                       text_justification, text_colors, text, &
+                       box_colors, box_patterns, box_scales, &
+                       box_line_widths, &
+                       line_colors, line_styles, line_widths, &
+                       symbol_colors, symbol_scales, &
+                       symbol_numbers, symbols )
+
+      end subroutine pllegend_2
+
       subroutine plline( x, y )
          real(kind=plflt), dimension(:) :: x, y
 
@@ -1110,37 +1163,37 @@
          call plline3f77( size(x), x, y, z )
       end subroutine plline3
 
-      subroutine plmap1(mapform,mapname,minx,maxx,miny,maxy) 
+      subroutine plmap1(mapform,mapname,minx,maxx,miny,maxy)
         use plplot_flt
         implicit none
         real(kind=plflt) minx, maxx, miny, maxy
         character*(*) mapname
         external mapform
-        
+
         include 'sfstubs.h'
-        
+
         call plstrf2c(mapname, string1, maxlen)
-        
+
         call plsetmapformc(mapform)
         s1 = transfer( string1, s1 )
         call plmap7(s1,minx,maxx,miny,maxy)
-        
+
       end subroutine plmap1
-      
+
       subroutine plmap2(mapname,minx,maxx,miny,maxy)
         use plplot_flt
         implicit none
         real(kind=plflt) minx, maxx, miny, maxy
         character*(*) mapname
-        
+
         include 'sfstubs.h'
-        
+
         call plstrf2c(mapname, string1, maxlen)
-        
+
         call plclearmapformc()
         s1 = transfer( string1, s1 )
         call plmap7(s1,minx,maxx,miny,maxy)
-        
+
       end subroutine plmap2
 
       subroutine plmeridians1(mapform,dlong,dlat,minlong,maxlong, &
@@ -1162,7 +1215,6 @@
 
       implicit none
       real(kind=plflt) dlong, dlat, minlong, maxlong, minlat, maxlat
-      external mapform
 
       include 'sfstubs.h'
 
@@ -1185,8 +1237,8 @@
          real(kind=plflt), dimension(:)   :: x, y, clevel
          real(kind=plflt), dimension(:,:) :: z
 
-	 call plmeshcf77( x, y, z, size(x), size(y), opt, &
-	   clevel, size(clevel), size(x))
+         call plmeshcf77( x, y, z, size(x), size(y), opt, &
+           clevel, size(clevel), size(x))
 
       end subroutine plmeshc
 
@@ -1195,10 +1247,10 @@
          logical                          :: side
          real(kind=plflt), dimension(:)   :: x, y
          real(kind=plflt), dimension(:,:) :: z
-	 integer                          :: iside
+         integer                          :: iside
 
          iside = convert_to_int(side)
-	 call plot3df77( x, y, z, size(x), size(y), opt, iside, size(x))
+         call plot3df77( x, y, z, size(x), size(y), opt, iside, size(x))
 
       end subroutine plot3d
 
@@ -1224,7 +1276,7 @@
       subroutine plsurf3d( x, y, z, opt, clevel )
          integer                        :: opt
          real(kind=plflt), dimension(:) :: x, y, clevel
-	 real(kind=plflt), dimension(:,:) :: z
+         real(kind=plflt), dimension(:,:) :: z
 
          call plsurf3df77( x, y, z, size(x), size(y), opt, clevel, &
            size(clevel), size(x))
@@ -1394,8 +1446,8 @@
       subroutine plsvect( arrowx, arrowy, fill )
            logical                        :: fill
            real(kind=plflt), dimension(:) :: arrowx, arrowy
-	   integer ifill
-	 ifill = convert_to_int(fill)
+           integer ifill
+           ifill = convert_to_int(fill)
 
          call plsvectf77( arrowx, arrowy, size(arrowx), ifill )
       end subroutine plsvect
