@@ -1,11 +1,11 @@
-//---------------------------------------------------------------------------//
+//--------------------------------------------------------------------------
 //
 // Copyright (C) 2004  Andrew Ross
 //
 // This file is part of PLplot.
 //
 // PLplot is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Library Public License as published
+// it under the terms of the GNU Library General Public License as published
 // by the Free Software Foundation; either version 2 of the License, or
 // (at your option) any later version.
 //
@@ -131,10 +131,10 @@ public class PLStream implements plplotjavacConstants {
         plplotjavac.pladv( page );
     }
 
-    public void arc( double x, double y, double a, double b, double angle1, double angle2, boolean fill )
+    public void arc( double x, double y, double a, double b, double angle1, double angle2, double rotate, boolean fill )
     {
         if ( set_stream() == -1 ) return;
-        plplotjavac.plarc( x, y, a, b, angle1, angle2, fill );
+        plplotjavac.plarc( x, y, a, b, angle1, angle2, rotate, fill );
     }
 
     public void axes( double x0, double y0, String xopt, double xtick, int nxsub,
@@ -528,6 +528,44 @@ public class PLStream implements plplotjavacConstants {
         plplotjavac.pllab( xlabel, ylabel, tlabel );
     }
 
+    public void legend( double[] p_legend_width, double[] p_legend_height,
+                        int opt, int position, double x, double y, double plot_width,
+                        int bg_color, int bb_color, int bb_style,
+                        int nrow, int ncolumn, int[] opt_array,
+                        double text_offset, double text_scale,
+                        double text_spacing, double text_justification,
+                        int[] text_colors, String[] text,
+                        int[] box_colors, int[] box_patterns,
+                        double[] box_scales, int[] box_line_widths,
+                        int[] line_colors, int[] line_styles,
+                        int[] line_widths,
+                        int[] symbol_colors, double[] symbol_scales,
+                        int[] symbol_numbers, String[] symbols )
+    {
+        if ( set_stream() == -1 ) return;
+        plplotjavac.pllegend( p_legend_width, p_legend_height,
+            opt, position, x, y, plot_width, bg_color, bb_color,
+            bb_style, nrow, ncolumn, opt_array,
+            text_offset, text_scale, text_spacing,
+            text_justification, text_colors, text,
+            box_colors, box_patterns, box_scales,
+            box_line_widths, line_colors, line_styles,
+            line_widths, symbol_colors, symbol_scales,
+            symbol_numbers, symbols );
+    }
+
+    //
+//      public void colorbar( int opt, double x, double y, double length,
+//                            double width, double ticks, double subticks,
+//                            String axis_opts, String label,
+//                            double[] colors, double[] values )
+//      {
+//          if ( set_stream() == -1 ) return;
+//          plplotjavac.plcolorbar( opt, x, y, length, width, ticks, subticks,
+//              axis_opts, label, colors, values );
+//      }
+//
+
     public void lightsource( double x, double y, double z )
     {
         if ( set_stream() == -1 ) return;
@@ -995,6 +1033,18 @@ public class PLStream implements plplotjavacConstants {
         plplotjavac.plstransform( coordTrans, data );
     }
 
+    public void string( double[] x, double[] y, String string )
+    {
+        if ( set_stream() == -1 ) return;
+        plplotjavac.plstring( x, y, string );
+    }
+
+    public void string3( double[] x, double[] y, double[] z, String string )
+    {
+        if ( set_stream() == -1 ) return;
+        plplotjavac.plstring3( x, y, z, string );
+    }
+
     public void stripa( int id, int pen, double x, double y )
     {
         if ( set_stream() == -1 ) return;
