@@ -1,5 +1,5 @@
 (*
-Copyright 2009  Hezekiah M. Carty
+Copyright 2009, 2010, 2011  Hezekiah M. Carty
 
 This file is part of PLplot.
 
@@ -137,23 +137,6 @@ module Plot :
                                                 length of one segment and gap
                                                 in the line drawing pattern. *)
 
-    (** Point/symbol styles *)
-    type symbol_t =
-      | Point_symbol
-      | Box_symbol
-      | Dot_symbol
-      | Plus_symbol
-      | Circle_symbol
-      | X_symbol
-      | Solar_symbol
-      | Diamond_symbol
-      | Open_star_symbol
-      | Big_dot_symbol
-      | Star_symbol
-      | Open_dot_symbol
-      | Index_symbol of int (** The index value here is the same value used in
-                                {!plssym}. *)
-
     (** The default list of axis rendering options, used for all plots generated
         with {!init} if no custom options are provided. *)
     val default_axis_options : axis_options_t list
@@ -262,10 +245,11 @@ module Plot :
 
     (** {4 Plot elements} *)
 
-    (** [arc ?fill color x y a b angle0 angle1] *)
+    (** [arc ?fill color x y a b angle0 angle1 rotate] *)
     val arc :
       ?fill:bool ->
-      color_t -> float -> float -> float -> float -> float -> float -> plot_t
+      color_t -> float -> float -> float -> float -> float -> float -> float ->
+      plot_t
 
     (** [axes ?color ?style ?width xopt yopt] *)
     val axes :
@@ -282,29 +266,6 @@ module Plot :
     (** [circle ?fill color x y r] *)
     val circle : ?fill:bool -> color_t -> float -> float -> float -> plot_t
 
-    (** [image_colorbar ?label ?log ?pos ?width (min, max)] add a
-        color bar to a plot using the current color scale.  This function
-        should be called after the rest of the plot is complete. *)
-    val image_colorbar :
-      ?custom_axis:axis_options_t list ->
-      ?label:string plot_side_t ->
-      ?log:bool ->
-      ?pos:float plot_side_t ->
-      ?width:float ->
-      float * float -> plot_t
-
-    (** [shade_colorbar ?label ?log ?pos ?width contours] add a shaded
-        color bar to a plot using the current color scale.  This is similar to
-        {!image_colorbar} but takes [contours] as rather than a range.  This
-        function should be called after the rest of the plot is complete. *)
-    val shade_colorbar :
-      ?custom_axis:axis_options_t list ->
-      ?label:string plot_side_t ->
-      ?log:bool ->
-      ?pos:float plot_side_t ->
-      ?width:float ->
-      float array -> plot_t
-
     (** [contours color tranform_func contours data] *)
     val contours :
       color_t -> pltr_t -> float array -> float array array -> plot_t
@@ -343,7 +304,7 @@ module Plot :
     (** [points ?label ?symbol ?scale color xs ys] *)
     val points :
       ?label:string ->
-      ?symbol:symbol_t ->
+      ?symbol:string ->
       ?scale:float ->
       color_t -> float array -> float array -> plot_t
 
@@ -384,7 +345,7 @@ module Plot :
         [x = min] to [x = max].  [step] can be used to tighten or coarsen the
         sampling of plot points. *)
     val func :
-      ?symbol:symbol_t ->
+      ?symbol:string ->
       ?step:float ->
       color_t -> (float -> float) -> float * float -> plot_t
 
@@ -413,6 +374,10 @@ module Plot :
         rendered. *)
     val list : plot_t list -> plot_t
 
+    (** [maybe m_p] will plot the contents of [m_p].  If [m_p] is [None] then
+        this is effectively a no-op. *)
+    val maybe : plot_t option -> plot_t
+
     (** Plot a list of plottable elements *)
     val plot : ?stream:stream_t -> plot_t list -> unit
 
@@ -421,22 +386,98 @@ module Plot :
     (** Character height in world coordinate units *)
     val character_height : ?stream:stream_t -> unit -> float
 
-    (** Draw a legend, given a list of titles and colors *)
-    val draw_legend :
-      ?stream:stream_t ->
-      ?line_length:float ->
-      ?x:float -> ?y:float -> string list -> color_t list -> unit
+    (** Positioning within viewport or subpage *)
+    type position_t
 
-    (** [colorbar_labeler ?log ?min ?max axis n] can be used as a custom
-        axis labeling function when a colorbar is meant to represent values
-        beyond those which are represented.  So if the colorbar labeling shows
-        values from 0.0 to 1.0, but the color for 1.0 is meant to represent
-        values > 1.0 then set [max_value] 1.0. *)
-    val colorbar_labeler :
-      ?log:bool ->
-      ?min:float ->
-      ?max:float ->
-      plplot_axis_type -> float -> string
+    (** Position relative to the plot viewport *)
+    val viewport_pos :
+      ?side1:unit plot_side_t ->
+      ?side2:unit plot_side_t -> ?inside:bool -> float -> float -> position_t
+
+    (** Position relative to the plot subpage *)
+    val subpage_pos :
+      ?side1:unit plot_side_t ->
+      ?side2:unit plot_side_t -> ?inside:bool -> float -> float -> position_t
+
+    (** Legend entry *)
+    type legend_entry_t
+
+    (** Layout of elements *)
+    type 'a layout_t
+
+    (** Empty legend entry *)
+    val no_legend : legend_entry_t
+
+    (** Color-filled box legend entry *)
+    val box_legend :
+      ?pattern:int ->
+      ?scale:float ->
+      ?line_width:int ->
+      ?label_color:color_t -> label:string -> color_t -> legend_entry_t
+
+    (** Line legend entry *)
+    val line_legend :
+      ?style:int ->
+      ?width:int ->
+      ?label_color:color_t -> label:string -> color_t -> legend_entry_t
+
+    (** Symbol/point legend entry *)
+    val symbol_legend :
+      ?scale:float ->
+      ?number:int ->
+      ?label_color:color_t ->
+      label:string -> color_t -> string -> legend_entry_t
+
+    (** Row-major layout *)
+    val row_major : 'a -> 'b -> ('a * 'b) layout_t
+
+    (** Column-major layout *)
+    val column_major : 'a -> 'b -> ('a * 'b) layout_t
+
+    (** [legend entries] *)
+    val legend :
+      ?pos:position_t ->
+      ?plot_width:float ->
+      ?bg:color_t ->
+      ?bb:color_t * line_style_t ->
+      ?layout:(int * int) layout_t ->
+      ?color:color_t ->
+      ?text_offset:float ->
+      ?text_scale:float ->
+      ?text_spacing:float ->
+      ?text_justification:float ->
+      ?text_left:bool -> legend_entry_t list list -> plot_t
+
+    (** Available colorbar kinds *)
+    type colorbar_kind_t
+
+    (** [gradient_colorbar [|min; max|]] from [min] to [max] *)
+    val gradient_colorbar : float array -> colorbar_kind_t
+
+    (** [image_colorbar [|min; max|]] from [min] to [max] *)
+    val image_colorbar : float array -> colorbar_kind_t
+
+    (** [shade_colorbar ?custom contours] defines a shaded contour colorbar
+        with axis labels at even spacings ([custom = false]) or at the
+        locations of the values in [contours]
+        ([custom = true] - the default). *)
+    val shade_colorbar : ?custom:bool -> float array -> colorbar_kind_t
+
+    (** Default options used for a colorbar axis *)
+    val default_colorbar_axis : axis_options_t list
+
+    (** [colorbar colorbar_kind] *)
+    val colorbar :
+      ?pos:position_t ->
+      ?bg:color_t ->
+      ?bb:color_t * line_style_t ->
+      ?cap:float option * float option ->
+      ?contour:color_t * int ->
+      ?orient:(float * float) plot_side_t ->
+      ?axis:axis_options_t list ->
+      ?label:string plot_side_t ->
+      ?color:color_t -> ?scale:float ->
+      colorbar_kind_t -> plot_t
 
     (** Draw the plot axes on the current plot page *)
     val plot_axes :
@@ -466,6 +507,7 @@ module Quick_plot :
       ?size:int * int ->
       ?device:Plot.plot_device_t ->
       ?labels:string * string * string ->
+      ?names:string list ->
       ?log:bool * bool -> (float array * float array) list -> unit
 
     (** [lines xs ys] plots the line segments described by the coordinates
@@ -496,7 +538,7 @@ module Quick_plot :
       ?device:Plot.plot_device_t ->
       ?labels:string * string * string ->
       ?names:string list ->
-      ?symbol:Plot.symbol_t ->
+      ?symbol:string ->
       ?step:float -> (float -> float) list -> float * float -> unit
 
     (** [shades ?log ?contours m] plots a filled contour/shaded [m] with a
@@ -549,13 +591,73 @@ and plplot_run_level_enum =
   | PL_VIEWPORT_DEFINED
   | PL_WORLD_COORDINATES_DEFINED
 and plplot_run_level = plplot_run_level_enum
+and plplot_position_enum =
+    PL_POSITION_LEFT
+  | PL_POSITION_RIGHT
+  | PL_POSITION_TOP
+  | PL_POSITION_BOTTOM
+  | PL_POSITION_INSIDE
+  | PL_POSITION_OUTSIDE
+  | PL_POSITION_VIEWPORT
+  | PL_POSITION_SUBPAGE
+and plplot_position_opt = plplot_position_enum list
+and plplot_legend_enum =
+    PL_LEGEND_NONE
+  | PL_LEGEND_COLOR_BOX
+  | PL_LEGEND_LINE
+  | PL_LEGEND_SYMBOL
+  | PL_LEGEND_TEXT_LEFT
+  | PL_LEGEND_BACKGROUND
+  | PL_LEGEND_BOUNDING_BOX
+  | PL_LEGEND_ROW_MAJOR
+and plplot_legend_opt = plplot_legend_enum list
+and plplot_colorbar_enum =
+  | PL_COLORBAR_LABEL_LEFT
+  | PL_COLORBAR_LABEL_RIGHT
+  | PL_COLORBAR_LABEL_TOP
+  | PL_COLORBAR_LABEL_BOTTOM
+  | PL_COLORBAR_IMAGE
+  | PL_COLORBAR_SHADE
+  | PL_COLORBAR_GRADIENT
+  | PL_COLORBAR_CAP_NONE
+  | PL_COLORBAR_CAP_LOW
+  | PL_COLORBAR_CAP_HIGH
+  | PL_COLORBAR_SHADE_LABEL
+  | PL_COLORBAR_ORIENT_RIGHT
+  | PL_COLORBAR_ORIENT_TOP
+  | PL_COLORBAR_ORIENT_LEFT
+  | PL_COLORBAR_ORIENT_BOTTOM
+  | PL_COLORBAR_BACKGROUND
+  | PL_COLORBAR_BOUNDING_BOX
+and plplot_colorbar_opt = plplot_colorbar_enum list
+and plplot_fci_family_enum =
+  | PL_FCI_FAMILY_UNCHANGED
+  | PL_FCI_SANS
+  | PL_FCI_SERIF
+  | PL_FCI_MONO
+  | PL_FCI_SCRIPT
+  | PL_FCI_SYMBOL
+and plplot_fci_style_enum =
+  | PL_FCI_STYLE_UNCHANGED
+  | PL_FCI_UPRIGHT
+  | PL_FCI_ITALIC
+  | PL_FCI_OBLIQUE
+and plplot_fci_weight_enum =
+  | PL_FCI_WEIGHT_UNCHANGED
+  | PL_FCI_MEDIUM
+  | PL_FCI_BOLD
+and plplot_draw_mode_enum =
+  | PL_DRAWMODE_UNKNOWN
+  | PL_DRAWMODE_DEFAULT
+  | PL_DRAWMODE_REPLACE
+  | PL_DRAWMODE_XOR
 external pl_setcontlabelformat : int -> int -> unit
   = "camlidl_plplot_core_c_pl_setcontlabelformat"
 external pl_setcontlabelparam : float -> float -> float -> int -> unit
   = "camlidl_plplot_core_c_pl_setcontlabelparam"
 external pladv : int -> unit = "camlidl_plplot_core_c_pladv"
 external plarc :
-  float -> float -> float -> float -> float -> float -> bool -> unit
+  float -> float -> float -> float -> float -> float -> float -> bool -> unit
   = "camlidl_plplot_core_c_plarc_bytecode" "camlidl_plplot_core_c_plarc"
 external plaxes :
   float -> float -> string -> float -> int -> string -> float -> int -> unit
@@ -609,6 +711,8 @@ external plflush : unit -> unit = "camlidl_plplot_core_c_plflush"
 external plfont : int -> unit = "camlidl_plplot_core_c_plfont"
 external plfontld : int -> unit = "camlidl_plplot_core_c_plfontld"
 external plgchr : unit -> float * float = "camlidl_plplot_core_c_plgchr"
+external plgcmap1_range : unit -> float * float =
+  "camlidl_plplot_core_c_plgcmap1_range"
 external plgcol0 : int -> int * int * int = "camlidl_plplot_core_c_plgcol0"
 external plgcol0a : int -> int * int * int * float
   = "camlidl_plplot_core_c_plgcol0a"
@@ -624,6 +728,8 @@ external plgdidev : unit -> float * float * float * float
 external plgdiori : unit -> float = "camlidl_plplot_core_c_plgdiori"
 external plgdiplt : unit -> float * float * float * float
   = "camlidl_plplot_core_c_plgdiplt"
+external plgdrawmode : unit -> plplot_draw_mode_enum
+  = "camlidl_plplot_core_c_plgdrawmode"
 external plgfci : unit -> int64 = "camlidl_plplot_core_c_plgfci"
 external plgfam : unit -> int * int * int = "camlidl_plplot_core_c_plgfam"
 external plgfnam : unit -> string = "camlidl_plplot_core_c_plgfnam"
@@ -655,6 +761,17 @@ external pljoin : float -> float -> float -> float -> unit
   = "camlidl_plplot_core_c_pljoin"
 external pllab : string -> string -> string -> unit
   = "camlidl_plplot_core_c_pllab"
+external plcolorbar : plplot_colorbar_opt -> plplot_position_opt -> float ->
+  float -> float -> float -> int -> int -> int -> float -> float -> int ->
+  int -> float -> int -> string -> string -> float array -> float * float
+  = "camlidl_plplot_core_c_plcolorbar_bytecode" "camlidl_plplot_core_c_plcolorbar"
+external pllegend : plplot_legend_opt -> plplot_position_opt ->
+  float -> float -> float -> int -> int -> int -> int -> int ->
+  plplot_legend_opt array -> float -> float ->
+  float -> float -> int array -> string array -> int array -> int array ->
+  float array -> int array -> int array -> int array -> int array ->
+  int array -> float array -> int array -> string array -> float * float
+  = "ml_pllegend_byte" "ml_pllegend"
 external pllightsource : float -> float -> float -> unit
   = "camlidl_plplot_core_c_pllightsource"
 external plline : float array -> float array -> unit
@@ -731,6 +848,8 @@ external plscmap1la :
   = "camlidl_plplot_core_c_plscmap1la_bytecode"
   "camlidl_plplot_core_c_plscmap1la"
 external plscmap1n : int -> unit = "camlidl_plplot_core_c_plscmap1n"
+external plscmap1_range : float -> float -> unit =
+  "camlidl_plplot_core_c_plscmap1_range"
 external plscol0 : int -> int -> int -> int -> unit
   = "camlidl_plplot_core_c_plscol0"
 external plscol0a : int -> int -> int -> int -> float -> unit
@@ -758,10 +877,13 @@ external plsesc : char -> unit = "camlidl_plplot_core_c_plsesc"
 external plsfam : int -> int -> int -> unit = "camlidl_plplot_core_c_plsfam"
 external plsfci : int64 -> unit = "camlidl_plplot_core_c_plsfci"
 external plsfnam : string -> unit = "camlidl_plplot_core_c_plsfnam"
-external plsfont : int -> int -> int -> unit
+external plsfont : plplot_fci_family_enum -> plplot_fci_style_enum ->
+  plplot_fci_weight_enum -> unit
   = "camlidl_plplot_core_c_plsfont"
 external plsmaj : float -> float -> unit = "camlidl_plplot_core_c_plsmaj"
 external plsmin : float -> float -> unit = "camlidl_plplot_core_c_plsmin"
+external plsdrawmode : plplot_draw_mode_enum -> unit
+  = "camlidl_plplot_core_c_plsdrawmode"
 external plsori : int -> unit = "camlidl_plplot_core_c_plsori"
 external plspage : float -> float -> int -> int -> int -> int -> unit
   = "camlidl_plplot_core_c_plspage_bytecode" "camlidl_plplot_core_c_plspage"
@@ -774,6 +896,10 @@ external plssym : float -> float -> unit = "camlidl_plplot_core_c_plssym"
 external plstar : int -> int -> unit = "camlidl_plplot_core_c_plstar"
 external plstart : string -> int -> int -> unit
   = "camlidl_plplot_core_c_plstart"
+external plstring : float array -> float array -> string -> unit
+  = "camlidl_plplot_core_c_plstring"
+external plstring3 : float array -> float array -> float array -> string -> unit
+  = "camlidl_plplot_core_c_plstring3"
 external plstripa : int -> int -> float -> float -> unit
   = "camlidl_plplot_core_c_plstripa"
 external plstripd : int -> unit = "camlidl_plplot_core_c_plstripd"
