@@ -1,23 +1,23 @@
-/*
- * Copyright 2007, 2008, 2009  Hezekiah M. Carty
- *
- * This file is part of PLplot.
- *
- * PLplot is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation, either version 2 of the License, or
- * (at your option) any later version.
- *
- * PLplot is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with PLplot.  If not, see <http://www.gnu.org/licenses/>.
- */
+//
+// Copyright 2007, 2008, 2009, 2010, 2011  Hezekiah M. Carty
+//
+// This file is part of PLplot.
+//
+// PLplot is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 2 of the License, or
+// (at your option) any later version.
+//
+// PLplot is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with PLplot.  If not, see <http://www.gnu.org/licenses/>.
+//
 
-/* The "usual" OCaml includes */
+// The "usual" OCaml includes
 #include <caml/alloc.h>
 #include <caml/callback.h>
 #include <caml/fail.h>
@@ -46,12 +46,13 @@ typedef void ( *ML_PLOTTER_FUNC )( PLFLT, PLFLT, PLFLT*, PLFLT*, PLPointer );
 typedef PLINT ( *ML_DEFINED_FUNC )( PLFLT, PLFLT );
 typedef void ( *ML_MAPFORM_FUNC )( PLINT, PLFLT*, PLFLT* );
 typedef void ( *ML_LABEL_FUNC )( PLINT, PLFLT, char*, PLINT, PLPointer );
+typedef PLINT ( *ML_VARIANT_FUNC )( PLINT );
 
-/*
- *
- * CALLBACK WRAPPERS
- *
- */
+//
+//
+// CALLBACK WRAPPERS
+//
+//
 
 // A simple routine to wrap a properly registered OCaml callback in a form
 // usable by PLPlot routines.  If an appropriate callback is not registered
@@ -362,20 +363,20 @@ value ml_plstransform( value unit )
     CAMLreturn( Val_unit );
 }
 
-/*
- *
- * CONTOURING, SHADING and IMAGE FUNCTIONS
- *
- */
+//
+//
+// CONTOURING, SHADING and IMAGE FUNCTIONS
+//
+//
 
-/*
- * void
- * c_plcont(PLFLT **f, PLINT nx, PLINT ny, PLINT kx, PLINT lx,
- * PLINT ky, PLINT ly, PLFLT *clevel, PLINT nlevel,
- * void (*pltr) (PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer),
- * PLPointer pltr_data);
- */
-void ml_plcont( PLFLT **f, PLINT nx, PLINT ny,
+//
+// void
+// c_plcont(PLFLT **f, PLINT nx, PLINT ny, PLINT kx, PLINT lx,
+// PLINT ky, PLINT ly, PLFLT *clevel, PLINT nlevel,
+// void (*pltr) (PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer),
+// PLPointer pltr_data);
+//
+void ml_plcont( const PLFLT **f, PLINT nx, PLINT ny,
                 PLINT kx, PLINT lx, PLINT ky, PLINT ly,
                 PLFLT *clevel, PLINT nlevel )
 {
@@ -390,23 +391,23 @@ void ml_plcont( PLFLT **f, PLINT nx, PLINT ny,
     else
     {
         c_plcont( f, nx, ny, kx, lx, ky, ly, clevel, nlevel,
-            get_ml_plotter_func(), (void*) 1 );
+            get_ml_plotter_func(), (void *) 1 );
     }
 }
 
-/*
- * void
- * c_plshade(PLFLT **a, PLINT nx, PLINT ny, PLINT (*defined) (PLFLT, PLFLT),
- * PLFLT left, PLFLT right, PLFLT bottom, PLFLT top,
- * PLFLT shade_min, PLFLT shade_max,
- * PLINT sh_cmap, PLFLT sh_color, PLINT sh_width,
- * PLINT min_color, PLINT min_width,
- * PLINT max_color, PLINT max_width,
- * void (*fill) (PLINT, PLFLT *, PLFLT *), PLBOOL rectangular,
- * void (*pltr) (PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer),
- * PLPointer pltr_data);
- */
-void ml_plshade( PLFLT **a, PLINT nx, PLINT ny,
+//
+// void
+// c_plshade(PLFLT **a, PLINT nx, PLINT ny, PLINT (*defined) (PLFLT, PLFLT),
+// PLFLT left, PLFLT right, PLFLT bottom, PLFLT top,
+// PLFLT shade_min, PLFLT shade_max,
+// PLINT sh_cmap, PLFLT sh_color, PLINT sh_width,
+// PLINT min_color, PLINT min_width,
+// PLINT max_color, PLINT max_width,
+// void (*fill) (PLINT, PLFLT *, PLFLT *), PLBOOL rectangular,
+// void (*pltr) (PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer),
+// PLPointer pltr_data);
+//
+void ml_plshade( const PLFLT **a, PLINT nx, PLINT ny,
                  PLFLT left, PLFLT right, PLFLT bottom, PLFLT top,
                  PLFLT shade_min, PLFLT shade_max,
                  PLINT sh_cmap, PLFLT sh_color, PLINT sh_width,
@@ -420,33 +421,33 @@ void ml_plshade( PLFLT **a, PLINT nx, PLINT ny,
         shade_min, shade_max,
         sh_cmap, sh_color, sh_width, min_color, min_width,
         max_color, max_width, plfill, rectangular,
-        get_ml_plotter_func(), (void*) 1 );
+        get_ml_plotter_func(), (void *) 1 );
 }
 
-/*
- * void
- * c_plshade1(PLFLT *a, PLINT nx, PLINT ny, PLINT (*defined) (PLFLT, PLFLT),
- * PLFLT left, PLFLT right, PLFLT bottom, PLFLT top,
- * PLFLT shade_min, PLFLT shade_max,
- * PLINT sh_cmap, PLFLT sh_color, PLINT sh_width,
- * PLINT min_color, PLINT min_width,
- * PLINT max_color, PLINT max_width,
- * void (*fill) (PLINT, PLFLT *, PLFLT *), PLBOOL rectangular,
- * void (*pltr) (PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer),
- * PLPointer pltr_data);
- */
+//
+// void
+// c_plshade1(PLFLT *a, PLINT nx, PLINT ny, PLINT (*defined) (PLFLT, PLFLT),
+// PLFLT left, PLFLT right, PLFLT bottom, PLFLT top,
+// PLFLT shade_min, PLFLT shade_max,
+// PLINT sh_cmap, PLFLT sh_color, PLINT sh_width,
+// PLINT min_color, PLINT min_width,
+// PLINT max_color, PLINT max_width,
+// void (*fill) (PLINT, PLFLT *, PLFLT *), PLBOOL rectangular,
+// void (*pltr) (PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer),
+// PLPointer pltr_data);
+//
 
-/*
- * void
- * c_plshades( PLFLT **a, PLINT nx, PLINT ny, PLINT (*defined) (PLFLT, PLFLT),
- * PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax,
- * PLFLT *clevel, PLINT nlevel, PLINT fill_width,
- * PLINT cont_color, PLINT cont_width,
- * void (*fill) (PLINT, PLFLT *, PLFLT *), PLBOOL rectangular,
- * void (*pltr) (PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer),
- * PLPointer pltr_data);
- */
-void ml_plshades( PLFLT **a, PLINT nx, PLINT ny,
+//
+// void
+// c_plshades( PLFLT **a, PLINT nx, PLINT ny, PLINT (*defined) (PLFLT, PLFLT),
+// PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax,
+// PLFLT *clevel, PLINT nlevel, PLINT fill_width,
+// PLINT cont_color, PLINT cont_width,
+// void (*fill) (PLINT, PLFLT *, PLFLT *), PLBOOL rectangular,
+// void (*pltr) (PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer),
+// PLPointer pltr_data);
+//
+void ml_plshades( const PLFLT **a, PLINT nx, PLINT ny,
                   PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax,
                   PLFLT *clevel, PLINT nlevel, PLINT fill_width,
                   PLINT cont_color, PLINT cont_width,
@@ -459,18 +460,18 @@ void ml_plshades( PLFLT **a, PLINT nx, PLINT ny,
         cont_color, cont_width,
         plfill, rectangular,
         get_ml_plotter_func(),
-        (void*) 1 );
+        (void *) 1 );
 }
 
-/*
- * void
- * c_plimagefr(PLFLT **idata, PLINT nx, PLINT ny,
- *      PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax, PLFLT zmin, PLFLT zmax,
- *      PLFLT valuemin, PLFLT valuemax,
- *      void (*pltr) (PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer),
- *      PLPointer pltr_data);
- */
-void ml_plimagefr( PLFLT **idata, PLINT nx, PLINT ny,
+//
+// void
+// c_plimagefr(PLFLT **idata, PLINT nx, PLINT ny,
+//      PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax, PLFLT zmin, PLFLT zmax,
+//      PLFLT valuemin, PLFLT valuemax,
+//      void (*pltr) (PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer),
+//      PLPointer pltr_data);
+//
+void ml_plimagefr( const PLFLT **idata, PLINT nx, PLINT ny,
                    PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax,
                    PLFLT zmin, PLFLT zmax,
                    PLFLT valuemin, PLFLT valuemax )
@@ -480,27 +481,27 @@ void ml_plimagefr( PLFLT **idata, PLINT nx, PLINT ny,
         zmin, zmax,
         valuemin, valuemax,
         get_ml_plotter_func(),
-        (void*) 1 );
+        (void *) 1 );
 }
 
-/*
- * void
- * c_plvect(PLFLT **u, PLFLT **v, PLINT nx, PLINT ny, PLFLT scale,
- * void (*pltr) (PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer),
- *      PLPointer pltr_data);
- */
-void ml_plvect( PLFLT **u, PLFLT **v, PLINT nx, PLINT ny, PLFLT scale )
+//
+// void
+// c_plvect(PLFLT **u, PLFLT **v, PLINT nx, PLINT ny, PLFLT scale,
+// void (*pltr) (PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer),
+//      PLPointer pltr_data);
+//
+void ml_plvect( const PLFLT **u, const PLFLT **v, PLINT nx, PLINT ny, PLFLT scale )
 {
     c_plvect( u, v, nx, ny, scale,
         get_ml_plotter_func(),
-        (void*) 1 );
+        (void *) 1 );
 }
 
-/*
- * void
- * c_plmap( void (*mapform)(PLINT, PLFLT *, PLFLT *), const char *type,
- *       PLFLT minlong, PLFLT maxlong, PLFLT minlat, PLFLT maxlat );
- */
+//
+// void
+// c_plmap( void (*mapform)(PLINT, PLFLT *, PLFLT *), const char *type,
+//       PLFLT minlong, PLFLT maxlong, PLFLT minlat, PLFLT maxlat );
+//
 void ml_plmap( const char *type,
                PLFLT minlong, PLFLT maxlong, PLFLT minlat, PLFLT maxlat )
 {
@@ -508,12 +509,12 @@ void ml_plmap( const char *type,
         type, minlong, maxlong, minlat, maxlat );
 }
 
-/*
- * void
- * c_plmeridians( void (*mapform)(PLINT, PLFLT *, PLFLT *),
- *             PLFLT dlong, PLFLT dlat,
- *             PLFLT minlong, PLFLT maxlong, PLFLT minlat, PLFLT maxlat );
- */
+//
+// void
+// c_plmeridians( void (*mapform)(PLINT, PLFLT *, PLFLT *),
+//             PLFLT dlong, PLFLT dlat,
+//             PLFLT minlong, PLFLT maxlong, PLFLT minlat, PLFLT maxlat );
+//
 void ml_plmeridians( PLFLT dlong, PLFLT dlat,
                      PLFLT minlong, PLFLT maxlong, PLFLT minlat, PLFLT maxlat )
 {
@@ -521,12 +522,12 @@ void ml_plmeridians( PLFLT dlong, PLFLT dlat,
         dlong, dlat, minlong, maxlong, minlat, maxlat );
 }
 
-/*
- * void
- * c_plgriddata(PLFLT *x, PLFLT *y, PLFLT *z, PLINT npts,
- *  PLFLT *xg, PLINT nptsx, PLFLT *yg, PLINT nptsy,
- *  PLFLT **zg, PLINT type, PLFLT data);
- */
+//
+// void
+// c_plgriddata(PLFLT *x, PLFLT *y, PLFLT *z, PLINT npts,
+//  PLFLT *xg, PLINT nptsx, PLFLT *yg, PLINT nptsy,
+//  PLFLT **zg, PLINT type, PLFLT data);
+//
 // This one is currently wrapped by hand, as I am not sure how to get camlidl
 // to allocate zg in a way that makes plgriddata happy and doesn't require the
 // user to pre-allocate the space.
@@ -565,8 +566,8 @@ value ml_plgriddata( value x, value y, value z,
 
     // Using "type + 1" because "type" is passed in as a variant type, so
     // the indexing starts from 0 rather than 1.
-    c_plgriddata( (double*) x, (double*) y, (double*) z, npts, (double*) xg, nptsx,
-        (double*) yg, nptsy, zg_local, Int_val( type ) + 1,
+    c_plgriddata( (double *) x, (double *) y, (double *) z, npts, (double *) xg, nptsx,
+        (double *) yg, nptsy, zg_local, Int_val( type ) + 1,
         Double_val( data ) );
 
     // Allocate the X-dimension of the to-be-returned OCaml array
@@ -595,10 +596,10 @@ value ml_plgriddata_bytecode( value* argv, int argn )
         argv[5], argv[6] );
 }
 
-/*
- * void
- * c_plpoly3(PLINT n, PLFLT *x, PLFLT *y, PLFLT *z, PLBOOL *draw, PLBOOL ifcc);
- */
+//
+// void
+// c_plpoly3(PLINT n, PLFLT *x, PLFLT *y, PLFLT *z, PLBOOL *draw, PLBOOL ifcc);
+//
 // plpoly3 is wrapped by hand because draw has a length of (n - 1) and camlidl
 // does not have a way to indicate this automatically.
 void ml_plpoly3( PLINT n, PLFLT *x, PLFLT *y, PLFLT *z, PLINT ndraw, PLBOOL *draw, PLBOOL ifcc )
@@ -606,7 +607,7 @@ void ml_plpoly3( PLINT n, PLFLT *x, PLFLT *y, PLFLT *z, PLINT ndraw, PLBOOL *dra
     plpoly3( n, x, y, z, draw, ifcc );
 }
 
-/* Raise Invalid_argument if the given value is <> 0 */
+// Raise Invalid_argument if the given value is <> 0
 void plplot_check_nonzero_result( int result )
 {
     if ( result != 0 )
@@ -618,8 +619,8 @@ void plplot_check_nonzero_result( int result )
     return;
 }
 
-/* Translate the integer version of the OCaml variant to the appropriate
- * PLplot constant. */
+// Translate the integer version of the OCaml variant to the appropriate
+// PLplot constant.
 int translate_parse_option( int parse_option )
 {
     int translated_option;
@@ -639,31 +640,50 @@ int translate_parse_option( int parse_option )
     return translated_option;
 }
 
+// Copy a string array
+#define INIT_STRING_ARRAY( o )         \
+    int o ## _length;                  \
+    o ## _length = Wosize_val( o );    \
+    const char *c_ ## o[o ## _length]; \
+    for ( i = 0; i < o ## _length; i++ ) { c_ ## o[i] = String_val( Field( o, i ) ); }
+
+// Copy an int array, o, of n element to the C array c
+#define INIT_INT_ARRAY( o )         \
+    int o ## _length;               \
+    o ## _length = Wosize_val( o ); \
+    int c_ ## o[o ## _length];      \
+    for ( i = 0; i < ( o ## _length ); i++ ) { ( c_ ## o )[i] = Int_val( Field( ( o ), i ) ); }
+
+int lor_ml_list( value list, ML_VARIANT_FUNC variant_f )
+{
+    CAMLparam1( list );
+    int result;
+
+    result = 0;
+    while ( list != Val_emptylist )
+    {
+        // Accumulate the elements of the list
+        result = result | variant_f( Int_val( Field( list, 0 ) ) );
+        // Point to the tail of the list for the next loop
+        list = Field( list, 1 );
+    }
+
+    CAMLreturn( result );
+}
+
 value ml_plparseopts( value argv, value parse_method )
 {
     CAMLparam2( argv, parse_method );
     int i;
     int result;
-    int argv_length;
     int combined_parse_method;
-    argv_length = Wosize_val( argv );
     // Make a copy of the command line argument strings
-    const char* argv_copy[argv_length];
-    for ( i = 0; i < argv_length; i++ )
-    {
-        argv_copy[i] = String_val( Field( argv, i ) );
-    }
+    INIT_STRING_ARRAY( argv )
+
     // OR the elements of the parse_method list together
-    combined_parse_method = 0;
-    while ( parse_method != Val_emptylist )
-    {
-        combined_parse_method =
-            combined_parse_method |
-            translate_parse_option( Int_val( Field( parse_method, 0 ) ) );
-        // Point to the tail of the list for the next loop
-        parse_method = Field( parse_method, 1 );
-    }
-    result = plparseopts( &argv_length, argv_copy, combined_parse_method );
+    combined_parse_method = lor_ml_list( parse_method, translate_parse_option );
+
+    result = plparseopts( &argv_length, c_argv, combined_parse_method );
     if ( result != 0 )
     {
         char exception_message[MAX_EXCEPTION_MESSAGE_LENGTH];
@@ -715,7 +735,136 @@ value ml_plstripc_byte( value* argv, int argn )
         argv[15], argv[16], argv[17], argv[18] );
 }
 
-/* pltr* function implementations */
+int translate_legend_option( int legend_option )
+{
+    int translated_option;
+    switch ( legend_option )
+    {
+    case 0: translated_option  = PL_LEGEND_NONE; break;
+    case 1: translated_option  = PL_LEGEND_COLOR_BOX; break;
+    case 2: translated_option  = PL_LEGEND_LINE; break;
+    case 3: translated_option  = PL_LEGEND_SYMBOL; break;
+    case 4: translated_option  = PL_LEGEND_TEXT_LEFT; break;
+    case 5: translated_option  = PL_LEGEND_BACKGROUND; break;
+    case 6: translated_option  = PL_LEGEND_BOUNDING_BOX; break;
+    case 7: translated_option  = PL_LEGEND_ROW_MAJOR; break;
+    default: translated_option = -1;
+    }
+    return translated_option;
+}
+
+int translate_position_option( int position_option )
+{
+    int translated_option;
+    switch ( position_option )
+    {
+    case 0: translated_option  = PL_POSITION_LEFT; break;
+    case 1: translated_option  = PL_POSITION_RIGHT; break;
+    case 2: translated_option  = PL_POSITION_TOP; break;
+    case 3: translated_option  = PL_POSITION_BOTTOM; break;
+    case 4: translated_option  = PL_POSITION_INSIDE; break;
+    case 5: translated_option  = PL_POSITION_OUTSIDE; break;
+    case 6: translated_option  = PL_POSITION_VIEWPORT; break;
+    case 7: translated_option  = PL_POSITION_SUBPAGE; break;
+    default: translated_option = -1;
+    }
+    return translated_option;
+}
+
+value ml_pllegend( value opt, value position, value x, value y, value plot_width,
+                   value bg_color,
+                   value bb_color, value bb_style,
+                   value nrow, value ncolumn,
+                   value opt_array,
+                   value text_offset, value text_scale, value text_spacing,
+                   value text_justification, value text_colors, value text,
+                   value box_colors, value box_patterns, value box_scales,
+                   value box_line_widths,
+                   value line_colors, value line_styles, value line_widths,
+                   value symbol_colors, value symbol_scales,
+                   value symbol_numbers, value symbols )
+{
+    CAMLparam5( position, opt, x, y, plot_width );
+    CAMLxparam5( bg_color, bb_color, bb_style, nrow, ncolumn );
+    CAMLxparam5( opt_array, text_offset, text_scale, text_spacing, text_justification );
+    CAMLxparam5( text_colors, text, box_colors, box_patterns, box_scales );
+    CAMLxparam5( box_line_widths, line_colors, line_styles, line_widths, symbol_colors );
+    CAMLxparam3( symbol_scales, symbol_numbers, symbols );
+    CAMLlocal1( result );
+    result = caml_alloc( 2, 0 );
+
+    // Counter
+    int i;
+    // General legend options
+    int c_position, c_opt;
+    // Number of legend entries
+    int n_legend;
+    n_legend = Wosize_val( opt_array );
+    // Options for each legend entry
+    int c_opt_array[n_legend];
+
+    // Assume that the dimensions all line up on the OCaml side, so we don't
+    // need to do any further dimension checks.
+
+    // Define and initialize all of the C arrays to pass in to pllegend
+    INIT_STRING_ARRAY( text )
+    INIT_INT_ARRAY( text_colors )
+    INIT_INT_ARRAY( box_colors )
+    INIT_INT_ARRAY( box_patterns )
+    INIT_INT_ARRAY( box_line_widths )
+    INIT_INT_ARRAY( line_colors )
+    INIT_INT_ARRAY( line_styles )
+    INIT_INT_ARRAY( line_widths )
+    INIT_INT_ARRAY( symbol_colors )
+    INIT_INT_ARRAY( symbol_numbers )
+    INIT_STRING_ARRAY( symbols )
+
+    // Translate the legend configuration options
+    c_opt      = lor_ml_list( opt, translate_legend_option );
+    c_position = lor_ml_list( position, translate_position_option );
+
+    for ( i = 0; i < n_legend; i++ )
+    {
+        c_opt_array[i] =
+            lor_ml_list( Field( opt_array, i ), translate_legend_option );
+    }
+
+    // The returned width and height of the legend
+    PLFLT width, height;
+
+    pllegend( &width, &height, c_opt, c_position, Double_val( x ), Double_val( y ),
+        Double_val( plot_width ), Int_val( bg_color ),
+        Int_val( bb_color ), Int_val( bb_style ),
+        Int_val( nrow ), Int_val( ncolumn ),
+        n_legend, c_opt_array,
+        Double_val( text_offset ), Double_val( text_scale ),
+        Double_val( text_spacing ),
+        Double_val( text_justification ),
+        c_text_colors, c_text,
+        c_box_colors, c_box_patterns, (double *) box_scales,
+        c_box_line_widths,
+        c_line_colors, c_line_styles, c_line_widths,
+        c_symbol_colors, (double *) symbol_scales, c_symbol_numbers,
+        c_symbols );
+
+    // Return a tuple with the legend's size
+    Store_field( result, 0, caml_copy_double( width ) );
+    Store_field( result, 1, caml_copy_double( height ) );
+
+    CAMLreturn( result );
+}
+
+value ml_pllegend_byte( value* argv, int argn )
+{
+    return ml_pllegend( argv[0], argv[1], argv[2], argv[3], argv[4],
+        argv[5], argv[6], argv[7], argv[8], argv[9],
+        argv[10], argv[11], argv[12], argv[13], argv[14],
+        argv[15], argv[16], argv[17], argv[18], argv[19],
+        argv[20], argv[21], argv[22], argv[23], argv[24],
+        argv[25], argv[26], argv[27] );
+}
+
+// pltr* function implementations
 void ml_pltr0( double x, double y, double* tx, double* ty )
 {
     pltr0( x, y, tx, ty, NULL );
@@ -729,8 +878,8 @@ value ml_pltr1( value xg, value yg, value x, value y )
     double  tx;
     double  ty;
     PLcGrid grid;
-    grid.xg = (double*) xg;
-    grid.yg = (double*) yg;
+    grid.xg = (double *) xg;
+    grid.yg = (double *) yg;
     grid.nx = Wosize_val( xg ) / Double_wosize;
     grid.ny = Wosize_val( yg ) / Double_wosize;
     pltr1( Double_val( x ), Double_val( y ), &tx, &ty, ( PLPointer ) & grid );
@@ -755,8 +904,8 @@ value ml_pltr2( value xg, value yg, value x, value y )
     double   tx;
     double   ty;
 
-    /* TODO: As of now, you will probably get a segfault of the xg and yg
-     * dimensions don't match up properly. */
+    // TODO: As of now, you will probably get a segfault of the xg and yg
+    // dimensions don't match up properly.
     // Build the grid.
     // Length of "outer" array
     length1 = Wosize_val( xg );
@@ -765,12 +914,12 @@ value ml_pltr2( value xg, value yg, value x, value y )
     c_xg    = malloc( length1 * sizeof ( double* ) );
     for ( i = 0; i < length1; i++ )
     {
-        c_xg[i] = (double*) Field( xg, i );
+        c_xg[i] = (double *) Field( xg, i );
     }
     c_yg = malloc( length1 * sizeof ( double* ) );
     for ( i = 0; i < length1; i++ )
     {
-        c_yg[i] = (double*) Field( yg, i );
+        c_yg[i] = (double *) Field( yg, i );
     }
     grid.xg = c_xg;
     grid.yg = c_yg;
@@ -789,34 +938,34 @@ value ml_pltr2( value xg, value yg, value x, value y )
     CAMLreturn( tx_ty );
 }
 
-/* XXX Non-core functions follow XXX */
-/**
- * The following functions are here for (my?) convenience.  As far as I can
- * tell, they are not defined in the core PLplot library.
- */
+// XXX Non-core functions follow XXX
+//*
+// The following functions are here for (my?) convenience.  As far as I can
+// tell, they are not defined in the core PLplot library.
+//
 
-/* Get the current color map 0 color index */
+// Get the current color map 0 color index
 int plg_current_col0( void )
 {
     return plsc->icol0;
 }
 
-/* Get the current color map 1 color index */
+// Get the current color map 1 color index
 float plg_current_col1( void )
 {
     return plsc->icol1;
 }
 
-/* Get the current pen width. TODO: Remove this, as I think this information
- * can be retrieved from another proper PLplot function. */
+// Get the current pen width. TODO: Remove this, as I think this information
+// can be retrieved from another proper PLplot function.
 int plgwid( void )
 {
     return plsc->width;
 }
 
-/* Get the current character (text) height in mm.  TODO: Remove this, as I
- * think this information can be retrieved from another proper PLplot
- * function */
+// Get the current character (text) height in mm.  TODO: Remove this, as I
+// think this information can be retrieved from another proper PLplot
+// function
 float plgchrht( void )
 {
     return plsc->chrht;
