@@ -34,17 +34,10 @@ function out = __pl_matstr(mat, str, n)
 	out(nn,:) = "";
       endif
     endif
-    if (exist("warn_fortran_indexing"))
-      old_dofi = warn_fortran_indexing;
-      warn_fortran_indexing = 0;
-      out(toascii (out) == 0) = " ";
-      warn_fortran_indexing = old_dofi;
-    else
-      old_dofi = warning("query","Octave:fortran-indexing");
-      warning("off","Octave:fortran-indexing");
-      out(toascii (out) == 0) = " ";
-      warning(old_dofi.state,"Octave:fortran-indexing");
-    endif
+    old_dofi = warning("query","Octave:fortran-indexing");
+    warning("off","Octave:fortran-indexing");
+    out(toascii (out) == 0) = " ";
+    warning(old_dofi.state,"Octave:fortran-indexing");
 
   else
     help __pl_matstr
