@@ -10,14 +10,19 @@
 # Copyright (c) 1997 Gary R. Holt.  This is distributed under the terms of the 
 # perl artistic license (http://language.perl.com/misc/Artistic.html).
 #
-# Modifications 2007 Andrew Ross 
-# This version contains three local fixes for plplot
+# Modifications 2007,2008 Andrew Ross 
+# This version contains four local fixes for plplot
 # 1) Change _dim function to allow a zero length array (required by plstyl)
 # 2) Alter string to std::string for compatibility with gcc3.2 and later
 # 3) Add octave version checking - the syntax of print_usage has changed
 #    from v2.1 to v2.9. This requires a file octave_version.pl which defines
 #    the variable octave_version.
+# 4) Add in GCC visibility pragma to ensure symbols are dispatch function 
+#    symbols are always visible, even when -fvisibility=hidden is used.
 #
+# Modifications 2008 Rafael Laboissiere
+# Change 3) above is adapted for Octave v3.0
+
 
 package octave;			# Everything should be in this package.
 
@@ -92,6 +97,13 @@ sub error_dimension {
 sub finish {
   print OUTFILE qq[
 
+// The following section needs to be default visibility. The DEFUN_DLD macro 
+// defines several functions so we can't easily individually tag them, and so
+// we resort to using the GGC pragma instead. What happens on Windows?
+#if defined(__GNUC__) && __GNUC__ > 3
+#pragma GCC visibility push(default)
+#endif
+
 //
 // The main dispatch function.  This function calls the appropriate wrapper
 // based on the value of the first argument.
@@ -113,6 +125,10 @@ DEFUN_DLD($octave_output_file, args, nargout, "See $stub_file for documentation"
   }
 }
 
+#if defined(__GNUC__) && __GNUC__ > 3
+#pragma GCC visibility pop
+#endif
+
 ";
 
   close(OUTFILE);		# Done with this file.
@@ -158,7 +174,7 @@ sub function_start {
 				# Permissible not to specify output args
 				# if there is only one.
   @ver = split(/\./,$octave_version);
-  if ($ver[0] >= 2 && $ver[1] >= 9) {
+  if ($ver[0] >= 3 || ($ver[0] >= 2 && $ver[1] >= 9)) {
     $retstr .= (")\n" .
 	      "  {\n" .
 	      "    print_usage();\n" . # Give an error.
@@ -663,6 +679,7 @@ sub put_val_ptr {
 #
 $typemap_get_scalar{'double'} = $typemap_get_scalar{'float'} = 
   $typemap_get_scalar{'int'} = $typemap_get_scalar{'unsigned'} = 
+  $typemap_get_scalar{'long'} = $typemap_get_scalar{'unsigned long'} = 
   $typemap_get_scalar{'short'} = $typemap_get_scalar{'unsigned short'} = sub {
     my ($arg) = @_;		# Name the arguments.
     "  $arg->{c_var_name} = ($arg->{basic_type})$arg->{oct_expr}.double_value();\n";
@@ -721,6 +738,7 @@ $typemap_get_ptr{'double'} =	# For double precision, if the input array is
 
 $typemap_get_ptr{'float'} =	# Floats and ints require a temporary array.
   $typemap_get_ptr{'int'} = $typemap_get_ptr{'unsigned'} =
+  $typemap_get_ptr{'long'} = $typemap_get_ptr{'unsigned long'} =
   $typemap_get_ptr{'short'} = $typemap_get_ptr{'unsigned short'} = sub {
     my ($arg, $argname, $argtype) = @_;	# Name the arguments.
     my $retstr =
@@ -834,6 +852,8 @@ $typemap_output_array_make{'double'} = sub {
 $typemap_output_array_make{'float'} = # These types require an intermediate
   $typemap_output_array_make{'int'} = # temporary vector.
   $typemap_output_array_make{'unsigned'} = 
+  $typemap_output_array_make{'long '} = 
+  $typemap_output_array_make{'unsigned long'} = 
   $typemap_output_array_make{'short'} =
   $typemap_output_array_make{'unsigned short'} = sub {
     my ($arg, $argname, @dims) = @_; # Name the arguments.
@@ -897,6 +917,8 @@ $typemap_output_scalar_make{'double'} =
   $typemap_output_scalar_make{'float'} =
   $typemap_output_scalar_make{'unsigned'} =
   $typemap_output_scalar_make{'int'} =
+  $typemap_output_scalar_make{'long'} =
+  $typemap_output_scalar_make{'unsigned long'} =
   $typemap_output_scalar_make{'short'} =
   $typemap_output_scalar_make{'unsigned short'} =
   $typemap_output_scalar_make{'char *'} =
@@ -927,7 +949,8 @@ $typemap_put_scalar{'double'} =
 
 $typemap_put_scalar{'float'} =
   $typemap_put_scalar{'int'} = $typemap_put_scalar{'unsigned'} =
-  $typemap_put_scalar{'short'} = $typemap_put_scalar{'short'} = sub {
+  $typemap_put_scalar{'long'} = $typemap_put_scalar{'unsigned long'} =
+  $typemap_put_scalar{'short'} = $typemap_put_scalar{'unsigned short'} = sub {
     my ($arg) = @_;	# Name the arguments.
 
     "  $arg->{oct_expr_out} = octave_value((double)$arg->{c_var_name});\n";
@@ -964,6 +987,7 @@ $typemap_put_ptr{'double'} =
 
 $typemap_put_ptr{'float'} =
   $typemap_put_ptr{'int'} = $typemap_put_ptr{'unsigned'} =
+  $typemap_put_ptr{'long'} = $typemap_put_ptr{'unsigned long'} =
   $typemap_put_ptr{'short'} = $typemap_put_ptr{'unsigned short'} = sub {
     my ($arg) = @_;		# Name the arguments.
     ("  if (_arraylen($arg->{oct_expr_out}) == 1)\n" . # Is this a scalar?
@@ -1082,6 +1106,8 @@ _cvt_double_to(FLOAT *out_arr, double *in_arr, unsigned n_el)
 
 template void _cvt_double_to(int *, double *, unsigned);
 template void _cvt_double_to(unsigned *, double *, unsigned);
+template void _cvt_double_to(long *, double *, unsigned);
+template void _cvt_double_to(unsigned long *, double *, unsigned);
 template void _cvt_double_to(short *, double *, unsigned);
 template void _cvt_double_to(unsigned short *, double *, unsigned);
 template void _cvt_double_to(float *, double *, unsigned);
@@ -1104,6 +1130,8 @@ _cvt_to_double(FLOAT *arr, double *d_arr, unsigned n_el)
 
 template void _cvt_to_double(int *, double *, unsigned);
 template void _cvt_to_double(unsigned *, double *, unsigned);
+template void _cvt_to_double(long *, double *, unsigned);
+template void _cvt_to_double(unsigned long *, double *, unsigned);
 template void _cvt_to_double(short *, double *, unsigned);
 template void _cvt_to_double(unsigned short *, double *, unsigned);
 template void _cvt_to_double(float *, double *, unsigned);
