@@ -1,35 +1,26 @@
-/*
- *
- * This software is provided under the LGPL in March 2009 by the
- * Cluster Science Centre
- * QSAS team,
- * Imperial College, London
- *
- * Copyright (C) 2009  Imperial College, London
- * Copyright (C) 2009  Alan W. Irwin
- *
- * This is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Lesser Public License as published
- * by the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This software is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License for more details.
- *
- * To received a copy of the GNU Library General Public License
- * write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
- *
- * History:
- *
- *
- * March 2009:  v1.00
- * Initial release.
- *
- */
-
+// This software was donated under the LGPL to the PLplot project in
+// March 2009 by the
+// Cluster Science Centre
+// QSAS team,
+// Imperial College, London
+//
+// Copyright (C) 2009  Imperial College, London
+// Copyright (C) 2009-2011  Alan W. Irwin
+//
+// This is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Lesser Public License as published
+// by the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+//
+// This software is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// To received a copy of the GNU Library General Public License
+// write to the Free Software Foundation, Inc.,
+// 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+//
 
 #include "qt.h"
 
@@ -90,9 +81,38 @@ void QtPLDriver::setPLStream( PLStream *p )
     pls = p;
 }
 
+void QtPLDriver::drawArc( short x, short y, short a, short b, PLFLT angle1, PLFLT angle2, PLFLT rotate, bool fill )
+{
+    if ( !m_painterP->isActive() )
+        return;
+    QRectF rect( (PLFLT) ( x - a ) * downscale,
+                 m_dHeight - (PLFLT) ( y + b ) * downscale,
+                 (PLFLT) a * downscale * 2,
+                 (PLFLT) b * downscale * 2
+                 );
+    if ( rotate != 0.0 )
+    {
+        m_painterP->save();
+        m_painterP->translate( (PLFLT) x * downscale, m_dHeight - (PLFLT) y * downscale );
+        m_painterP->rotate( -rotate );
+        m_painterP->translate( -(PLFLT) x * downscale, -m_dHeight + (PLFLT) y * downscale );
+    }
+
+    if ( fill )
+        m_painterP->drawPie( rect, (int) ( angle1 * 16 ), (int) ( ( angle2 - angle1 ) * 16 ) );
+    else
+        m_painterP->drawArc( rect, (int) ( angle1 * 16 ), (int) ( ( angle2 - angle1 ) * 16 ) );
+
+    if ( rotate != 0.0 )
+    {
+        m_painterP->restore();
+    }
+}
+
 void QtPLDriver::drawLine( short x1, short y1, short x2, short y2 )
 {
-    if ( !m_painterP->isActive() ) return;
+    if ( !m_painterP->isActive() )
+        return;
     QLineF line( (PLFLT) x1 * downscale,
                  m_dHeight - (PLFLT) y1 * downscale,
                  (PLFLT) x2 * downscale,
@@ -104,7 +124,8 @@ void QtPLDriver::drawLine( short x1, short y1, short x2, short y2 )
 
 void QtPLDriver::drawPolyline( short * x, short * y, PLINT npts )
 {
-    if ( !m_painterP->isActive() ) return;
+    if ( !m_painterP->isActive() )
+        return;
     QPointF * polyline = new QPointF[npts];
     for ( int i = 0; i < npts; ++i )
     {
@@ -117,14 +138,18 @@ void QtPLDriver::drawPolyline( short * x, short * y, PLINT npts )
 
 void QtPLDriver::drawPolygon( short * x, short * y, PLINT npts )
 {
-    if ( !m_painterP->isActive() ) return;
+    if ( !m_painterP->isActive() )
+        return;
     QPointF * polygon = new QPointF[npts];
     for ( int i = 0; i < npts; ++i )
     {
         polygon[i].setX( (PLFLT) x[i] * downscale );
         polygon[i].setY( m_dHeight - (PLFLT) y[i] * downscale );
     }
-    m_painterP->drawPolygon( polygon, npts );
+    if ( plsc->dev_eofill )
+        m_painterP->drawPolygon( polygon, npts, Qt::OddEvenFill );
+    else
+        m_painterP->drawPolygon( polygon, npts, Qt::WindingFill );
     delete[] polygon;
 }
 
@@ -156,9 +181,12 @@ QFont QtPLDriver::getFont( PLUNICODE unicode )
     }
     f.setFamily( "" ); // no family name, forcing Qt to find an appropriate font by itself
 
-    if ( fontStyle ) f.setItalic( true );
-    if ( fontWeight ) f.setWeight( QFont::Bold );
-    else f.setWeight( QFont::Normal );
+    if ( fontStyle )
+        f.setItalic( true );
+    if ( fontWeight )
+        f.setWeight( QFont::Bold );
+    else
+        f.setWeight( QFont::Normal );
 
     f.setUnderline( underlined );
     f.setOverline( overlined );
@@ -202,22 +230,30 @@ void QtPLDriver::drawTextInPicture( QPainter* p, const QString& text )
     xOffset += bounding.width();
 }
 
+// 0.8 mimics the offset of first superscript/subscript level implemented
+// in plstr (plsym.c) for Hershey fonts.  Indeed when comparing with
+// -dev xwin results this factor appears to offset the centers of the
+// letters appropriately (but not their edges since different font sizes
+// are involved).
+# define RISE_FACTOR    0.8
+
 QPicture QtPLDriver::getTextPicture( PLUNICODE fci, PLUNICODE* text, int len, PLFLT chrht )
 {
     char plplotEsc;
     plgesc( &plplotEsc );
 
-    double   old_fontScale;
-
     QPicture res;
     QPainter p( &res );
 
     QString  currentString;
+    PLFLT    old_sscale, sscale, old_soffset, soffset;
+    PLINT    level    = 0;
+    PLFLT    dyOffset = 0.;
 
     yOffset = 0.;
     xOffset = 0.;
 
-    // Scaling factor of 1.6 determined empirically to make all qt results
+    // Scaling factor of 1.45 determined empirically to make all qt results
     // have the same character size as cairo results (taking into account
     // the slightly different actual glyph sizes for the different
     // default fonts found by cairo and qt).
@@ -242,38 +278,42 @@ QPicture QtPLDriver::getTextPicture( PLUNICODE fci, PLUNICODE* text, int len, PL
             ++i; // Now analyse the escaped character
             switch ( text[i] )
             {
-            case 'd':
+            case 'd': //subscript
                 drawTextInPicture( &p, currentString );
                 currentString.clear();
-                old_fontScale = currentFontScale;
-                if ( yOffset > 0.000000000001 )    // I've already encountered precision issues here, so changed 0 into epsilon
-                {
-                    currentFontScale *= 1.25;      /* Subscript scaling parameter */
-                }
-                else
-                {
-                    currentFontScale *= 0.8;      /* Subscript scaling parameter */
-                }
+                plP_script_scale( FALSE, &level,
+                    &old_sscale, &sscale, &old_soffset, &soffset );
+                currentFontScale = sscale;
 
-                yOffset -= currentFontSize * old_fontScale / 2.;
+                // The correction for the difference in magnitude
+                // between the baseline and middle coordinate systems
+                // for subscripts should be
+                // -0.5*(fontSize - superscript/subscript fontSize).
+                // dyOffset = -0.5 * currentFontSize * ( 1.0 - sscale );
+                // But empirically this change in offset should not be applied
+                // so leave it at its initial value of zero.
+                yOffset = -( currentFontSize * RISE_FACTOR * soffset + dyOffset );
 
                 p.setFont( getFont( fci ) );
                 break;
 
-            case 'u':
+            case 'u':  //superscript
                 drawTextInPicture( &p, currentString );
 
                 currentString.clear();
-                if ( yOffset < -0.000000000001 )
-                {
-                    currentFontScale *= 1.25;      /* Subscript scaling parameter */
-                }
-                else
-                {
-                    currentFontScale *= 0.8;      /* Subscript scaling parameter */
-                }
+                plP_script_scale( TRUE, &level,
+                    &old_sscale, &sscale, &old_soffset, &soffset );
+                currentFontScale = sscale;
+
+                // The correction for the difference in magnitude
+                // between the baseline and middle coordinate systems
+                // for superscripts should be
+                // 0.5*(fontSize - superscript/subscript fontSize).
+                // dyOffset = 0.5 * currentFontSize * ( 1.0 - sscale );
+                // But empirically this change in offset should not be applied
+                // so leave it at its initial value of zero.
+                yOffset = currentFontSize * RISE_FACTOR * soffset + dyOffset;
 
-                yOffset += currentFontSize * currentFontScale / 2.;
                 p.setFont( getFont( fci ) );
                 break;
 
@@ -295,7 +335,7 @@ QPicture QtPLDriver::getTextPicture( PLUNICODE fci, PLUNICODE* text, int len, PL
 
 
             case '#':
-                currentString.append( QString( (QChar*) &( text[i] ), 1 ) );
+                currentString.append( QString( (QChar *) &( text[i] ), 1 ) );
                 break;
 
             default:
@@ -316,21 +356,23 @@ QPicture QtPLDriver::getTextPicture( PLUNICODE fci, PLUNICODE* text, int len, PL
     drawTextInPicture( &p, currentString );
 
     p.end();
+
     return res;
 }
 
 void QtPLDriver::drawText( EscText* txt )
 {
-    if ( !m_painterP->isActive() ) return;
+    if ( !m_painterP->isActive() )
+        return;
 
-    /* Check that we got unicode, warning message and return if not */
+    // Check that we got unicode, warning message and return if not
     if ( txt->unicode_array_len == 0 )
     {
         printf( "Non unicode string passed to a Qt driver, ignoring\n" );
         return;
     }
 
-    /* Check that unicode string isn't longer then the max we allow */
+    // Check that unicode string isn't longer then the max we allow
     if ( txt->unicode_array_len >= 500 )
     {
         printf( "Sorry, the Qt drivers only handle strings of length < %d\n", 500 );
@@ -346,6 +388,12 @@ void QtPLDriver::drawText( EscText* txt )
     QPicture  picText = getTextPicture( fci, txt->unicode_array, txt->unicode_array_len, pls->chrht );
     picDpi = picText.logicalDpiY();
 
+    if ( pls->get_string_length )
+    {
+        pls->string_length = ( (PLFLT) xOffset / picDpi ) * 25.4;
+        return;
+    }
+
     m_painterP->setClipping( true );
     m_painterP->setClipRect( QRect( (int) ( pls->clpxmi * downscale ), (int) ( m_dHeight - pls->clpyma * downscale ), (int) ( ( pls->clpxma - pls->clpxmi ) * downscale ), (int) ( ( pls->clpyma - pls->clpymi ) * downscale ) ), Qt::ReplaceClip );
 
@@ -365,7 +413,8 @@ void QtPLDriver::drawText( EscText* txt )
 
 void QtPLDriver::setColor( int r, int g, int b, double alpha )
 {
-    if ( !m_painterP->isActive() ) return;
+    if ( !m_painterP->isActive() )
+        return;
 
     QPen p = m_painterP->pen();
     p.setColor( QColor( r, g, b, (int) ( alpha * 255 ) ) );
@@ -381,7 +430,8 @@ void QtPLDriver::setGradient( int x1, int x2, int y1, int y2,
                               unsigned char *r, unsigned char *g,
                               unsigned char *b, PLFLT *alpha, PLINT ncol1 )
 {
-    if ( !m_painterP->isActive() || ncol1 < 2 ) return;
+    if ( !m_painterP->isActive() || ncol1 < 2 )
+        return;
 
     int             i;
     qreal           stop_arg;
@@ -404,7 +454,8 @@ void QtPLDriver::setGradient( int x1, int x2, int y1, int y2,
 
 void QtPLDriver::setWidth( PLINT w )
 {
-    if ( !m_painterP->isActive() ) return;
+    if ( !m_painterP->isActive() )
+        return;
 
     QPen p = m_painterP->pen();
     p.setWidth( w );
@@ -428,7 +479,8 @@ void QtPLDriver::setWidth( PLINT w )
 
 void QtPLDriver::setSolid()
 {
-    if ( !m_painterP->isActive() ) return;
+    if ( !m_painterP->isActive() )
+        return;
 
     QPen p = m_painterP->pen();
     p.setStyle( Qt::SolidLine );
@@ -478,7 +530,8 @@ void QtRasterDevice::savePlot()
 
 void QtRasterDevice::setBackgroundColor( int r, int g, int b, double alpha )
 {
-    if ( !m_painterP->isActive() ) return;
+    if ( !m_painterP->isActive() )
+        return;
 
     QBrush brush( QColor( r, g, b, (int) ( alpha * 255 ) ) );
     m_painterP->fillRect( 0, 0, width(), height(), brush );
@@ -516,7 +569,8 @@ void QtSVGDevice::savePlot()
 
 void QtSVGDevice::setBackgroundColor( int r, int g, int b, double alpha )
 {
-    if ( !m_painterP->isActive() ) return;
+    if ( !m_painterP->isActive() )
+        return;
 
     QBrush brush( QColor( r, g, b, (int) ( alpha * 255 ) ) );
     m_painterP->fillRect( 0, 0, width(), height(), brush );
@@ -577,7 +631,8 @@ void QtEPSDevice::savePlot()
 
 void QtEPSDevice::setBackgroundColor( int r, int g, int b, double alpha )
 {
-    if ( !m_painterP->isActive() ) return;
+    if ( !m_painterP->isActive() )
+        return;
 
     QBrush brush( QColor( r, g, b, (int) ( alpha * 255 ) ) );
     m_painterP->fillRect( 0, 0, width(), height(), brush );
@@ -662,6 +717,11 @@ void QtPLWidget::clearBuffer()
             delete i->Data.LinearGradient;
             break;
 
+        case ARC:
+            delete i->Data.ArcStruct->rect;
+            delete i->Data.ArcStruct->dx;
+            delete i->Data.ArcStruct;
+
         default:
             break;
         }
@@ -672,6 +732,28 @@ void QtPLWidget::clearBuffer()
     redrawAll      = true;
 }
 
+
+void QtPLWidget::drawArc( short x, short y, short a, short b, PLFLT angle1, PLFLT angle2, PLFLT rotate, bool fill )
+{
+    BufferElement el;
+    el.Element              = ARC;
+    el.Data.ArcStruct       = new struct ArcStruct_;
+    el.Data.ArcStruct->rect = new QRectF( (PLFLT) ( x - a ) * downscale,
+        m_dHeight - (PLFLT) ( y + b ) * downscale,
+        (PLFLT) a * downscale * 2,
+        (PLFLT) b * downscale * 2
+        );
+    el.Data.ArcStruct->startAngle = (int) ( angle1 * 16 );
+    el.Data.ArcStruct->spanAngle  = (int) ( ( angle2 - angle1 ) * 16 );
+    el.Data.ArcStruct->rotate     = rotate;
+    el.Data.ArcStruct->dx         = new QPointF( (PLFLT) x * downscale, m_dHeight - (PLFLT) y * downscale );
+    el.Data.ArcStruct->fill       = fill;
+
+    m_listBuffer.append( el );
+    redrawFromLastFlush = true;
+}
+
+
 void QtPLWidget::drawLine( short x1, short y1, short x2, short y2 )
 {
     BufferElement el;
@@ -857,7 +939,35 @@ void QtPLWidget::setWidth( PLINT w )
 
 void QtPLWidget::drawText( EscText* txt )
 {
+    if ( pls->get_string_length )
+    {
+        PLUNICODE fci;
+        QPicture  picText;
+        double    picDpi;
+        PLUNICODE *text;
+
+        plgfci( &fci );
+        text = new PLUNICODE[txt->unicode_array_len];
+        memcpy( text, txt->unicode_array, txt->unicode_array_len * sizeof ( PLUNICODE ) );
+        picText = getTextPicture( fci,
+            text,
+            txt->unicode_array_len,
+            pls->chrht );
+        //
+        // I'm assuming that y_fact is 1.0 here, as it is impossible
+        // to know in advance (or so I believe). When the text is
+        // rendered "for real" it will be: pls->chrht * y_fact.
+        //
+        // Hazen 6/2011
+        //
+        picDpi             = picText.logicalDpiY();
+        pls->string_length = ( (PLFLT) xOffset / picDpi ) * 25.4;
+        delete[] text;
+        return;
+    }
+
     BufferElement el;
+
     el.Element                   = TEXT;
     el.Data.TextStruct           = new struct TextStruct_;
     el.Data.TextStruct->x        = txt->x * downscale;
@@ -887,7 +997,8 @@ void QtPLWidget::drawText( EscText* txt )
 
 void QtPLWidget::renderText( QPainter* p, struct TextStruct_* s, double x_fact, double x_offset, double y_fact, double y_offset )
 {
-    if ( s->len <= 0 || s->len >= 500 ) return;
+    if ( s->len <= 0 || s->len >= 500 )
+        return;
     QPicture picText = getTextPicture( s->fci, s->text, s->len, s->chrht * y_fact );
 
     double   picDpi = picText.logicalDpiY();
@@ -1079,10 +1190,14 @@ void QtPLWidget::keyPressEvent( QKeyEvent* event )
             x1 = gin.pX + dx;
             y1 = gin.pY + dy;
 
-            if ( x1 < xmin ) dx = xmin - gin.pX;
-            if ( y1 < ymin ) dy = ymin - gin.pY;
-            if ( x1 > xmax ) dx = xmax - gin.pX;
-            if ( y1 > ymax ) dy = ymax - gin.pY;
+            if ( x1 < xmin )
+                dx = xmin - gin.pX;
+            if ( y1 < ymin )
+                dy = ymin - gin.pY;
+            if ( x1 > xmax )
+                dx = xmax - gin.pX;
+            if ( y1 > ymax )
+                dy = ymax - gin.pY;
 
             QCursor::setPos( p.x() + dx, p.y() + dy );
             plGinInit( &gin );
@@ -1276,7 +1391,10 @@ void QtPLWidget::doPlot( QPainter* p, double x_fact, double y_fact, double x_off
                 p->setPen( NoPen );
                 hasPen = false;
             }
-            p->drawConvexPolygon( *( i->Data.Polyline ) );
+            if ( plsc->dev_eofill )
+                p->drawPolygon( *( i->Data.Polyline ), Qt::OddEvenFill );
+            else
+                p->drawPolygon( *( i->Data.Polyline ), Qt::WindingFill );
             p->setRenderHints( QPainter::Antialiasing, (bool) lines_aa );
             break;
 
@@ -1306,6 +1424,31 @@ void QtPLWidget::doPlot( QPainter* p, double x_fact, double y_fact, double x_off
             p->fillRect( 0, 0, (int) m_dWidth, (int) m_dHeight, SolidBrush );
             break;
 
+        case ARC:
+            if ( !hasPen )
+            {
+                p->setPen( SolidPen );
+                hasPen = true;
+            }
+            if ( i->Data.ArcStruct->rotate != 0.0 )
+            {
+                p->save();
+                p->translate( *( i->Data.ArcStruct->dx ) );
+                p->rotate( -i->Data.ArcStruct->rotate );
+                p->translate( -*( i->Data.ArcStruct->dx ) );
+            }
+
+            if ( i->Data.ArcStruct->fill )
+                p->drawPie( *( i->Data.ArcStruct->rect ), i->Data.ArcStruct->startAngle, i->Data.ArcStruct->spanAngle );
+            else
+                p->drawArc( *( i->Data.ArcStruct->rect ), i->Data.ArcStruct->startAngle, i->Data.ArcStruct->spanAngle );
+
+            if ( i->Data.ArcStruct->rotate != 0.0 )
+            {
+                p->restore();
+            }
+
+            break;
         default:
             break;
         }
@@ -1390,7 +1533,8 @@ void QtExtWidget::captureMousePlotCoords( PLFLT* x, PLFLT* y )
 
 void QtExtWidget::mouseMoveEvent( QMouseEvent* event )
 {
-    if ( !cursorParameters.isTracking ) return;
+    if ( !cursorParameters.isTracking )
+        return;
 
     double x_fact, y_fact, x_offset, y_offset; //Parameters to scale and center the plot on the widget
 
@@ -1423,7 +1567,8 @@ void QtExtWidget::mousePressEvent( QMouseEvent* event )
 
 void QtExtWidget::mouseReleaseEvent( QMouseEvent* event )
 {
-    if ( !cursorParameters.isTracking ) return;
+    if ( !cursorParameters.isTracking )
+        return;
 
     double x_fact, y_fact, x_offset, y_offset; //Parameters to scale and center the plot on the widget
 
@@ -1461,7 +1606,8 @@ void QtExtWidget::paintEvent( QPaintEvent* event )
 {
     QtPLWidget::paintEvent( event );
 
-    if ( !cursorParameters.isTracking || cursorParameters.cursor_x < 0 ) return;
+    if ( !cursorParameters.isTracking || cursorParameters.cursor_x < 0 )
+        return;
 
     QPainter p( this );
 
@@ -1475,20 +1621,20 @@ void QtExtWidget::paintEvent( QPaintEvent* event )
 
 void plsetqtdev( QtExtWidget* widget )
 {
-    plsc->dev = (void*) widget;
+    plsc->dev = (void *) widget;
     widget->setPLStream( plsc );
 }
 
 void plsetqtdev( QtExtWidget* widget, int argc, char** argv )
 {
-    plparseopts( &argc, (const char**) argv, PL_PARSE_FULL );
-    plsc->dev = (void*) widget;
+    plparseopts( &argc, (const char **) argv, PL_PARSE_FULL );
+    plsc->dev = (void *) widget;
     widget->setPLStream( plsc );
 }
 
 void plfreeqtdev()
 {
-    delete ( (QtExtWidget*) plsc->dev );
+    delete ( (QtExtWidget *) plsc->dev );
     plsc->dev = NULL;
 }
 #endif
