@@ -6,7 +6,7 @@
 #
 # @> [incr Tcl] interface to PLplot
 #
-# $Id: Plwindow.tcl 5669 2004-06-25 21:40:26Z airwin $
+# $Id: Plwindow.tcl 11659 2011-03-19 23:56:59Z airwin $
 #
 ###############################################################################
 
@@ -47,10 +47,6 @@ itcl::class Plwindow {
 	uplevel 1 $itk_interior.plwin cmd $args
     }
 
-    method plcol {color} {
-	cmd plcol0 $color
-    }
-
     method plcont {data clev} {
 	upvar $data d
 	upvar $clev c
