@@ -1,11 +1,11 @@
-/* $Id: tcpip.h 10785 2010-01-31 20:05:17Z hezekiahcarty $
- *
- * Maurice LeBrun
- * 31-May-95
- *
- * Declarations for IP utility routines.
- * Put here so as not to clutter up user codes.
- */
+// $Id: tcpip.h 11295 2010-11-01 22:19:45Z airwin $
+//
+// Maurice LeBrun
+// 31-May-95
+//
+// Declarations for IP utility routines.
+// Put here so as not to clutter up user codes.
+//
 
 #ifndef __TCPIP_H__
 #define __TCPIP_H__
@@ -13,16 +13,16 @@
 #include "pdf.h"
 #include <tcl.h>
 
-/* Modified version of the "Tdp_PacketSend" command. */
+// Modified version of the "Tdp_PacketSend" command.
 
 PLDLLIMPEXP_TCLTK int
 pl_PacketSend           PLARGS( ( Tcl_Interp * interp, PLiodev * iodev,
                                   PDFstrm * pdfs ) );
 
-/* Modified version of the "Tdp_PacketReceive" command. */
+// Modified version of the "Tdp_PacketReceive" command.
 
 PLDLLIMPEXP_TCLTK int
 pl_PacketReceive        PLARGS( ( Tcl_Interp * interp, PLiodev * iodev,
                                   PDFstrm * pdfs ) );
 
-#endif  /* __TCPIP_H__ */
+#endif  // __TCPIP_H__
