@@ -1,65 +1,65 @@
-/* $Id: tkMain.c 10785 2010-01-31 20:05:17Z hezekiahcarty $
- *
- * Modified version of tkMain.c, from Tk 3.6.
- * Maurice LeBrun
- * 23-Jun-1994
- *
- * Copyright (C) 2004  Joao Cardoso
- *
- * This file is part of PLplot.
- *
- * PLplot is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Library Public License as published
- * by the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * PLplot is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with PLplot; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
- *
- *
- * Modifications include:
- * 1. main() changed to pltkMain().
- * 2. tcl_RcFileName -> RcFileName, now passed in through the argument list.
- * 3. Tcl_AppInit -> AppInit, now passed in through the argument list.
- * 4. Support for -e <script> startup option
- *
- * The original notes follow.
- */
+// $Id: tkMain.c 11680 2011-03-27 17:57:51Z airwin $
+//
+// Modified version of tkMain.c, from Tk 3.6.
+// Maurice LeBrun
+// 23-Jun-1994
+//
+// Copyright (C) 2004  Joao Cardoso
+//
+// This file is part of PLplot.
+//
+// PLplot is free software; you can redistribute it and/or modify
+// it under the terms of the GNU Library General Public License as published
+// by the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+//
+// PLplot is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Library General Public License for more details.
+//
+// You should have received a copy of the GNU Library General Public License
+// along with PLplot; if not, write to the Free Software
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+//
+//
+// Modifications include:
+// 1. main() changed to pltkMain().
+// 2. tcl_RcFileName -> RcFileName, now passed in through the argument list.
+// 3. Tcl_AppInit -> AppInit, now passed in through the argument list.
+// 4. Support for -e <script> startup option
+//
+// The original notes follow.
+//
 
-/*
- * main.c --
- *
- *	This file contains the main program for "wish", a windowing
- *	shell based on Tk and Tcl.  It also provides a template that
- *	can be used as the basis for main programs for other Tk
- *	applications.
- *
- * Copyright (c) 1990-1993 The Regents of the University of California.
- * All rights reserved.
- *
- * Permission is hereby granted, without written agreement and without
- * license or royalty fees, to use, copy, modify, and distribute this
- * software and its documentation for any purpose, provided that the
- * above copyright notice and the following two paragraphs appear in
- * all copies of this software.
- *
- * IN NO EVENT SHALL THE UNIVERSITY OF CALIFORNIA BE LIABLE TO ANY PARTY FOR
- * DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES ARISING OUT
- * OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION, EVEN IF THE UNIVERSITY OF
- * CALIFORNIA HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * THE UNIVERSITY OF CALIFORNIA SPECIFICALLY DISCLAIMS ANY WARRANTIES,
- * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
- * AND FITNESS FOR A PARTICULAR PURPOSE.  THE SOFTWARE PROVIDED HEREUNDER IS
- * ON AN "AS IS" BASIS, AND THE UNIVERSITY OF CALIFORNIA HAS NO OBLIGATION TO
- * PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
- */
+//
+// main.c --
+//
+//	This file contains the main program for "wish", a windowing
+//	shell based on Tk and Tcl.  It also provides a template that
+//	can be used as the basis for main programs for other Tk
+//	applications.
+//
+// Copyright (c) 1990-1993 The Regents of the University of California.
+// All rights reserved.
+//
+// Permission is hereby granted, without written agreement and without
+// license or royalty fees, to use, copy, modify, and distribute this
+// software and its documentation for any purpose, provided that the
+// above copyright notice and the following two paragraphs appear in
+// all copies of this software.
+//
+// IN NO EVENT SHALL THE UNIVERSITY OF CALIFORNIA BE LIABLE TO ANY PARTY FOR
+// DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES ARISING OUT
+// OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION, EVEN IF THE UNIVERSITY OF
+// CALIFORNIA HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+//
+// THE UNIVERSITY OF CALIFORNIA SPECIFICALLY DISCLAIMS ANY WARRANTIES,
+// INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
+// AND FITNESS FOR A PARTICULAR PURPOSE.  THE SOFTWARE PROVIDED HEREUNDER IS
+// ON AN "AS IS" BASIS, AND THE UNIVERSITY OF CALIFORNIA HAS NO OBLIGATION TO
+// PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
+//
 
 #include "plplotP.h"
 #include "pltkd.h"
@@ -74,16 +74,16 @@
 # include <itcl.h>
 #endif
 
-/* itk.h includes itclInt.h which includes tclInt.h ...disaster -mjl */
-/* #ifdef HAVE_ITK */
-/* #include <itk.h> */
-/* #endif */
+// itk.h includes itclInt.h which includes tclInt.h ...disaster -mjl
+// #ifdef HAVE_ITK
+// #include <itk.h>
+// #endif
 
-/* From itkDecls.h */
+// From itkDecls.h
 
 EXTERN int Itk_Init _ANSI_ARGS_( ( Tcl_Interp * interp ) );
 
-/* From tclIntDecls.h */
+// From tclIntDecls.h
 
 #ifndef Tcl_Import_TCL_DECLARED
 EXTERN int Tcl_Import _ANSI_ARGS_( ( Tcl_Interp * interp,
@@ -96,34 +96,34 @@ EXTERN Tcl_Namespace * Tcl_GetGlobalNamespace _ANSI_ARGS_( (
                                                                Tcl_Interp * interp ) );
 #endif
 
-/*
- * Declarations for various library procedures and variables (don't want
- * to include tkInt.h or tkConfig.h here, because people might copy this
- * file out of the Tk source directory to make their own modified versions).
- */
+//
+// Declarations for various library procedures and variables (don't want
+// to include tkInt.h or tkConfig.h here, because people might copy this
+// file out of the Tk source directory to make their own modified versions).
+//
 
-/* these are defined in unistd.h, included by plplotP.h
- * extern void		exit _ANSI_ARGS_((int status));
- * extern int		isatty _ANSI_ARGS_((int fd));
- * extern int		read _ANSI_ARGS_((int fd, char *buf, size_t size));
- */
+// these are defined in unistd.h, included by plplotP.h
+// extern void		exit _ANSI_ARGS_((int status));
+// extern int		isatty _ANSI_ARGS_((int fd));
+// extern int		read _ANSI_ARGS_((int fd, char *buf, size_t size));
+//
 extern char *           strrchr _ANSI_ARGS_( ( CONST char *string, int c ) );
 
-/*
- * Global variables used by the main program:
- */
+//
+// Global variables used by the main program:
+//
 
-static Tcl_Interp  *interp;     /* Interpreter for this application. */
-static Tcl_DString command;     /* Used to assemble lines of terminal input
-                                 * into Tcl commands. */
-static int         tty;         /* Non-zero means standard input is a
-                                 * terminal-like device.  Zero means it's
-                                 * a file. */
+static Tcl_Interp  *interp;     // Interpreter for this application.
+static Tcl_DString command;     // Used to assemble lines of terminal input
+                                // into Tcl commands.
+static int         tty;         // Non-zero means standard input is a
+                                // terminal-like device.  Zero means it's
+                                // a file.
 static char errorExitCmd[] = "exit 1";
 
-/*
- * Command-line options:
- */
+//
+// Command-line options:
+//
 
 static int         synchronize = 0;
 static const char  *script     = NULL;
@@ -149,32 +149,32 @@ static Tk_ArgvInfo argTable[] = {
       (char *) NULL }
 };
 
-/*
- * Forward declarations for procedures defined later in this file:
- */
+//
+// Forward declarations for procedures defined later in this file:
+//
 
 static void Prompt _ANSI_ARGS_( ( Tcl_Interp * interp, int partial ) );
 static void StdinProc _ANSI_ARGS_( ( ClientData clientData,
                                      int mask ) );
 
-/*
- *----------------------------------------------------------------------
- *
- * main --
- *
- *	Main program for Wish.
- *
- * Results:
- *	None. This procedure never returns (it exits the process when
- *	it's done
- *
- * Side effects:
- *	This procedure initializes the wish world and then starts
- *	interpreting commands;  almost anything could happen, depending
- *	on the script being interpreted.
- *
- *----------------------------------------------------------------------
- */
+//
+//--------------------------------------------------------------------------
+//
+// main --
+//
+//	Main program for Wish.
+//
+// Results:
+//	None. This procedure never returns (it exits the process when
+//	it's done
+//
+// Side effects:
+//	This procedure initializes the wish world and then starts
+//	interpreting commands;  almost anything could happen, depending
+//	on the script being interpreted.
+//
+//--------------------------------------------------------------------------
+//
 
 int
 pltkMain( int argc, const char **argv, char *RcFileName,
@@ -185,7 +185,7 @@ pltkMain( int argc, const char **argv, char *RcFileName,
     char       buf[20];
     int        code;
 
-#ifdef HAVE_PTHREAD
+#ifdef PL_HAVE_PTHREAD
     XInitThreads();
 #endif
 
@@ -195,9 +195,9 @@ pltkMain( int argc, const char **argv, char *RcFileName,
     Tcl_InitMemory( interp );
 #endif
 
-    /*
-     * Parse command-line arguments.
-     */
+    //
+    // Parse command-line arguments.
+    //
 
     if ( Tk_ParseArgv( interp, (Tk_Window) NULL, &argc, argv, argTable, 0 )
          != TCL_OK )
@@ -226,25 +226,25 @@ pltkMain( int argc, const char **argv, char *RcFileName,
         }
     }
 
-    /*
-     * If a display was specified, put it into the DISPLAY
-     * environment variable so that it will be available for
-     * any sub-processes created by us.
-     */
+    //
+    // If a display was specified, put it into the DISPLAY
+    // environment variable so that it will be available for
+    // any sub-processes created by us.
+    //
 
     if ( display != NULL )
     {
         Tcl_SetVar2( interp, "env", "DISPLAY", display, TCL_GLOBAL_ONLY );
     }
 
-    /*
-     * Initialize the Tk application.
-     */
+    //
+    // Initialize the Tk application.
+    //
 
-    /*
-     * This must be setup *before* calling Tk_Init,
-     * and `name' has already been setup above
-     */
+    //
+    // This must be setup *before* calling Tk_Init,
+    // and `name' has already been setup above
+    //
 
     Tcl_SetVar( interp, "argv0", name, TCL_GLOBAL_ONLY );
 
@@ -268,15 +268,15 @@ pltkMain( int argc, const char **argv, char *RcFileName,
         return TCL_ERROR;
     }
 
-/*
- * Pulled in this next section from itkwish in itcl3.0.1.
- */
+//
+// Pulled in this next section from itkwish in itcl3.0.1.
+//
 
-    /*
-     *  This is itkwish, so import all [incr Tcl] commands by
-     *  default into the global namespace.  Fix up the autoloader
-     *  to do the same.
-     */
+    //
+    //  This is itkwish, so import all [incr Tcl] commands by
+    //  default into the global namespace.  Fix up the autoloader
+    //  to do the same.
+    //
     if ( Tcl_Import( interp, Tcl_GetGlobalNamespace( interp ),
              "::itk::*", /* allowOverwrite */ 1 ) != TCL_OK )
     {
@@ -295,11 +295,11 @@ pltkMain( int argc, const char **argv, char *RcFileName,
     }
 #endif
 
-    /*
-     * Make command-line arguments available in the Tcl variables "argc"
-     * and "argv".  Also set the "geometry" variable from the geometry
-     * specified on the command line.
-     */
+    //
+    // Make command-line arguments available in the Tcl variables "argc"
+    // and "argv".  Also set the "geometry" variable from the geometry
+    // specified on the command line.
+    //
 
     args = Tcl_Merge( argc - 1, ( CONST char * CONST * )argv + 1 );
     Tcl_SetVar( interp, "argv", args, TCL_GLOBAL_ONLY );
@@ -312,31 +312,31 @@ pltkMain( int argc, const char **argv, char *RcFileName,
         Tcl_SetVar( interp, "geometry", geometry, TCL_GLOBAL_ONLY );
     }
 
-    /*
-     * Set the "tcl_interactive" variable.
-     */
+    //
+    // Set the "tcl_interactive" variable.
+    //
 
     tty = isatty( 0 );
     Tcl_SetVar( interp, "tcl_interactive",
         ( ( fileName == NULL ) && tty ) ? "1" : "0", TCL_GLOBAL_ONLY );
 
-    /*
-     * Add a few application-specific commands to the application's
-     * interpreter.
-     */
+    //
+    // Add a few application-specific commands to the application's
+    // interpreter.
+    //
 
-    /*
-     * Invoke application-specific initialization.
-     */
+    //
+    // Invoke application-specific initialization.
+    //
 
     if ( ( *AppInit )( interp ) != TCL_OK )
     {
         fprintf( stderr, "(*AppInit) failed: %s\n", interp->result );
     }
 
-    /*
-     * Set the geometry of the main window, if requested.
-     */
+    //
+    // Set the geometry of the main window, if requested.
+    //
 
     if ( geometry != NULL )
     {
@@ -347,9 +347,9 @@ pltkMain( int argc, const char **argv, char *RcFileName,
         }
     }
 
-    /*
-     * Process the startup script, if any.
-     */
+    //
+    // Process the startup script, if any.
+    //
 
     if ( script != NULL )
     {
@@ -361,9 +361,9 @@ pltkMain( int argc, const char **argv, char *RcFileName,
         tty = 0;
     }
 
-    /*
-     * Invoke the script specified on the command line, if any.
-     */
+    //
+    // Invoke the script specified on the command line, if any.
+    //
 
     if ( fileName != NULL )
     {
@@ -376,13 +376,13 @@ pltkMain( int argc, const char **argv, char *RcFileName,
     }
     else
     {
-        /*
-         * Commands will come from standard input, so set up an event
-         * handler for standard input.  If the input device is aEvaluate the
-         * .rc file, if one has been specified, set up an event handler
-         * for standard input, and print a prompt if the input
-         * device is a terminal.
-         */
+        //
+        // Commands will come from standard input, so set up an event
+        // handler for standard input.  Evaluate the .rc file, if one
+        // has been specified, set up an event handler for standard
+        // input, and print a prompt if the input device is a
+        // terminal.
+        //
 
         if ( RcFileName != NULL )
         {
@@ -410,7 +410,7 @@ pltkMain( int argc, const char **argv, char *RcFileName,
             }
             Tcl_DStringFree( &buffer );
         }
-/* Exclude UNIX-only feature */
+// Exclude UNIX-only feature
 #if !defined ( MAC_TCL ) && !defined ( __WIN32__ ) && !defined ( __CYGWIN__ )
         Tk_CreateFileHandler( 0, TK_READABLE, StdinProc, (ClientData) 0 );
 #endif
@@ -422,18 +422,18 @@ pltkMain( int argc, const char **argv, char *RcFileName,
     fflush( stdout );
     Tcl_DStringInit( &command );
 
-    /*
-     * Loop infinitely, waiting for commands to execute.  When there
-     * are no windows left, Tk_MainLoop returns and we exit.
-     */
+    //
+    // Loop infinitely, waiting for commands to execute.  When there
+    // are no windows left, Tk_MainLoop returns and we exit.
+    //
 
     Tk_MainLoop();
 
-    /*
-     * Don't exit directly, but rather invoke the Tcl "exit" command.
-     * This gives the application the opportunity to redefine "exit"
-     * to do additional cleanup.
-     */
+    //
+    // Don't exit directly, but rather invoke the Tcl "exit" command.
+    // This gives the application the opportunity to redefine "exit"
+    // to do additional cleanup.
+    //
 
     Tcl_Eval( interp, "exit" );
     exit( 1 );
@@ -446,34 +446,34 @@ error:
     }
     fprintf( stderr, "%s\n", msg );
     Tcl_Eval( interp, errorExitCmd );
-    return 1;                   /* Needed only to prevent compiler warnings. */
+    return 1;                   // Needed only to prevent compiler warnings.
 }
 
-/*
- *----------------------------------------------------------------------
- *
- * StdinProc --
- *
- *	This procedure is invoked by the event dispatcher whenever
- *	standard input becomes readable.  It grabs the next line of
- *	input characters, adds them to a command being assembled, and
- *	executes the command if it's complete.
- *
- * Results:
- *	None.
- *
- * Side effects:
- *	Could be almost arbitrary, depending on the command that's
- *	typed.
- *
- *----------------------------------------------------------------------
- */
+//
+//--------------------------------------------------------------------------
+//
+// StdinProc --
+//
+//	This procedure is invoked by the event dispatcher whenever
+//	standard input becomes readable.  It grabs the next line of
+//	input characters, adds them to a command being assembled, and
+//	executes the command if it's complete.
+//
+// Results:
+//	None.
+//
+// Side effects:
+//	Could be almost arbitrary, depending on the command that's
+//	typed.
+//
+//--------------------------------------------------------------------------
+//
 
-/* ARGSUSED */
+// ARGSUSED
 static void
 StdinProc( clientData, mask )
-ClientData clientData;                  /* Not used. */
-int mask;                               /* Not used. */
+ClientData clientData;                  // Not used.
+int mask;                               // Not used.
 {
 #define BUFFER_SIZE    4000
     char       input[BUFFER_SIZE + 1];
@@ -520,13 +520,13 @@ int mask;                               /* Not used. */
     }
     gotPartial = 0;
 
-    /*
-     * Disable the stdin file handler while evaluating the command;
-     * otherwise if the command re-enters the event loop we might
-     * process commands from stdin before the current command is
-     * finished.  Among other things, this will trash the text of the
-     * command being evaluated.
-     */
+    //
+    // Disable the stdin file handler while evaluating the command;
+    // otherwise if the command re-enters the event loop we might
+    // process commands from stdin before the current command is
+    // finished.  Among other things, this will trash the text of the
+    // command being evaluated.
+    //
 #if !defined ( MAC_TCL ) && !defined ( __WIN32__ ) && !defined ( __CYGWIN__ )
     Tk_CreateFileHandler( 0, 0, StdinProc, (ClientData) 0 );
 #endif
@@ -543,9 +543,9 @@ int mask;                               /* Not used. */
         }
     }
 
-    /*
-     * Output a prompt.
-     */
+    //
+    // Output a prompt.
+    //
 
 prompt:
     if ( tty )
@@ -554,30 +554,30 @@ prompt:
     }
 }
 
-/*
- *----------------------------------------------------------------------
- *
- * Prompt --
- *
- *	Issue a prompt on standard output, or invoke a script
- *	to issue the prompt.
- *
- * Results:
- *	None.
- *
- * Side effects:
- *	A prompt gets output, and a Tcl script may be evaluated
- *	in interp.
- *
- *----------------------------------------------------------------------
- */
+//
+//--------------------------------------------------------------------------
+//
+// Prompt --
+//
+//	Issue a prompt on standard output, or invoke a script
+//	to issue the prompt.
+//
+// Results:
+//	None.
+//
+// Side effects:
+//	A prompt gets output, and a Tcl script may be evaluated
+//	in interp.
+//
+//--------------------------------------------------------------------------
+//
 
 static void
 Prompt( interp, partial )
-Tcl_Interp * interp;                    /* Interpreter to use for prompting. */
-int partial;                            /* Non-zero means there already
-                                         * exists a partial command, so use
-                                         * the secondary prompt. */
+Tcl_Interp * interp;                    // Interpreter to use for prompting.
+int partial;                            // Non-zero means there already
+                                        // exists a partial command, so use
+                                        // the secondary prompt.
 {
     char *promptCmd;
     int  code;
