@@ -1,9 +1,9 @@
-//---------------------------------------------------------------------------//
-// $Id: x04.cc 10785 2010-01-31 20:05:17Z hezekiahcarty $
-//---------------------------------------------------------------------------//
+//--------------------------------------------------------------------------
+// $Id: x04.cc 11717 2011-04-21 00:47:06Z airwin $
+//--------------------------------------------------------------------------
 //
-//---------------------------------------------------------------------------//
-// Copyright (C) 2004  Andrew Ross <andrewr@coriolis.greenend.org.uk>
+//--------------------------------------------------------------------------
+// Copyright (C) 2004  Andrew Ross
 // Copyright (C) 2004  Alan W. Irwin
 //
 // This file is part of PLplot.
@@ -20,11 +20,11 @@
 // You should have received a copy of the GNU Library General Public License
 // along with PLplot; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
-//---------------------------------------------------------------------------//
+//--------------------------------------------------------------------------
 //
-//---------------------------------------------------------------------------//
+//--------------------------------------------------------------------------
 // Implementation of PLplot example 4 in C++.
-//---------------------------------------------------------------------------//
+//--------------------------------------------------------------------------
 
 #include "plc++demos.h"
 
@@ -69,11 +69,21 @@ x04::x04( int argc, const char ** argv )
 
 void x04::plot1( int type )
 {
-    int   i;
-    PLFLT *freql = new PLFLT[101];
-    PLFLT *ampl  = new PLFLT[101];
-    PLFLT *phase = new PLFLT[101];
-    PLFLT f0, freq;
+    int        i;
+    PLFLT      *freql = new PLFLT[101];
+    PLFLT      *ampl  = new PLFLT[101];
+    PLFLT      *phase = new PLFLT[101];
+    PLFLT      f0, freq;
+    PLINT      nlegend;
+    const char *text[2], *symbols[2];
+    PLINT      opt_array[2];
+    PLINT      text_colors[2];
+    PLINT      line_colors[2];
+    PLINT      line_styles[2];
+    PLINT      line_widths[2];
+    PLINT      symbol_numbers[2], symbol_colors[2];
+    PLFLT      symbol_scales[2];
+    PLFLT      legend_width, legend_height;
 
     pls->adv( 0 );
 
@@ -108,7 +118,7 @@ void x04::plot1( int type )
 
     pls->col0( 2 );
     pls->line( 101, freql, ampl );
-    pls->col0( 1 );
+    pls->col0( 2 );
     pls->ptex( 1.6, -30.0, 1.0, -20.0, 0.5, "-20 dB/decade" );
 
     // Put labels on.
@@ -118,6 +128,7 @@ void x04::plot1( int type )
     pls->mtex( "t", 2.0, 0.5, 0.5, "Single Pole Low-Pass Filter" );
     pls->col0( 2 );
     pls->mtex( "l", 5.0, 0.5, 0.5, "Amplitude (dB)" );
+    nlegend = 1;
 
     // For the gridless case, put phase vs freq on same plot.
 
@@ -128,10 +139,49 @@ void x04::plot1( int type )
         pls->box( "", 0.0, 0, "cmstv", 30.0, 3 );
         pls->col0( 3 );
         pls->line( 101, freql, phase );
+        pls->string( 101, freql, phase, "*" );
         pls->col0( 3 );
         pls->mtex( "r", 5.0, 0.5, 0.5, "Phase shift (degrees)" );
+        nlegend = 2;
     }
 
+    // Draw a legend
+    // First legend entry.
+    opt_array[0]   = PL_LEGEND_LINE;
+    text_colors[0] = 2;
+    text[0]        = "Amplitude";
+    line_colors[0] = 2;
+    line_styles[0] = 1;
+    line_widths[0] = 1;
+    // note from the above opt_array the first symbol (and box) indices
+    // do not have to be specified
+
+    // Second legend entry.
+    opt_array[1]      = PL_LEGEND_LINE | PL_LEGEND_SYMBOL;
+    text_colors[1]    = 3;
+    text[1]           = "Phase shift";
+    line_colors[1]    = 3;
+    line_styles[1]    = 1;
+    line_widths[1]    = 1;
+    symbol_colors[1]  = 3;
+    symbol_scales[1]  = 1.;
+    symbol_numbers[1] = 4;
+    symbols[1]        = "*";
+    // from the above opt_arrays we can completely ignore everything
+    // to do with boxes.
+
+    pls->scol0a( 15, 32, 32, 32, 0.70 );
+    pls->legend( &legend_width, &legend_height,
+        PL_LEGEND_BACKGROUND | PL_LEGEND_BOUNDING_BOX, 0,
+        0.0, 0.0, 0.1, 15,
+        1, 1, 0, 0,
+        nlegend, opt_array,
+        1.0, 1.0, 2.0,
+        1., text_colors, (const char **) text,
+        NULL, NULL, NULL, NULL,
+        line_colors, line_styles, line_widths,
+        symbol_colors, symbol_scales, symbol_numbers, (const char **) symbols );
+
     delete[] freql;
     delete[] ampl;
     delete[] phase;
@@ -146,6 +196,6 @@ int main( int argc, const char ** argv )
 }
 
 
-//---------------------------------------------------------------------------//
+//--------------------------------------------------------------------------
 //                              End of x04.cc
-//---------------------------------------------------------------------------//
+//--------------------------------------------------------------------------
