@@ -1,8 +1,8 @@
-//---------------------------------------------------------------------------//
-// $Id: x07.cc 10967 2010-05-05 22:38:15Z andrewross $
-//---------------------------------------------------------------------------//
+//--------------------------------------------------------------------------
+// $Id: x07.cc 11297 2010-11-02 03:31:14Z airwin $
+//--------------------------------------------------------------------------
 //
-//---------------------------------------------------------------------------//
+//--------------------------------------------------------------------------
 // Copyright (C) 2004  Andrew Ross <andrewr@coriolis.greenend.org.uk>
 // Copyright (C) 2004  Alan W. Irwin
 //
@@ -20,11 +20,11 @@
 // You should have received a copy of the GNU Library General Public License
 // along with PLplot; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
-//---------------------------------------------------------------------------//
+//--------------------------------------------------------------------------
 //
-//---------------------------------------------------------------------------//
+//--------------------------------------------------------------------------
 // Implementation of PLplot example 07 in C++.
-//---------------------------------------------------------------------------//
+//--------------------------------------------------------------------------
 
 #include "plc++demos.h"
 
@@ -66,7 +66,8 @@ x07::x07( int argc, const char ** argv )
     pls->fontld( 0 );
     for ( l = 0; l < 20; l++ )
     {
-        if ( l == 2 ) pls->fontld( 1 );
+        if ( l == 2 )
+            pls->fontld( 1 );
         pls->adv( 0 );
 
         // Set up viewport and window.
@@ -125,6 +126,6 @@ int main( int argc, const char ** argv )
 }
 
 
-//---------------------------------------------------------------------------//
+//--------------------------------------------------------------------------
 //                              End of x07.cc
-//---------------------------------------------------------------------------//
+//--------------------------------------------------------------------------
