@@ -1,8 +1,8 @@
-//---------------------------------------------------------------------------//
-// $Id: x17.cc 10551 2009-10-26 13:47:26Z andrewross $
-//---------------------------------------------------------------------------//
+//--------------------------------------------------------------------------
+// $Id: x17.cc 11760 2011-06-01 19:29:11Z airwin $
+//--------------------------------------------------------------------------
 //
-//---------------------------------------------------------------------------//
+//--------------------------------------------------------------------------
 // Copyright (C) 2004  Andrew Ross <andrewr@coriolis.greenend.org.uk>
 // Copyright (C) 2004  Alan W. Irwin
 //
@@ -20,11 +20,11 @@
 // You should have received a copy of the GNU Library General Public License
 // along with PLplot; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
-//---------------------------------------------------------------------------//
+//--------------------------------------------------------------------------
 //
-//---------------------------------------------------------------------------//
+//--------------------------------------------------------------------------
 // Implementation of PLplot example 17 in C++.
-//---------------------------------------------------------------------------//
+//--------------------------------------------------------------------------
 
 #include "plc++demos.h"
 #ifdef PL_HAVE_UNISTD_H
@@ -52,8 +52,8 @@ public:
     static char  errmsg[160];
 };
 
-PLINT x17::pl_errcode  = 0;
-char x17:: errmsg[160] = "";
+PLINT x17::pl_errcode   = 0;
+char  x17:: errmsg[160] = "";
 
 x17::x17( int argc, const char ** argv )
 {
@@ -152,12 +152,14 @@ x17::x17( int argc, const char ** argv )
     for ( n = 0; n < nsteps; n++ )
     {
 #ifdef PL_HAVE_USLEEP
-        usleep( 10000 ); /* wait a little (10 ms) to simulate time elapsing */
+        usleep( 10000 ); // wait a little (10 ms) to simulate time elapsing
 #else
 # ifdef PL_HAVE_POLL
         poll( 0, 0, 10 );
 # else
-        { int i; for ( i = 0; i < 1000000; i++ ) ;}
+        { int i; for ( i = 0; i < 1000000; i++ )
+              ;
+        }
 # endif
 #endif
         t     = (double) n * dt;
@@ -195,6 +197,6 @@ int main( int argc, const char ** argv )
 }
 
 
-//---------------------------------------------------------------------------//
+//--------------------------------------------------------------------------
 //                              End of x17.cc
-//---------------------------------------------------------------------------//
+//--------------------------------------------------------------------------
