@@ -1,4 +1,4 @@
-!      $Id: x03f.f90 10613 2009-11-19 12:05:09Z andrewross $
+!      $Id: x03f.f90 11680 2011-03-27 17:57:51Z airwin $
 !      Generates polar plot with, 1-1 scaling
 !
 !      Copyright (C) 2004  Alan W. Irwin
@@ -6,7 +6,7 @@
 !      This file is part of PLplot.
 !
 !      PLplot is free software; you can redistribute it and/or modify
-!      it under the terms of the GNU General Library Public License as
+!      it under the terms of the GNU Library General Public License as
 !      published by the Free Software Foundation; either version 2 of the
 !      License, or (at your option) any later version.
 !
@@ -49,7 +49,7 @@
 !     Draw circles for polar grid
       do i = 1,10
         call plarc(0.0_plflt, 0.0_plflt, 0.1_plflt*i, 0.1_plflt*i, &
-             0.0_plflt, 360.0_plflt, 0)
+             0.0_plflt, 360.0_plflt, 0.0_plflt, 0)
       enddo
       call plcol0(2)
       do i = 0,11
