@@ -1,4 +1,4 @@
-!      $Id: x04f.f90 6572 2006-05-16 20:24:14Z airwin $
+!      $Id: x04f.f90 11717 2011-04-21 00:47:06Z airwin $
 !      Illustration of logarithmic axes, and redefinition of window
 !
 !      Copyright (C) 2004  Alan W. Irwin
@@ -6,7 +6,7 @@
 !      This file is part of PLplot.
 !
 !      PLplot is free software; you can redistribute it and/or modify
-!      it under the terms of the GNU General Library Public License as
+!      it under the terms of the GNU Library General Public License as
 !      published by the Free Software Foundation; either version 2 of the
 !      License, or (at your option) any later version.
 !
@@ -21,6 +21,7 @@
 
       use plplot
       implicit none
+
 !      Process command-line arguments
       call plparseopts(PL_PARSE_FULL)
 
@@ -35,8 +36,19 @@
       subroutine plot1(type)
       use plplot, PI => PL_PI
       implicit none
-      real(kind=plflt) freql(0:100),ampl(0:100),phase(0:100), freq, f0
-      integer i, type
+      real(kind=plflt)  freql(0:100),ampl(0:100),phase(0:100), freq, f0
+      integer           i, type
+      integer           nlegend
+
+      real(kind=plflt)  legend_width, legend_height
+      integer           opt_array(2), text_colors(2), line_colors(2), &
+                        line_styles(2), line_widths(2), symbol_colors(2), &
+                        symbol_numbers(2)
+      real(kind=plflt)  symbol_scales(2), box_scales(0)
+      integer           box_colors(0), box_patterns(0)
+      integer           box_line_widths(0)
+      character(len=20) text(2)
+      character(len=1)  symbols(2)
 
       call pladv(0)
 !      Set up data for log plot.
@@ -61,7 +73,7 @@
 !      Plot ampl vs freq.
       call plcol0(2)
       call plline(freql,ampl)
-      call plcol0(1)
+      call plcol0(2)
       call plptex(1.6_plflt, -30.0_plflt, 1.0_plflt, -20.0_plflt, 0.5_plflt, &
                   '-20 dB/decade')
 !      Put labels on.
@@ -71,15 +83,58 @@
                   'Single Pole Low-Pass Filter')
       call plcol0(2)
       call plmtex('l', 5.0_plflt, 0.5_plflt, 0.5_plflt, 'Amplitude (dB)')
+      nlegend = 1
 !      For the gridless case, put phase vs freq on same plot.
       if(type.eq.0) then
         call plcol0(1)
         call plwind(-2.0_plflt, 3.0_plflt, -100.0_plflt, 0.0_plflt)
         call plbox(' ', 0.0_plflt, 0, 'cmstv', 30.0_plflt, 3)
         call plcol0(3)
-        call plline(freql,phase)
+        call plline(freql, phase)
+        call plstring(freql, phase, '*')
         call plcol0(3)
         call plmtex('r', 5.0_plflt, 0.5_plflt, 0.5_plflt, &
                     'Phase shift (degrees)')
+        nlegend = 2
       endif
+
+!     Draw a legend
+!     First legend entry.
+      opt_array(1)   = PL_LEGEND_LINE
+      text_colors(1) = 2
+      text(1)        = 'Amplitude'
+      line_colors(1) = 2
+      line_styles(1) = 1
+      line_widths(1) = 1
+!     note from the above opt_array the first symbol (and box) indices
+!     do not have to be specified
+
+!     Second legend entry.
+      opt_array(2)      = PL_LEGEND_LINE + PL_LEGEND_SYMBOL
+      text_colors(2)    = 3
+      text(2)           = 'Phase shift'
+      line_colors(2)    = 3
+      line_styles(2)    = 1
+      line_widths(2)    = 1
+      symbol_colors(2)  = 3
+      symbol_scales(2)  = 1.0
+      symbol_numbers(2) = 4
+      symbols(2)        = '*'
+
+!     from the above opt_arrays we can completely ignore everything
+!     to do with boxes. (Hence the size 0 for the associated arrays)
+!     (note: use the argument nlegend explicitly)
+
+      call plscol0a( 15, 32, 32, 32, 0.70_plflt )
+      call pllegend( legend_width, legend_height, &
+          PL_LEGEND_BACKGROUND + PL_LEGEND_BOUNDING_BOX, 0, &
+          0.0_plflt, 0.0_plflt, 0.1_plflt, 15, &
+          1, 1, 0, 0, &
+          nlegend, opt_array, &
+          1.0_plflt, 1.0_plflt, 2.0_plflt, &
+          1.0_plflt, text_colors, text, &
+          box_colors, box_patterns, box_scales, box_line_widths, &
+          line_colors, line_styles, line_widths, &
+          symbol_colors, symbol_scales, symbol_numbers, symbols )
+
       end
