@@ -1,4 +1,4 @@
-!      $Id: x09f.f90 9134 2008-12-16 14:13:49Z andrewross $
+!      $Id: x09f.f90 11680 2011-03-27 17:57:51Z airwin $
 !      Contour plot demo.
 !
 !      Copyright (C) 2004  Alan W. Irwin
@@ -6,7 +6,7 @@
 !      This file is part of PLplot.
 !
 !      PLplot is free software; you can redistribute it and/or modify
-!      it under the terms of the GNU General Library Public License as
+!      it under the terms of the GNU Library General Public License as
 !      published by the Free Software Foundation; either version 2 of the
 !      License, or (at your option) any later version.
 !
@@ -179,14 +179,14 @@
 
 !      shielded potential contour plot example
       subroutine potential()
-      use plplot
+      use plplot, TWOPI => PL_TWOPI
       implicit none
 
       integer NCX, NCY, NPLT, i, j, nx, ny, kx, lx, ky, ly, &
         nlevel, ilevgt, ilevlt, nlevlt, nlevgt, &
         ncollin, ncolbox, ncollab, &
         nxsub, nysub, xdim, ydim
-      real(kind=plflt) TWOPI, r, theta, rmax, x0, &
+      real(kind=plflt) r, theta, rmax, x0, &
         y0, xmin, xmax, eps, q1, d1, &
         ymin, ymax, &
         q1i, d1i, q2, d2, q2i, d2i, div1, div1i, div2, div2i, &
@@ -196,7 +196,6 @@
 !      NCX and NCY are associated with the part of the
 !      2D arrays that are defined.
       parameter (xdim=99, NCX=40, ydim=100, NCY=64, NPLT=100)
-      parameter (TWOPI=6.2831853071795864768_plflt)
 
       real(kind=plflt) z(xdim, ydim), ztmp(xdim, ydim+1)
       real(kind=plflt) xg(xdim, ydim+1), yg(xdim, ydim+1), xtm(NPLT), ytm(NPLT)
