@@ -1,11 +1,11 @@
-!      $Id: x18f.f90 6572 2006-05-16 20:24:14Z airwin $
+!      $Id: x18f.f90 11680 2011-03-27 17:57:51Z airwin $
 !
 !      Copyright (C) 2004  Alan W. Irwin
 !
 !      This file is part of PLplot.
 !
 !      PLplot is free software; you can redistribute it and/or modify
-!      it under the terms of the GNU General Library Public License as
+!      it under the terms of the GNU Library General Public License as
 !      published by the Free Software Foundation; either version 2 of the
 !      License, or (at your option) any later version.
 !
@@ -87,7 +87,8 @@
         if ( opt(k).gt. 0 ) then
           call plline3(x, y, z)
         else
-          call plpoin3(x, y, z, 1)
+          !U+22C5 DOT OPERATOR.
+          call plstring3( x, y, z, "⋅" )
         endif
 
         call plcol0(3)
@@ -102,15 +103,13 @@
       end
 
       subroutine test_poly(k, alt, az)
-      use plplot, PI => PL_PI
+      use plplot, PI => PL_PI, TWOPI => PL_TWOPI
       implicit none
       integer k
       real(kind=plflt) alt, az
 
       real(kind=plflt) x(5), y(5), z(5)
       integer i, j
-      real(kind=plflt) two_pi
-      parameter ( two_pi = 2.0_plflt*pi                )
       logical draw(4,4)
       DATA draw / &
         .true., .true., .true., .true., &
@@ -119,8 +118,8 @@
         .true., .true., .false., .false. /
       real(kind=plflt) theta, phi
       integer ia
-      THETA(ia) = (two_pi * (ia) /20._plflt)
-      PHI(ia)   = (pi * (ia) / 20.1_plflt)
+      THETA(ia) = (TWOPI * (ia) /20._plflt)
+      PHI(ia)   = (PI * (ia) / 20.1_plflt)
 
       call pladv(0)
       call plvpor(0.0_plflt, 1.0_plflt, 0.0_plflt, 0.9_plflt)
