@@ -1,4 +1,4 @@
-!      $Id: x21f.f90 10618 2009-11-20 19:17:35Z airwin $
+!      $Id: x21f.f90 11680 2011-03-27 17:57:51Z airwin $
 !      Grid data demo.
 !
 !      Copyright (C) 2004  Joao Cardoso
@@ -7,7 +7,7 @@
 !      This file is part of PLplot.
 !
 !      PLplot is free software; you can redistribute it and/or modify
-!      it under the terms of the GNU General Library Public License as
+!      it under the terms of the GNU Library General Public License as
 !      published by the Free Software Foundation; either version 2 of the
 !      License, or (at your option) any later version.
 !
@@ -24,23 +24,6 @@
 
       implicit none
 
-!       integer PL_PARSE_FULL
-!       parameter(PL_PARSE_FULL = 1)
-      
-      integer GRID_CSA, GRID_DTLI, GRID_NNI, GRID_NNIDW, GRID_NNLI, &
-           GRID_NNAIDW
-      parameter (GRID_CSA = 1)
-      parameter (GRID_DTLI = 2)
-      parameter (GRID_NNI = 3)
-      parameter (GRID_NNIDW = 4)
-      parameter (GRID_NNLI = 5)
-      parameter (GRID_NNAIDW = 6)
-
-      integer DRAW_LINEXY, MAG_COLOR, BASE_CONT
-      parameter(DRAW_LINEXY = 3)
-      parameter(MAG_COLOR = 4)
-      parameter(BASE_CONT = 8)
-      
       external myisnan
       logical myisnan
 
