@@ -1,8 +1,8 @@
-//---------------------------------------------------------------------------//
-// $Id: x03.java 10785 2010-01-31 20:05:17Z hezekiahcarty $
-//---------------------------------------------------------------------------//
+//--------------------------------------------------------------------------
+// $Id: x03.java 11682 2011-03-31 02:55:49Z airwin $
+//--------------------------------------------------------------------------
 
-//---------------------------------------------------------------------------//
+//--------------------------------------------------------------------------
 // Copyright (C) 2001  Geoffrey Furnish
 // Copyright (C) 2001, 2002  Alan W. Irwin
 // Copyright (C) 2004  Andrew Ross
@@ -21,11 +21,11 @@
 // You should have received a copy of the GNU Library General Public License
 // along with PLplot; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
-//---------------------------------------------------------------------------//
+//--------------------------------------------------------------------------
 
-//---------------------------------------------------------------------------//
+//--------------------------------------------------------------------------
 // Implementation of PLplot example 3 in Java.
-//---------------------------------------------------------------------------//
+//--------------------------------------------------------------------------
 
 package plplot.examples;
 
@@ -77,7 +77,7 @@ class x03 {
         pls.env( -1.3, 1.3, -1.3, 1.3, 1, -2 );
         for ( i = 1; i <= 10; i++ )
         {
-            pls.arc( 0.0, 0.0, 0.1 * i, 0.1 * i, 0.0, 360.0, false );
+            pls.arc( 0.0, 0.0, 0.1 * i, 0.1 * i, 0.0, 360.0, 0.0, false );
         }
 
         pls.col0( 2 );
@@ -134,6 +134,6 @@ class x03 {
     }
 }
 
-//---------------------------------------------------------------------------//
+//--------------------------------------------------------------------------
 //                              End of x03.java
-//---------------------------------------------------------------------------//
+//--------------------------------------------------------------------------
