@@ -1,9 +1,9 @@
-//---------------------------------------------------------------------------//
-// $Id: x26.java 10785 2010-01-31 20:05:17Z hezekiahcarty $
+//--------------------------------------------------------------------------
+// $Id: x26.java 11717 2011-04-21 00:47:06Z airwin $
 // Multi-lingual version of the first page of example 4.
-//---------------------------------------------------------------------------//
+//--------------------------------------------------------------------------
 
-//---------------------------------------------------------------------------//
+//--------------------------------------------------------------------------
 // Copyright (C) 2006  Alan W. Irwin
 // Copyright (C) 2006  Andrew Ross
 //
@@ -24,7 +24,7 @@
 // You should have received a copy of the GNU Library General Public License
 // along with PLplot; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
-//---------------------------------------------------------------------------//
+//--------------------------------------------------------------------------
 
 //  This example designed just for devices (e.g., psttfc and the
 //  cairo-related devices) that use the pango and fontconfig libraries. The
@@ -57,9 +57,9 @@
 //  (5) decade represents a factor of 10, see
 //      http://en.wikipedia.org/wiki/Decade_(log_scale) .
 
-//---------------------------------------------------------------------------//
+//--------------------------------------------------------------------------
 // Implementation of PLplot example 26 in Java.
-//---------------------------------------------------------------------------//
+//--------------------------------------------------------------------------
 
 package plplot.examples;
 
@@ -85,12 +85,18 @@ class x26 {
         "Фазовый сдвиг (градусы)"
     };
 
-    static   String[] title_label = {
+    // Short rearranged versions of y_label and alty_label.
+    static String[][] legend_text = {
+        { "Amplitude",          "Phase shift"               },
+        { "Амплитуда", "Фазовый сдвиг" }
+    };
+
+    static String[] title_label = {
         "Single Pole Low-Pass Filter",
         "Однополюсный Низко-Частотный Фильтр"
     };
 
-    static   String[] line_label = {
+    static String[] line_label = {
         "-20 dB/decade",
         "-20 dB/десяток"
     };
@@ -126,8 +132,8 @@ class x26 {
 
         for ( i = 0; i < nlang; i++ )
         {
-            plot1( 0, x_label[i], y_label[i], alty_label[i], title_label[i],
-                line_label[i] );
+            plot1( 0, x_label[i], y_label[i], alty_label[i],
+                legend_text[i], title_label[i], line_label[i] );
         }
 
         pls.end();
@@ -136,13 +142,25 @@ class x26 {
 // Log-linear plot.
 
     void plot1( int type, String x_label, String y_label, String alty_label,
-                String title_label, String line_label )
+                String[] legend_text, String title_label, String line_label )
     {
         int i;
         double[] freql = new double[101];
         double[] ampl  = new double[101];
         double[] phase = new double[101];
         double f0, freq;
+        int    nlegend = 2;
+        int[] opt_array        = new int[2];
+        int[] text_colors      = new int[2];
+        int[] line_colors      = new int[2];
+        int[] line_styles      = new int[2];
+        int[] line_widths      = new int[2];
+        int[] symbol_numbers   = new int[2];
+        int[] symbol_colors    = new int[2];
+        double[] symbol_scales = new double[2];
+        String[] symbols       = new String[2];
+        double[] legend_width  = new double[1];
+        double[] legend_height = new double[1];
 
         pls.adv( 0 );
 
@@ -178,7 +196,7 @@ class x26 {
 
         pls.col0( 2 );
         pls.line( freql, ampl );
-        pls.col0( 1 );
+        pls.col0( 2 );
         pls.ptex( 1.6, -30.0, 1.0, -20.0, 0.5, line_label );
 
         // Put labels on.
@@ -198,12 +216,49 @@ class x26 {
             pls.box( "", 0.0, 0, "cmstv", 30.0, 3 );
             pls.col0( 3 );
             pls.line( freql, phase );
+            pls.string( freql, phase, "*" );
             pls.col0( 3 );
             pls.mtex( "r", 5.0, 0.5, 0.5, alty_label );
         }
+        // Draw a legend
+        // First legend entry.
+        opt_array[0]   = PLStream.PL_LEGEND_LINE;
+        text_colors[0] = 2;
+        line_colors[0] = 2;
+        line_styles[0] = 1;
+        line_widths[0] = 1;
+        // note from the above opt_array the first symbol (and box) indices
+        // do not have to be specified EXCEPT for symbols.
+        // Although this is unused, it can't be undefined as the String
+        // array is copied as part of the java bindings.
+        symbols[0] = "";
+
+        // Second legend entry.
+        opt_array[1]      = PLStream.PL_LEGEND_LINE | PLStream.PL_LEGEND_SYMBOL;
+        text_colors[1]    = 3;
+        line_colors[1]    = 3;
+        line_styles[1]    = 1;
+        line_widths[1]    = 1;
+        symbol_colors[1]  = 3;
+        symbol_scales[1]  = 1.;
+        symbol_numbers[1] = 4;
+        symbols[1]        = "*";
+        // from the above opt_arrays we can completely ignore everything
+        // to do with boxes.
+
+        pls.scol0a( 15, 32, 32, 32, 0.70 );
+        pls.legend( legend_width, legend_height,
+            PLStream.PL_LEGEND_BACKGROUND | PLStream.PL_LEGEND_BOUNDING_BOX, 0,
+            0.0, 0.0, 0.10, 15,
+            1, 1, 0, 0, opt_array,
+            1.0, 1.0, 2.0,
+            1., text_colors, legend_text,
+            null, null, null, null,
+            line_colors, line_styles, line_widths,
+            symbol_colors, symbol_scales, symbol_numbers, symbols );
     }
 }
 
-//---------------------------------------------------------------------------//
+//--------------------------------------------------------------------------
 //                              End of x26.java
-//---------------------------------------------------------------------------//
+//--------------------------------------------------------------------------
