@@ -1,4 +1,4 @@
-(* $Id: x16.ml 10303 2009-08-20 00:10:20Z hezekiahcarty $
+(* $Id: x16.ml 10524 2009-10-11 23:07:19Z hezekiahcarty $
 
         plshade demo, using color fill.
 
@@ -56,7 +56,7 @@ let () =
   let cont_width = 0 in
 
   (* Parse and process command line arguments *)
-  ignore (plparseopts Sys.argv [PL_PARSE_FULL]);
+  plparseopts Sys.argv [PL_PARSE_FULL];
 
   (* Load color palettes *)
   plspal0 "cmap0_black_on_white.pal";
@@ -131,7 +131,7 @@ let () =
 
   plpsty 0;
 
-  plshades z (-1.0) 1.0 (-1.0) 1.0 shedge fill_width cont_color cont_width 1;
+  plshades z (-1.0) 1.0 (-1.0) 1.0 shedge fill_width cont_color cont_width true;
 
   plcol0 1;
   plbox "bcnst" 0.0 0 "bcnstv" 0.0 0;
@@ -150,8 +150,8 @@ let () =
 
   plpsty 0;
 
-  plset_pltr (fun x y -> pltr1 x y xg1 yg1);
-  plshades z (-1.0) 1.0 (-1.0) 1.0 shedge fill_width cont_color cont_width 1;
+  plset_pltr (pltr1 xg1 yg1);
+  plshades z (-1.0) 1.0 (-1.0) 1.0 shedge fill_width cont_color cont_width true;
 
   plcol0 1;
   plbox "bcnst" 0.0 0 "bcnstv" 0.0 0;
@@ -170,8 +170,9 @@ let () =
 
   plpsty 0;
 
-  plset_pltr (fun x y -> pltr2 x y xg2 yg2);
-  plshades z (-1.0) 1.0 (-1.0) 1.0 shedge fill_width cont_color cont_width 0;
+  plset_pltr (pltr2 xg2 yg2);
+  plshades
+    z (-1.0) 1.0 (-1.0) 1.0 shedge fill_width cont_color cont_width false;
 
   plcol0 1;
   plbox "bcnst" 0.0 0 "bcnstv" 0.0 0;
@@ -192,7 +193,7 @@ let () =
 
   plpsty 0;
 
-  plshades z (-1.0) 1.0 (-1.) 1.0 shedge fill_width 2 3 0;
+  plshades z (-1.0) 1.0 (-1.) 1.0 shedge fill_width 2 3 false;
 
   plcol0 1;
   plbox "bcnst" 0.0 0 "bcnstv" 0.0 0;
@@ -211,7 +212,8 @@ let () =
     plpsty 0;
 
     plset_defined zdefined;
-    plshades z (-1.0) 1.0 (-1.0) 1.0 shedge fill_width cont_color cont_width 0;
+    plshades
+      z (-1.0) 1.0 (-1.0) 1.0 shedge fill_width cont_color cont_width false;
     plunset_defined ();
 
     plcol0 1;
@@ -252,7 +254,8 @@ let () =
   in
 
   (*  Now we can shade the interior region. *)
-  plshades z (-1.0) 1.0 (-1.0) 1.0 shedge fill_width cont_color cont_width 0;
+  plshades
+    z (-1.0) 1.0 (-1.0) 1.0 shedge fill_width cont_color cont_width false;
 
   (* Now we can draw the perimeter.  (If do before, shade stuff may overlap.) *)
   let px = Array.make perimeterpts 0.0 in
