@@ -10,8 +10,8 @@ demo.py - Demonstrates the simplest use of the plplot canvas widget with gtk.
   Dalhousie University, Halifax, Nova Scotia, Canada, B3H 3J5
 
   $Author: airwin $
-  $Revision: 9083 $
-  $Date: 2008-12-10 16:12:20 -0500 (Wed, 10 Dec 2008) $
+  $Revision: 10568 $
+  $Date: 2009-11-09 19:05:09 -0500 (Mon, 09 Nov 2009) $
   $Name$
 
 
@@ -44,7 +44,7 @@ HEIGHT = 600 # 300
 
 # Delete event callback
 def delete_event(widget, event, data=None):
-    return gtk.FALSE
+    return False
 
 # Destroy event calback
 def destroy(widget, data=None):
