@@ -1,4 +1,4 @@
-# $Id: x19.tcl 11026 2010-05-27 09:56:37Z andrewross $
+# $Id: x19.tcl 11680 2011-03-27 17:57:51Z airwin $
 #
 #      Copyright (C) 2002  Alan W. Irwin
 #      Copyright (C) 2009  Arjen Markus
@@ -7,7 +7,7 @@
 #      This file is part of PLplot.
 #
 #      PLplot is free software; you can redistribute it and/or modify
-#      it under the terms of the GNU General Library Public License as
+#      it under the terms of the GNU Library General Public License as
 #      published by the Free Software Foundation; either version 2 of the
 #      License, or (at your option) any later version.
 #
@@ -44,7 +44,7 @@ proc map_transform { x y } {
 
 proc mapform19 {n matx maty} {
 
-    set deg_to_rad [expr {acos(-1.0)/180.0}]
+    set deg_to_rad [expr {$::PLPLOT::PL_PI/180.0}]
 
     for {set i 0} {$i < $n} {incr i} {
         set x      [$matx $i]
@@ -180,7 +180,7 @@ proc x19 {{w loopback}} {
 
     $w cmd plssym 0. 1.
     $w cmd plptex -76.6125 43. 0.0 0.0 0.0 "Baltimore, MD"
-  
+
     $w cmd plstransform NULL
 
     $w cmd pllsty 1
