@@ -1,4 +1,4 @@
-# $Id: x20.tcl 10225 2009-08-09 18:39:45Z airwin $
+# $Id: x20.tcl 11680 2011-03-27 17:57:51Z airwin $
 #
 #      Copyright (C) 2004  Alan W. Irwin
 #      Copyright (C) 2008  Arjen Markus
@@ -7,7 +7,7 @@
 #      This file is part of PLplot.
 #
 #      PLplot is free software; you can redistribute it and/or modify
-#      it under the terms of the GNU General Library Public License as
+#      it under the terms of the GNU Library General Public License as
 #      published by the Free Software Foundation; either version 2 of the
 #      License, or (at your option) any later version.
 #
@@ -70,7 +70,7 @@
 
 proc x20 {{w loopback}} {
 
-    set PI   [expr {4.0*atan(1.0)}]
+    set PI   $::PLPLOT::PL_PI
 
     set XDIM 260
     set YDIM 220
@@ -241,7 +241,7 @@ proc x20 {{w loopback}} {
 
     a2mnmx img_f $width $height img_min img_max
 
-    $w cmd plcol 2
+    $w cmd plcol0 2
     $w cmd plenv 0. $width 0. $height 1 -1
     $w cmd pllab "" "" "Reduced dynamic range image example"
     $w cmd plimagefr img_f 0. $width 0. $height 0. 0. \
