@@ -1,19 +1,7 @@
-/* $Id: stndfont.c 10785 2010-01-31 20:05:17Z hezekiahcarty $
- * $Log$
- * Revision 1.10  2000/12/18 21:01:49  airwin
- * Change to new style plplot/*.h header file locations.
- *
- * Revision 1.9  1995/04/12 08:20:13  mjl
- * Eliminated SCHAR in favor of simply "signed char".
- *
- * Revision 1.8  1994/08/25  04:02:57  mjl
- * Cleaned up header file inclusion.
- */
-
-/*	stndfont.c
- *
- *      Utility to generate standard font set.
- */
+// $Id: stndfont.c 11289 2010-10-29 20:44:17Z airwin $
+//
+//      Utility to generate standard font set.
+//
 
 #include "plplotP.h"
 
@@ -46,11 +34,11 @@ main( int argc, char **argv )
     for ( k = 0; k < 176; k++ )
         hrshlst[ib++] = *( hersh[0] + k );
 
-/* Sort list */
+// Sort list
 
     qsort( (char *) hrshlst, ib, sizeof ( short ), compare );
 
-/* Remove duplicates */
+// Remove duplicates
 
     k = 0;
     j = 0;
@@ -64,7 +52,7 @@ main( int argc, char **argv )
 
     nstd = k + 1;
 
-/* Now reindex the fonts */
+// Now reindex the fonts
 
     for ( k = 0; k < 176; k++ )
         for ( i = 0; i < nstd; i++ )
@@ -123,8 +111,8 @@ main( int argc, char **argv )
 
     nchars = 0;
     nleng  = 1;
-    fseek( pdfs->file, 0, 2 );            /* Go to end of file */
-    fpos = ftell( pdfs->file );           /* Save current position */
+    fseek( pdfs->file, 0, 2 );            // Go to end of file
+    fpos = ftell( pdfs->file );           // Save current position
     pdf_wr_2bytes( pdfs, nleng );
 
     for ( j = 0; j < nstd; j++ )
