@@ -1,56 +1,56 @@
-/*
- *
- * This software is provided under the LGPL in March 2009 by the
- * Cluster Science Centre
- * QSAS team,
- * Imperial College, London
- *
- * Copyright (C) 2009  Imperial College, London
- * Copyright (C) 2009  Alan W. Irwin
- *
- * This is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Lesser Public License as published
- * by the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This software is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License for more details.
- *
- * To received a copy of the GNU Library General Public License
- * write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
- *
- *  History:
- *
- *
- * March 2009:  v1.00
- * Initial release.
- *
- */
+//
+//
+// This software is provided under the LGPL in March 2009 by the
+// Cluster Science Centre
+// QSAS team,
+// Imperial College, London
+//
+// Copyright (C) 2009  Imperial College, London
+// Copyright (C) 2009  Alan W. Irwin
+//
+// This is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Lesser Public License as published
+// by the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+//
+// This software is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// To received a copy of the GNU Library General Public License
+// write to the Free Software Foundation, Inc.,
+// 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+//
+//  History:
+//
+//
+// March 2009:  v1.00
+// Initial release.
+//
+//
 
-/*
- * Interpretation of the -geometry XSIZExYSIZE option (or the third and fourth
- * parameters of plspage if those are specified by the user instead) for
- * the various devices:
- * - the raster devices (bmpqt, jpgqt, pngqt, ppmqt, tiffqt):
- * XSIZE and YSIZE define the x and y size in pixels
- * - qtwidget:
- * XSIZE and YSIZE define the default x and y size of the widget in
- * pixels, as well as its aspect ratio, which is kept when the widget is
- * resized.
- * - svgqt, epsqt, pdfqt:
- * XSIZE and YSIZE define the x and y size in points (1/72 of inches).
- * EPS and PDF files will be drawn in A4 pages for Qt versions before 4.4
- *
- * Interpretation of the -dpi DPI option (or the first parameter of
- * plspage if that is specified by the user instead).
- * DPI is ignored for all but the raster devices.  For those devices
- * DPI should be set to the DPI value of the monitor being used to view
- * the results if exact character sizes are desired.  Otherwise, DEFAULT_DPI
- * (set to an average value for modern monitors) is used instead.
- */
+//
+// Interpretation of the -geometry XSIZExYSIZE option (or the third and fourth
+// parameters of plspage if those are specified by the user instead) for
+// the various devices:
+// - the raster devices (bmpqt, jpgqt, pngqt, ppmqt, tiffqt):
+// XSIZE and YSIZE define the x and y size in pixels
+// - qtwidget:
+// XSIZE and YSIZE define the default x and y size of the widget in
+// pixels, as well as its aspect ratio, which is kept when the widget is
+// resized.
+// - svgqt, epsqt, pdfqt:
+// XSIZE and YSIZE define the x and y size in points (1/72 of inches).
+// EPS and PDF files will be drawn in A4 pages for Qt versions before 4.4
+//
+// Interpretation of the -dpi DPI option (or the first parameter of
+// plspage if that is specified by the user instead).
+// DPI is ignored for all but the raster devices.  For those devices
+// DPI should be set to the DPI value of the monitor being used to view
+// the results if exact character sizes are desired.  Otherwise, DEFAULT_DPI
+// (set to an average value for modern monitors) is used instead.
+//
 
 #ifndef QT_H
 #define QT_H
@@ -124,6 +124,7 @@ public:
 
     void setPLStream( PLStream *pls );  // store the related stream
 
+    virtual void drawArc( short x, short y, short width, short height, PLFLT angle1, PLFLT angle2, PLFLT rotate, bool fill );
     // Draws a line from (x1, y1) to (x2, y2) in internal plplot coordinates
     virtual void drawLine( short x1, short y1, short x2, short y2 );
     virtual void drawPolyline( short * x, short * y, PLINT npts );
@@ -169,7 +170,7 @@ class PLDLLIMPEXP_QT QtRasterDevice : public QtPLDriver, public QImage
 {
 public:
     QtRasterDevice( int i_iWidth = QT_DEFAULT_X,
-        int i_iHeight = QT_DEFAULT_Y );
+                    int i_iHeight = QT_DEFAULT_Y );
     virtual ~QtRasterDevice();
 
     virtual void setBackgroundColor( int r, int g, int b, double alpha );
@@ -180,6 +181,8 @@ public:
         setDotsPerMeterX( (int) ( ( dotsPerInch / 25.4 ) * 1000. ) );
         setDotsPerMeterY( (int) ( ( dotsPerInch / 25.4 ) * 1000. ) );
     }
+    // used by the memqt driver
+    unsigned char *memory;
 
 protected:
     char    format[5];
@@ -194,7 +197,7 @@ class PLDLLIMPEXP_QT QtSVGDevice : public QtPLDriver, public QSvgGenerator
 {
 public:
     QtSVGDevice( int i_iWidth = QT_DEFAULT_X,
-        int i_iHeight = QT_DEFAULT_Y );
+                 int i_iHeight = QT_DEFAULT_Y );
 
     virtual ~QtSVGDevice();
 
@@ -241,7 +244,8 @@ typedef enum ElementType_
     SET_GRADIENT,
     SET_SMOOTH,
     TEXT,
-    SET_BG_COLOUR
+    SET_BG_COLOUR,
+    ARC
 } ElementType; // Identifiers for elements of the buffer
 
 struct ColourStruct_
@@ -267,6 +271,15 @@ struct TextStruct_
     PLFLT     chrht;
 };
 
+struct ArcStruct_
+{
+    QRectF  *rect;
+    QPointF *dx;
+    int     startAngle;
+    int     spanAngle;
+    PLFLT   rotate;
+    bool    fill;
+};
 
 class BufferElement
 {
@@ -281,6 +294,7 @@ public:
         QLinearGradient     * LinearGradient;
         struct ColourStruct_* ColourStruct;
         struct TextStruct_  * TextStruct;
+        struct ArcStruct_   * ArcStruct;
         PLINT intParam;
         PLFLT fltParam;
     } Data;
@@ -305,6 +319,7 @@ public:
 
     int pageNumber;
 
+    void drawArc( short x, short y, short width, short height, PLFLT angle1, PLFLT angle2, PLFLT rotate, bool fill );
     void drawLine( short x1, short y1, short x2, short y2 );
     void drawPolyline( short * x, short * y, PLINT npts );
     void drawPolygon( short * x, short * y, PLINT npts );
