@@ -1,18 +1,18 @@
-/******************************************************************************
- *
- * File:           hash.c
- *
- * Purpose:        Hash table implementation
- *
- * Author:         Jerry Coffin
- *
- * Description:    Public domain code by Jerry Coffin, with improvements by
- *                 HenkJan Wolthuis.
- *                 Date last modified: 05-Jul-1997
- *
- * Revisions:      18-09-2002 -- modified by Pavel Sakov
- *
- *****************************************************************************/
+//--------------------------------------------------------------------------
+//
+// File:           hash.c
+//
+// Purpose:        Hash table implementation
+//
+// Author:         Jerry Coffin
+//
+// Description:    Public domain code by Jerry Coffin, with improvements by
+//                 HenkJan Wolthuis.
+//                 Date last modified: 05-Jul-1997
+//
+// Revisions:      18-09-2002 -- modified by Pavel Sakov
+//
+//--------------------------------------------------------------------------
 
 #include <string.h>
 #include <stdlib.h>
@@ -21,34 +21,34 @@
 
 #define INT_PER_DOUBLE    2
 
-/** A hash table consists of an array of these buckets.
- */
+//* A hash table consists of an array of these buckets.
+//
 typedef struct ht_bucket
 {
     void * key;
     void            * data;
-    int  id;                    /* unique id -- just in case */
+    int  id;                    // unique id -- just in case
     struct ht_bucket* next;
 } ht_bucket;
 
-/** Hash table structure.
- * Note that more nodes than `size' can be inserted in the table,
- * but performance degrades as this happens.
- */
+//* Hash table structure.
+// Note that more nodes than `size' can be inserted in the table,
+// but performance degrades as this happens.
+//
 struct hashtable
 {
-    int         size;           /* table size */
-    int         n;              /* current number of entries */
-    int         naccum;         /* number of inserted entries */
-    int         nhash;          /* number of used table elements */
+    int         size;           // table size
+    int         n;              // current number of entries
+    int         naccum;         // number of inserted entries
+    int         nhash;          // number of used table elements
     ht_keycp    cp;
     ht_keyeq    eq;
     ht_key2hash hash;
     ht_bucket   ** table;
 };
 
-/* Creates a hashtable of specified size.
- */
+// Creates a hashtable of specified size.
+//
 hashtable* ht_create( int size, ht_keycp cp, ht_keyeq eq, ht_key2hash hash )
 {
     hashtable* table = malloc( sizeof ( hashtable ) );
@@ -56,9 +56,9 @@ hashtable* ht_create( int size, ht_keycp cp, ht_keyeq eq, ht_key2hash hash )
     int      i;
 
     assert( sizeof ( double ) == INT_PER_DOUBLE * sizeof ( int ) );
-    /*
-     * (used in d1hash() and d2hash())
-     */
+    //
+    // (used in d1hash() and d2hash())
+    //
 
     if ( table == NULL )
         return NULL;
@@ -91,12 +91,12 @@ hashtable* ht_create( int size, ht_keycp cp, ht_keyeq eq, ht_key2hash hash )
     return table;
 }
 
-/* Destroys a hash table.
- * (Take care of deallocating data by ht_process() prior to destroying the
- * table if necessary.)
- *
- * @param table Hash table to be destroyed
- */
+// Destroys a hash table.
+// (Take care of deallocating data by ht_process() prior to destroying the
+// table if necessary.)
+//
+// @param table Hash table to be destroyed
+//
 void ht_destroy( hashtable* table )
 {
     int i;
@@ -122,24 +122,24 @@ void ht_destroy( hashtable* table )
     free( table );
 }
 
-/* Inserts a new entry into the hash table.
- *
- * @param table The hash table
- * @param key Ponter to entry's key
- * @param data Pointer to associated data
- * @return Pointer to the old data associated with the key, NULL if the key
- *         wasn't in the table previously
- */
+// Inserts a new entry into the hash table.
+//
+// @param table The hash table
+// @param key Ponter to entry's key
+// @param data Pointer to associated data
+// @return Pointer to the old data associated with the key, NULL if the key
+//         wasn't in the table previously
+//
 void* ht_insert( hashtable* table, void* key, void* data )
 {
     unsigned int val = table->hash( key ) % table->size;
     ht_bucket    * bucket;
 
-    /*
-     * NULL means this bucket hasn't been used yet.  We'll simply allocate
-     * space for our new bucket and put our data there, with the table
-     * pointing at it.
-     */
+    //
+    // NULL means this bucket hasn't been used yet.  We'll simply allocate
+    // space for our new bucket and put our data there, with the table
+    // pointing at it.
+    //
     if ( ( table->table )[val] == NULL )
     {
         bucket = malloc( sizeof ( ht_bucket ) );
@@ -159,10 +159,10 @@ void* ht_insert( hashtable* table, void* key, void* data )
         return bucket->data;
     }
 
-    /*
-     * This spot in the table is already in use.  See if the current string
-     * has already been inserted, and if so, return corresponding data.
-     */
+    //
+    // This spot in the table is already in use.  See if the current string
+    // has already been inserted, and if so, return corresponding data.
+    //
     for ( bucket = ( table->table )[val]; bucket != NULL; bucket = bucket->next )
         if ( table->eq( key, bucket->key ) == 1 )
         {
@@ -175,15 +175,15 @@ void* ht_insert( hashtable* table, void* key, void* data )
             return old_data;
         }
 
-    /*
-     * This key must not be in the table yet.  We'll add it to the head of
-     * the list at this spot in the hash table.  Speed would be slightly
-     * improved if the list was kept sorted instead.  In this case, this
-     * code would be moved into the loop above, and the insertion would take
-     * place as soon as it was determined that the present key in the list
-     * was larger than this one.
-     */
-    bucket = (ht_bucket*) malloc( sizeof ( ht_bucket ) );
+    //
+    // This key must not be in the table yet.  We'll add it to the head of
+    // the list at this spot in the hash table.  Speed would be slightly
+    // improved if the list was kept sorted instead.  In this case, this
+    // code would be moved into the loop above, and the insertion would take
+    // place as soon as it was determined that the present key in the list
+    // was larger than this one.
+    //
+    bucket = (ht_bucket *) malloc( sizeof ( ht_bucket ) );
     if ( bucket == NULL )
         return 0;
     bucket->key  = table->cp( key );
@@ -198,13 +198,13 @@ void* ht_insert( hashtable* table, void* key, void* data )
     return data;
 }
 
-/* Returns a pointer to the data associated with a key.  If the key has
- * not been inserted in the table, returns NULL.
- *
- * @param table The hash table
- * @param key The key
- * @return The associated data or NULL
- */
+// Returns a pointer to the data associated with a key.  If the key has
+// not been inserted in the table, returns NULL.
+//
+// @param table The hash table
+// @param key The key
+// @return The associated data or NULL
+//
 void* ht_find( hashtable* table, void* key )
 {
     unsigned int val = table->hash( key ) % table->size;
@@ -220,14 +220,14 @@ void* ht_find( hashtable* table, void* key )
     return NULL;
 }
 
-/* Deletes an entry from the table.  Returns a pointer to the data that
- * was associated with the key so that the calling code can dispose it
- * properly.
- *
- * @param table The hash table
- * @param key The key
- * @return The associated data or NULL
- */
+// Deletes an entry from the table.  Returns a pointer to the data that
+// was associated with the key so that the calling code can dispose it
+// properly.
+//
+// @param table The hash table
+// @param key The key
+// @return The associated data or NULL
+//
 void* ht_delete( hashtable* table, void* key )
 {
     unsigned int val = table->hash( key ) % table->size;
@@ -238,13 +238,13 @@ void* ht_delete( hashtable* table, void* key )
     if ( ( table->table )[val] == NULL )
         return NULL;
 
-    /*
-     * Traverse the list, keeping track of the previous node in the list.
-     * When we find the node to delete, we set the previous node's next
-     * pointer to point to the node after ourself instead.  We then delete
-     * the key from the present node, and return a pointer to the data it
-     * contains.
-     */
+    //
+    // Traverse the list, keeping track of the previous node in the list.
+    // When we find the node to delete, we set the previous node's next
+    // pointer to point to the node after ourself instead.  We then delete
+    // the key from the present node, and return a pointer to the data it
+    // contains.
+    //
     for ( prev = NULL, bucket = ( table->table )[val]; bucket != NULL; prev = bucket, bucket = bucket->next )
     {
         if ( table->eq( key, bucket->key ) == 1 )
@@ -254,13 +254,13 @@ void* ht_delete( hashtable* table, void* key )
                 prev->next = bucket->next;
             else
             {
-                /*
-                 * If 'prev' still equals NULL, it means that we need to
-                 * delete the first node in the list. This simply consists
-                 * of putting our own 'next' pointer in the array holding
-                 * the head of the list.  We then dispose of the current
-                 * node as above.
-                 */
+                //
+                // If 'prev' still equals NULL, it means that we need to
+                // delete the first node in the list. This simply consists
+                // of putting our own 'next' pointer in the array holding
+                // the head of the list.  We then dispose of the current
+                // node as above.
+                //
                 ( table->table )[val] = bucket->next;
                 table->nhash--;
             }
@@ -272,19 +272,19 @@ void* ht_delete( hashtable* table, void* key )
         }
     }
 
-    /*
-     * If we get here, it means we didn't find the item in the table. Signal
-     * this by returning NULL.
-     */
+    //
+    // If we get here, it means we didn't find the item in the table. Signal
+    // this by returning NULL.
+    //
     return NULL;
 }
 
-/* For each entry, calls a specified function with corresponding data as a
- * parameter.
- *
- * @param table The hash table
- * @param func The action function
- */
+// For each entry, calls a specified function with corresponding data as a
+// parameter.
+//
+// @param table The hash table
+// @param func The action function
+//
 void ht_process( hashtable* table, void ( *func )( void* ) )
 {
     int i;
@@ -299,18 +299,18 @@ void ht_process( hashtable* table, void ( *func )( void* ) )
         }
 }
 
-/*
- * functions for for string keys
- */
+//
+// functions for for string keys
+//
 
 static unsigned int strhash( void* key )
 {
-    char         * str     = (char*) key;
+    char         * str     = (char *) key;
     unsigned int hashvalue = 0;
 
     while ( *str != 0 )
     {
-        hashvalue  ^= *(unsigned int*) str;
+        hashvalue  ^= *(unsigned int *) str;
         hashvalue <<= 1;
         str++;
     }
@@ -328,11 +328,11 @@ static int streq( void* key1, void* key2 )
     return !strcmp( key1, key2 );
 }
 
-/* functions for for double keys */
+// functions for for double keys
 
 static unsigned int d1hash( void* key )
 {
-    unsigned int* v = (unsigned int*) key;
+    unsigned int* v = (unsigned int *) key;
 
 #if INT_PER_DOUBLE == 2
     return v[0] + v[1];
@@ -345,31 +345,31 @@ static void* d1cp( void* key )
 {
     double* newkey = malloc( sizeof ( double ) );
 
-    *newkey = *(double*) key;
+    *newkey = *(double *) key;
 
     return newkey;
 }
 
 int d1eq( void* key1, void* key2 )
 {
-    return *(double*) key1 == *(double*) key2;
+    return *(double *) key1 == *(double *) key2;
 }
 
-/*
- * functions for for double[2] keys
- */
+//
+// functions for for double[2] keys
+//
 
 #include "math.h"
 
 static unsigned int d2hash( void* key )
 {
-    unsigned int* v = (unsigned int*) key;
+    unsigned int* v = (unsigned int *) key;
 
 #if INT_PER_DOUBLE == 2
-    /*
-     * PS: here multiplications suppose to make (a,b) and (b,a) generate
-     * different hash values
-     */
+    //
+    // PS: here multiplications suppose to make (a,b) and (b,a) generate
+    // different hash values
+    //
     return v[0] + v[1] + v[2] * 3 + v[3] * 7;
 #else
 #error not implemented
@@ -380,15 +380,15 @@ static void* d2cp( void* key )
 {
     double* newkey = malloc( sizeof ( double ) * 2 );
 
-    newkey[0] = ( (double*) key )[0];
-    newkey[1] = ( (double*) key )[1];
+    newkey[0] = ( (double *) key )[0];
+    newkey[1] = ( (double *) key )[1];
 
     return newkey;
 }
 
 static int d2eq( void* key1, void* key2 )
 {
-    return ( ( (double*) key1 )[0] == ( (double*) key2 )[0] ) && ( ( (double*) key1 )[1] == ( (double*) key2 )[1] );
+    return ( ( (double *) key1 )[0] == ( (double *) key2 )[0] ) && ( ( (double *) key1 )[1] == ( (double *) key2 )[1] );
 }
 
 hashtable* ht_create_d1( int size )
@@ -415,12 +415,12 @@ hashtable* ht_create_str( int size )
 
 static void print_double( void* data )
 {
-    printf( " \"%d\"", (int) *(double*) data );
+    printf( " \"%d\"", (int) *(double *) data );
 }
 
 static void print_string( void* data )
 {
-    printf( " \"%s\"", (char*) data );
+    printf( " \"%s\"", (char *) data );
 }
 
 int main()
@@ -553,9 +553,9 @@ int main()
     hashtable* ht;
     int      i;
 
-    /*
-     * double[2] key
-     */
+    //
+    // double[2] key
+    //
 
     printf( "\n1. Testing a table with key of double[2] type\n\n" );
 
@@ -615,9 +615,9 @@ int main()
     ht_destroy( ht );
     printf( "done\n" );
 
-    /*
-     * char* key
-     */
+    //
+    // char* key
+    //
 
     printf( "\n2. Testing a table with key of char* type\n\n" );
 
@@ -699,4 +699,4 @@ int main()
     return 0;
 }
 
-#endif                          /* HT_TEST */
+#endif                          // HT_TEST
