@@ -1,31 +1,31 @@
-/*  $Id: tai-utc-gen.c 10785 2010-01-31 20:05:17Z hezekiahcarty $
- *
- *  Copyright (C) 2009 Alan W. Irwin
- *
- *  This file is part of PLplot.
- *  PLplot is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Library Public License as published
- *  by the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  PLplot is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with PLplot; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
- *
- */
+//  $Id: tai-utc-gen.c 11680 2011-03-27 17:57:51Z airwin $
+//
+//  Copyright (C) 2009 Alan W. Irwin
+//
+//  This file is part of PLplot.
+//  PLplot is free software; you can redistribute it and/or modify
+//  it under the terms of the GNU Library General Public License as published
+//  by the Free Software Foundation; either version 2 of the License, or
+//  (at your option) any later version.
+//
+//  PLplot is distributed in the hope that it will be useful,
+//  but WITHOUT ANY WARRANTY; without even the implied warranty of
+//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+//  GNU Library General Public License for more details.
+//
+//  You should have received a copy of the GNU Library General Public License
+//  along with PLplot; if not, write to the Free Software
+//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+//
+//
 
-/* Program for generating data structure used for containing tai-utc
- * conversion information (linear transforms and leap seconds).
- *
- * The program assumes that argv[1] will be the input file, and
- * argv[2] the output file.  This works cross-platform without
- * worrying about shell redirects of stdin and stdout that are
- * not accessible on Windows, apparently.  */
+// Program for generating data structure used for containing tai-utc
+// conversion information (linear transforms and leap seconds).
+//
+// The program assumes that argv[1] will be the input file, and
+// argv[2] the output file.  This works cross-platform without
+// worrying about shell redirects of stdin and stdout that are
+// not accessible on Windows, apparently.
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -33,9 +33,9 @@
 #include <math.h>
 
 
-/*--------------------------------------------------------------------------*\
- *   Function-like macro definitions
- \*--------------------------------------------------------------------------*/
+//--------------------------------------------------------------------------
+//   Function-like macro definitions
+//--------------------------------------------------------------------------
 
 #define MemError1( a )    do { fprintf( stderr, "MEMORY ERROR %d\n" a "\n", __LINE__ ); exit( __LINE__ ); } while ( 0 )
 
@@ -44,7 +44,7 @@ const char header[] = ""
                       "  This file is part of PLplot.\n"                                                 \
                       "  \n"                                                                             \
                       "  PLplot is free software; you can redistribute it and/or modify\n"               \
-                      "  it under the terms of the GNU General Library Public License as published\n"    \
+                      "  it under the terms of the GNU Library General Public License as published\n"    \
                       "  by the Free Software Foundation; either version 2 of the License, or\n"         \
                       "  (at your option) any later version.\n"                                          \
                       "  \n"                                                                             \
@@ -99,18 +99,18 @@ int main( int argc, char *argv[] )
         exit( 1 );
     }
 
-    /*
-     *   Work out how many lines we have all up
-     */
+    //
+    //   Work out how many lines we have all up
+    //
 
     while ( ( fgets( readbuffer, 255, fr ) != NULL ) )
     {
         ++number_of_lines;
     }
 
-    /*
-     *   Allocate memory to the arrays which will hold the data
-     */
+    //
+    //   Allocate memory to the arrays which will hold the data
+    //
 
     if ( ( MJDstart = (int *) calloc( number_of_lines, (size_t) sizeof ( int ) ) ) == NULL )
         MemError1( "Allocating memory to the MJDstart table" );
@@ -127,25 +127,25 @@ int main( int argc, char *argv[] )
     if ( ( leap_sec = (double *) calloc( number_of_lines, (size_t) sizeof ( double ) ) ) == NULL )
         MemError1( "Allocating memory to the leap_sec table" );
 
-    rewind( fr ); /* Go back to the start of the file */
+    rewind( fr ); // Go back to the start of the file
 
-    /*
-     *    Read in line by line, and copy the numbers into our arrays
-     */
+    //
+    //    Read in line by line, and copy the numbers into our arrays
+    //
 
     while ( ( fgets( readbuffer, 255, fr ) != NULL ) )
     {
         sscanf( readbuffer, "%*s %*s %*s %*s %d.5 %*s %lf %*s %*s %*s %*s %d.) X %lf S", (int *) &jd, (double *) &offset1[i], (int *) &offset2[i], (double *) &slope[i] );
-        /* Should be exact since all jd's in the file are integer+0.5 */
+        // Should be exact since all jd's in the file are integer+0.5
         MJDstart[i] = jd - 2400000;
         i++;
     }
 
     fclose( fr );
 
-/*
- *   Write the data out to file ready to be included in our source
- */
+//
+//   Write the data out to file ready to be included in our source
+//
 
 
     fprintf( fw, "%s\n", header );
@@ -161,14 +161,15 @@ int main( int argc, char *argv[] )
         if ( i == 0 )
             leap_sec[i] = 0.;
         else
-            /* sec is TAI-UTC in seconds calculated from UTC transformation
-             * (equation 1 in README.tai-utc).  This calculation must be correct
-             * for start of epoch range.  However, near end of epoch range where
-             * ambiguities in UTC occur, must use equivalent TAI transformation
-             * (equation 2 from same source) to calculate the UTC discontinuity
-             * unambiguously. */
+            // sec is TAI-UTC in seconds calculated from UTC transformation
+            // (equation 1 in README.tai-utc).  This calculation must be correct
+            // for start of epoch range.  However, near end of epoch range where
+            // ambiguities in UTC occur, must use equivalent TAI transformation
+            // (equation 2 from same source) to calculate the UTC discontinuity
+            // unambiguously.
             leap_sec[i] = sec - ( offset1[i - 1] + (double) ( MJDstart[i] + sec / 86400. - offset2[i - 1] ) * slope[i - 1] ) / ( 1. + slope[i - 1] / 86400. );
-        if ( fabs( leap_sec[i] ) < 1.e-14 ) leap_sec[i] = 0.;
+        if ( fabs( leap_sec[i] ) < 1.e-14 )
+            leap_sec[i] = 0.;
         fprintf( fw, "{%d, %15.8f, 0., %20.14f, %15.8f, %d, %15.8f},\n", MJDstart[i], sec, leap_sec[i], offset1[i], offset2[i], slope[i] );
     }
     fprintf( fw, "};\n" );
