@@ -1,4 +1,4 @@
-#! /bin/bash
+#!/bin/bash
 
 # This script generates a tarball of source code and screenshots,
 # 'htdocs_plot_examples.tgz', that will be part of the 'examples' web page,
@@ -82,7 +82,7 @@ popd
 $CP examples/c/lena.pgm .
 
 for exe in 01 02 03 04 05 06 07 08 09 10 11 12 13 14 15 16 17 18 19 20 21 22 \
-    23 24 25 26 27 28 29 30 31 32; do
+    23 24 25 26 27 28 29 30 31 32 33; do
 
     if [ $exe = "08" -o $exe = "16" -o $exe = "20" -o $exe = "30" ] ; then
       # The default cairo graphics AA looks good for these examples now
@@ -90,14 +90,16 @@ for exe in 01 02 03 04 05 06 07 08 09 10 11 12 13 14 15 16 17 18 19 20 21 22 \
       # to explicitly turn graphics AA off any more with
       # DRIVEROPT='-drvopt graphics_anti_aliasing=1'
 	DRIVEROPT=
+    elif [ $exe = "09" -o $exe = "21" ] ; then
+      # Text clipping.
+        DRIVEROPT='-drvopt text_clipping=1'
+    elif [ $exe = "27" ] ; then
+      # even-odd fill rule (a general option rather than a driver option)
+      # generates more interesting results.
+        DRIVEROPT='-eofill'
     else
-	if [ $exe = "09" -o $exe = "21" ] ; then
-        # Text clipping.
-            DRIVEROPT='-drvopt text_clipping=1'
-	else
-        # Otherwise use default graphics AA which is full AA 
-            DRIVEROPT=
-	fi
+      # Otherwise use default graphics AA which is full AA 
+        DRIVEROPT=
     fi
     echo Working on example ${exe} using DRIVEROPT of $DRIVEROPT
 
@@ -128,11 +130,11 @@ for exe in 01 02 03 04 05 06 07 08 09 10 11 12 13 14 15 16 17 18 19 20 21 22 \
     rm -rf $EXDIR/demo${exe}
     mkdir -p $EXDIR/demo${exe}
     mv *${exe}.??.png $EXDIR/demo${exe}
-    # Note both Ada and fortran 77 examples grabbed from the installed
+    # Note configured fortran 77 examples must be grabbed from the installed
     # examples.
     for f in \
-	$cexamples_dir/../ada/x${exe}a.adb \
-	$cexamples_dir/../ada/xthick${exe}a.adb \
+	examples/ada/x${exe}a.adb \
+	examples/ada/xthick${exe}a.adb \
         examples/c/x${exe}c.c \
 	examples/c++/x${exe}.cc \
 	$cexamples_dir/../f77/x${exe}f.f \
