@@ -1,48 +1,50 @@
-/* $Id: plvect.c 10864 2010-03-13 23:37:28Z airwin $
- *
- *      Vector plotting routines.
- *
- * Copyright (C) 2004  Andrew Ross
- *
- * This file is part of PLplot.
- *
- * PLplot is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Library Public License as published
- * by the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * PLplot is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with PLplot; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
- */
+// $Id: plvect.c 11759 2011-06-01 17:41:34Z airwin $
+//
+//      Vector plotting routines.
+//
+// Copyright (C) 2004  Andrew Ross
+//
+// This file is part of PLplot.
+//
+// PLplot is free software; you can redistribute it and/or modify
+// it under the terms of the GNU Library General Public License as published
+// by the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+//
+// PLplot is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Library General Public License for more details.
+//
+// You should have received a copy of the GNU Library General Public License
+// along with PLplot; if not, write to the Free Software
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+//
 
 #define NEED_PLDEBUG
 #include "plplotP.h"
 #include <float.h>
 #include <ctype.h>
 
-/* Static function prototypes */
+// Static function prototypes
 
 static void plP_plotvect( PLFLT x, PLFLT y, PLFLT u, PLFLT v, PLFLT scale );
 
-/*--------------------------------------------------------------------------*\
- * void c_plsvect()
- *
- * Set the style of the arrow used by plvect
- \*--------------------------------------------------------------------------*/
+//--------------------------------------------------------------------------
+// void c_plsvect()
+//
+// Set the style of the arrow used by plvect
+//--------------------------------------------------------------------------
 
 void
-c_plsvect( PLFLT *arrowx, PLFLT *arrowy, PLINT npts, PLINT fill )
+c_plsvect( const PLFLT *arrowx, const PLFLT *arrowy, PLINT npts, PLINT fill )
 {
     int i;
 
-    if ( plsc->arrow_x ) free_mem( plsc->arrow_x );
-    if ( plsc->arrow_y ) free_mem( plsc->arrow_y );
+    if ( plsc->arrow_x )
+        free_mem( plsc->arrow_x );
+    if ( plsc->arrow_y )
+        free_mem( plsc->arrow_y );
 
     if ( ( ( plsc->arrow_x = (PLFLT *) malloc( npts * sizeof ( PLFLT ) ) ) == NULL ) ||
          ( ( plsc->arrow_y = (PLFLT *) malloc( npts * sizeof ( PLFLT ) ) ) == NULL ) )
@@ -59,9 +61,9 @@ c_plsvect( PLFLT *arrowx, PLFLT *arrowy, PLINT npts, PLINT fill )
     }
 }
 
-/*
- * Plot an individual vector
- */
+//
+// Plot an individual vector
+//
 static void
 plP_plotvect( PLFLT x, PLFLT y, PLFLT u, PLFLT v, PLFLT scale )
 {
@@ -72,7 +74,8 @@ plP_plotvect( PLFLT x, PLFLT y, PLFLT u, PLFLT v, PLFLT scale )
     uu = scale * u;
     vv = scale * v;
 
-    if ( uu == 0.0 && vv == 0.0 ) return;
+    if ( uu == 0.0 && vv == 0.0 )
+        return;
 
     if ( ( ( a_x = (PLINT *) malloc( sizeof ( PLINT ) * ( plsc->arrow_npts ) ) ) == NULL ) ||
          ( ( a_y = (PLINT *) malloc( sizeof ( PLINT ) * ( plsc->arrow_npts ) ) ) == NULL ) )
@@ -88,7 +91,7 @@ plP_plotvect( PLFLT x, PLFLT y, PLFLT u, PLFLT v, PLFLT scale )
     dpx = plP_wcpcx( x + 0.5 * uu ) - px0;
     dpy = plP_wcpcy( y + 0.5 * vv ) - py0;
 
-    /* transform arrow -> a */
+    // transform arrow -> a
 
     for ( j = 0; j < plsc->arrow_npts; j++ )
     {
@@ -96,7 +99,7 @@ plP_plotvect( PLFLT x, PLFLT y, PLFLT u, PLFLT v, PLFLT scale )
         a_y[j] = (PLINT) ( plsc->arrow_x[j] * dpy + plsc->arrow_y[j] * dpx + py0 );
     }
 
-    /* draw the arrow */
+    // draw the arrow
     plP_draphy_poly( a_x, a_y, plsc->arrow_npts );
     if ( plsc->arrow_fill )
     {
@@ -108,12 +111,12 @@ plP_plotvect( PLFLT x, PLFLT y, PLFLT u, PLFLT v, PLFLT scale )
     free( (void *) a_y );
 }
 
-/*
- * void plfvect()
- *
- * Routine to plot a vector array with arbitrary coordinate
- * and vector transformations
- */
+//
+// void plfvect()
+//
+// Routine to plot a vector array with arbitrary coordinate
+// and vector transformations
+//
 void plfvect( PLFLT ( *getuv )( PLINT, PLINT, PLPointer ),
               PLPointer up, PLPointer vp,
               PLINT nx, PLINT ny, PLFLT scale,
@@ -139,7 +142,7 @@ void plfvect( PLFLT ( *getuv )( PLINT, PLINT, PLPointer ),
         }
     }
 
-    /* Calculate apropriate scaling if necessary */
+    // Calculate apropriate scaling if necessary
     if ( scale <= 0.0 )
     {
         if ( nx <= 1 && ny <= 1 )
@@ -210,10 +213,10 @@ void plfvect( PLFLT ( *getuv )( PLINT, PLINT, PLPointer ),
 }
 
 void
-c_plvect( PLFLT **u, PLFLT **v, PLINT nx, PLINT ny, PLFLT scale,
+c_plvect( const PLFLT **u, const PLFLT **v, PLINT nx, PLINT ny, PLFLT scale,
           void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
           PLPointer pltr_data )
 {
-    plfvect( plf2eval1, ( PLPointer ) u, ( PLPointer ) v,
+    plfvect( plf2eval1, (PLPointer) u, (PLPointer) v,
         nx, ny, scale, pltr, pltr_data );
 }
