@@ -1,12 +1,12 @@
-/* $Id: pltek.c 10785 2010-01-31 20:05:17Z hezekiahcarty $
- *
- *  Review a Tektronix vector file.
- *  from 'scan', by Clair Nielsen, LANL.
- *  Modifications by Maurice LeBrun, IFS.
- *
- *  This version works well with xterm and at least one vt100/tek emulator
- *  I've tried.
- */
+// $Id: pltek.c 11289 2010-10-29 20:44:17Z airwin $
+//
+//  Review a Tektronix vector file.
+//  from 'scan', by Clair Nielsen, LANL.
+//  Modifications by Maurice LeBrun, IFS.
+//
+//  This version works well with xterm and at least one vt100/tek emulator
+//  I've tried.
+//
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -17,10 +17,10 @@
 static void describe( void );
 static void tek_mode( int mode );
 
-#define ESC           27                /* ESCape character */
+#define ESC           27                // ESCape character
 
-#define ALPHA_MODE    0                 /* switch to alpha mode */
-#define GRAPH_MODE    1                 /* switch to graph mode */
+#define ALPHA_MODE    0                 // switch to alpha mode
+#define GRAPH_MODE    1                 // switch to graph mode
 #define BUFSZ         1024
 #define MAXPAGES      1024
 
@@ -33,7 +33,7 @@ main( int argc, char *argv[] )
     FILE *fd;
     int  i, j, nb, npage, ipage, ifirst, oldpage;
     int  istop;
-    long start[MAXPAGES];               /* start (offset) of each page */
+    long start[MAXPAGES];               // start (offset) of each page
     char buf[BUFSZ], xtra, lastchar = '\0';
     char c, ibuf[128], *t;
 
@@ -62,7 +62,7 @@ main( int argc, char *argv[] )
         }
     }
 
-/* Find out how many pages there are in file. */
+// Find out how many pages there are in file.
 
     ipage    = 0;
     start[0] = 0;
@@ -83,14 +83,14 @@ main( int argc, char *argv[] )
         }
     }
 
-/* don't count a FF at the end of the file as a separate page */
+// don't count a FF at the end of the file as a separate page
 
     if ( lastchar == '\f' )
         ipage--;
 
     npage = ipage + 1;
 
-/* Loop until the user quits */
+// Loop until the user quits
 
     ipage = 0;
     while ( 1 )
@@ -103,41 +103,41 @@ main( int argc, char *argv[] )
 
         c = ibuf[0];
 
-/* User input a page number or a return */
-/* A carriage return in response to the prompt proceeds to the next page. */
+// User input a page number or a return
+// A carriage return in response to the prompt proceeds to the next page.
 
-        if ( c == '\n' )                  /* CR = increment by one page */
+        if ( c == '\n' )                  // CR = increment by one page
         {
             ipage++;
         }
-        else if ( c == '+' )            /* +<n> = increment by <n> pages */
+        else if ( c == '+' )            // +<n> = increment by <n> pages
         {
             ipage += atoi( ibuf + 1 );
         }
-        else if ( c == '-' )            /* -<n> = decrement by <n> pages */
+        else if ( c == '-' )            // -<n> = decrement by <n> pages
         {
             ipage -= atoi( ibuf + 1 );
         }
-        else if ( isdigit( c ) )         /* <n> = goto page <n> */
+        else if ( isdigit( c ) )         // <n> = goto page <n>
         {
             ipage = atoi( ibuf );
         }
         else if ( c == '\f' )
         {
-            ;                           /* FF = redraw the last plot */
+            ;                           // FF = redraw the last plot
         }
-        else if ( c == 'q' )            /* q = quit */
+        else if ( c == 'q' )            // q = quit
         {
             break;
         }
-        else                            /* h, ? or garbage = give help */
+        else                            // h, ? or garbage = give help
         {
             tek_mode( ALPHA_MODE );
             describe();
             continue;
         }
 
-/* Bounds checking */
+// Bounds checking
 
         if ( ipage > npage )
         {
@@ -151,16 +151,16 @@ main( int argc, char *argv[] )
         }
         else if ( ipage == 0 )
         {
-            continue;                   /* page 0 does not exist */
+            continue;                   // page 0 does not exist
         }
 
-/* Time to actually plot something. */
+// Time to actually plot something.
 
         tek_mode( GRAPH_MODE );
         istop = fseek( fd, start[ipage - 1], 0 );
         xtra  = '\0';
         istop = 0;
-        for ( i = 0; i < 8196; i++ )      /* less than 8MB per page! */
+        for ( i = 0; i < 8196; i++ )      // less than 8MB per page!
         {
             if ( xtra )
             {
@@ -205,16 +205,16 @@ main( int argc, char *argv[] )
         if ( termtype == xterm )
             tek_mode( ALPHA_MODE );
     }
-    tek_mode( ALPHA_MODE );               /* how to kill an xterm Tek window? */
+    tek_mode( ALPHA_MODE );               // how to kill an xterm Tek window?
     fclose( fd );
     exit( 0 );
 }
 
-/*----------------------------------------------------------------------*\
- *  tek_mode()
- *
- *  switch to alpha/graph mode
- \*----------------------------------------------------------------------*/
+//--------------------------------------------------------------------------
+//  tek_mode()
+//
+//  switch to alpha/graph mode
+//--------------------------------------------------------------------------
 
 static int currentmode = ALPHA_MODE;
 static void
@@ -229,14 +229,14 @@ tek_mode( int mode )
             case tekterm:
                 break;
             case xterm:
-                printf( "\033[?38h" );            /* open graphics window */
+                printf( "\033[?38h" );            // open graphics window
                 break;
             default:
-                printf( "\033[?38h" );            /* open graphics window */
+                printf( "\033[?38h" );            // open graphics window
             }
-            printf( "\035" );                     /* Enter Vector mode = GS */
+            printf( "\035" );                     // Enter Vector mode = GS
         }
-        printf( "\033\f" );                       /* clear screen = ESC FF */
+        printf( "\033\f" );                       // clear screen = ESC FF
         fflush( stdout );
         currentmode = mode;
     }
@@ -245,26 +245,26 @@ tek_mode( int mode )
         switch ( termtype )
         {
         case tekterm:
-            printf( "\037\030" );         /* Enter Alpha mode = US CAN */
+            printf( "\037\030" );         // Enter Alpha mode = US CAN
             break;
         case xterm:
-            printf( "\033\003" );         /* VT mode (xterm) = ESC ETX */
+            printf( "\033\003" );         // VT mode (xterm) = ESC ETX
             break;
         default:
-            printf( "\033\003" );         /* VT mode (xterm) = ESC ETX */
+            printf( "\033\003" );         // VT mode (xterm) = ESC ETX
         }
         fflush( stdout );
         currentmode = mode;
     }
 }
 
-/*----------------------------------------------------------------------*\
- *  describe()
- *
- *  Print help message.
- *  Note: if this message starts to exceed 512 bytes, may need to split
- *  since some compilers can't handle strings that long.
- \*----------------------------------------------------------------------*/
+//--------------------------------------------------------------------------
+//  describe()
+//
+//  Print help message.
+//  Note: if this message starts to exceed 512 bytes, may need to split
+//  since some compilers can't handle strings that long.
+//--------------------------------------------------------------------------
 
 static void
 describe( void )
