@@ -18,7 +18,7 @@
 	<h3>Introduction</h3>
         <p>PLplot is a cross-platform software package for creating scientific plots.  To help accomplish that task it is organized as a core C library, language bindings for that library, and device drivers which control how the plots are presented in non-interactive and interactive plotting contexts.</p>
 	<p>The PLplot core library can be used to create standard x-y plots, semi-log plots, log-log plots, contour plots, 3D surface plots, mesh plots, bar charts and pie charts. Multiple graphs (of the same or different sizes) may be placed on a single page, and multiple pages are allowed for those device formats that support them.</p>
-	<p>PLplot has core support for Unicode. This means plots can be labelled using the enormous selection of Unicode mathematical symbols for simple text layout (left to right) language scripts using our libfreetype-based devices. For our SVG and libpango/libcairo-based devices we additionally support complex text layout (CTL) languages such as Arabic, Hebrew, and Indic and Indic-derived CTL scripts such as Devanagari, Thai, Lao, and Tibetan.</p>
+	<p>PLplot has core support for Unicode. This means for our many Unicode-aware devices that plots can be labelled using the enormous selection of Unicode mathematical symbols.  A large subset of our Unicode-aware devices also support complex text layout (CTL) languages such as Arabic, Hebrew, and Indic and Indic-derived CTL scripts such as Devanagari, Thai, Lao, and Tibetan.</p>
         <p>A number of compiled and interpreted languages have access to PLplot, <a href="#languages">see our list of language bindings</a>.</p>
         <p>PLplot device drivers support <a href="#files">a number of different file formats</a> for non-interactive plotting and <a href="#interactive">a number of different platforms</a> that are suitable for interactive plotting.  It is easy to add new device drivers to PLplot by writing a small number of device dependent routines.</p>
 <p>PLplot is free software primarily licensed under the
